#!/usr/bin/env python
#Usage: $0 uni0E01 > code.txt
#or:    $0 --all

import os
import sys
import dfont

# cvt value
#NEW VALUE ***
#    "headdia":          257,    #384
#    "headstem":         258,    #120
#    "hwidth_14":        256,    #896    =ko_kai
cvt_dict = {
    "w_1337":           57,     #1337
    "w_1290":           127,    #1290
    "w_1231":           75,     #1231
    "w_1180":           73,     #1180
    "w_1133":           60,     #1133
    "w_1120":           200,    #1120
    "w_1112":           228,    #1112
    "w_1081":           71,     #1081
    "w_1051":           225,    #1051
    "w_1024":           138,    #1024
    "w_973":            178,    #973
    "w_926":            275,    #926
    "w_866":            286,    #866
    "w_569":            58,     #569
    "w_522":            108,    #522
    "w_455":            109,    #455
    "w_397":            45,     #397
    "w_385":            44,     #385
    "w_307":            1,      #307
    "w_291":            87,     #291
    "w_264":            271,    #264
#
    "w_236":            159,    #236
    "w_213":            102,    #213
    "w_195":            144,    #195
    "w_172":            16,     #172
    "w_154":            85,     #154
    "w_139":            238,    #139
#
    "base":             10,     #0
    "hstem":            13,         #358
    "hstem_curve":      144,        #195    =big curve hstem
    "hstem_thin":       54,         #246
#
    "vstem_236":        159,        #236    =3 spline, thinner
    "vstem_258":        161,        #258    =2 spline, thicker
    "vstem_thin":       85,         #154
    "vstem_small":      221,        #133 
    "vstem_tiny":       124,        #152
#
    "headstem":         30,         #127
    "headstem_plus_hole":   301,    #279
    "headstem_small":   36,         #113    =kho
    "headstem_small_plus_hole":   271,          #264
    "headstem_tiny":    158,        #106
    "headstem_tiny_plus_hole":    4,            #233
    "headstem_wan":     260,    #60
    "headstem_big":     16,     #172
    "headstem_sara":    59,     #88
    "headstem_sara_plus_hole":    94,    #193
    "sarastem":         30,         #127
#
    "headdia":          298,        #406
    "headdia_small":    198,        #377    =kho
    "headdia_tiny":     24,         #340
    "headdia_sara":     91,         #281
    "headhole":         131,        #152    
    "headneck_kho":     39,     #180    =kho
#
    "hwidth_a":         61,     #1085   =a
    "hwidth_ching":     275,    #926    =cho_ching
#
    "hnext_1":          58,         #569    =next spline of sho_sher
#
    "vheight":          179,        #1120   =normal height 
    "vheight_shoot":    202,        #1147   =overshoot height
    "vheight_hi":       49,     #1208   =ko 
    "vheight_hi_kho":   47,     #1204   =kho 
    "vheight_po":       163,        #1556   =po_pla, fo_fa
    "vheight_o":        197,        #1638   =sara_o, sara_i
    "vheight_lo":       152,        #29 
    "vheight_lu":       98,         #410    =lo_lu
    "vheight_below_do": 98,     #410
    "vheight_num":      275,        #926
    "vheight_sara1":    127,        #1290
#
    "head_diff":        131,    #254    =head of character: bo,po
    "beak_diff":        148,    #84     =beak of ko,tho
    "beak_diff_2":      38,     #340    =beak of ko,tho
#
    "front_001":        7,          #162
#
    "front_kai":        59,         #88     =front spacing of ko_kai
    "front_khai":       262,        #20     =front spacing of kho_khai
    "front_dek":        30,         #127
    "front_thahan":    38,         #37
#
    "front_khuad":      157,    #451    =front spacing of kho_khud
    "front_tahan":      38,     #340    =front spaceing of to_tahan
    "front_dek":        106,    #213    =front spaceing of do_dek
    "front_thong":      79,     #229    =front spaceing of to_thong
    "front_pung":       228,    #174    =front spaceing of po_pung
    "front_pan":        31,     #330    =front spacing of do_chada, po_pan
    "front_ma":         180,    #377    =front spaceing of mo_ma
    "front_ling":       1,      #184    =front spaceing of lo_ling, aw_ang
#
#special
    "special_1":        230,    #45
    "special_2":        88,     #20
#gap
    "gap_20":           262,    #20
    "gap_88":           59,     #88
    "gap_113":          36,     #113
    "gap_143":          129,    #143
    "gap_162":          7,      #162
    "gap_172":          16,     #172
    "gap_186":          41,     #186
    "gap_195":          144,    #195
    "gap_236":          159,    #236
}

#SKEL
#vd: vstem delta shift
#f_deltap    x 16+4  x 17+2  x 18+2  x 19+2  x 23+4  x 24+4  x 25+4  x 31+4

#hd: head delta shift
#top head
#f_deltap    y 17+8  y 18+8  y 19+8
#bottom_head
#f_deltap    y 17-8  y 18-8  y 19-8

#sd: sara delta shift
#1
#f_deltap   y 12+8  y 16+8  y 18+8  y 38+8  
######### PSUEDO-CODE ##########
pseudo_code_dict = {
    #ko_kai
    "uni0E01": """
f_deltap    27 10+8   27 13-8   27 15-8   27 16-8   27 21+8   27 31-8   27 32+8
srp0    26
mirp[rp0,rnd,white] gap_186 14
mdrp[grey]  18
mdrp[rnd,grey]  17
mirp[rp0,min,rnd,grey]  hstem  12
mdrp[grey]  10
mdrp[rnd,grey]  8
#
srp0    27
mirp[rp0,rnd,white] gap_162 25
mirp[min,rnd,grey]  hstem  1
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]  1
alignrp    13
mirp[rp0,rnd,grey]  vheight_shoot    22
mirp[min,rnd,grey]  vstem_236  5
f_deltap    5 16+4  5 17+2  5 18+2  5 19+2  5 23+4  5 24+4  5 25+4  5 31+4
srp1    13
sloop 10
ip 19 8 18 9 17 10 15 12 2 25
IUP[y]
""",

    #kho_khai
    "uni0E02":  """
f_deltap    52 9+8  52 11+8  52 12+8  52 16-8  52 17+8  52 20+8  52 25-8  52 26+8  52 32+8
srp0    51
mdrp[rp0,rnd,white] 13
mirp[min,rnd,grey]  headstem_small 42
mirp[rp0,rnd,grey]  headdia_small 19
mirp[min,rnd,grey]  headstem_small 48
srp0    13
mdrp[grey]  10
mdrp[rp0,rnd,white] 7
mdrp[grey]  25
mdrp[rp0,rnd,grey]  1
mdap[rnd]   1
f_deltap    1 10-8
mirp[min,rnd,grey]  hstem 30
#
srp0    52
mirp[rp0,rnd,white] gap_162 36
mirp[rp0,min,rnd,grey] hstem 34
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   0
mirp[min,rnd,grey]  vstem_236 32
mirp[rnd,grey]      vheight 36
mirp[rp0,rnd,grey]  vheight_shoot 22
mirp[min,rnd,grey]  vstem_small 10
mdrp[min,rnd,grey]  45
mdrp[rp0,rnd,grey]  16
mirp[min,rnd,grey]  headstem_small 39
srp2    31
ip      3
ip      29
IUP[y]
""",

    #kho_khuad
    "uni0E03": """
f_deltap    59 9+8   59 10+8   59 16-8   59 19+8   59 20+8  59 21+8    59 27+8   59 32+8   
srp0    58
mdrp[rp0,rnd,grey]  18
f_deltap    18 11-8
mirp[min,rnd,grey]  headstem_small 49
mirp[rp0,rnd,grey]  headstem_small_plus_hole 55
mdrp[grey]  24
mdrp[grey]  13
srp0    18
mdrp[rp0,rnd,white] 7
f_deltap    7 17-4   7 20-8   7 28-8
mdrp[grey]  32
srp2    13
sloop   6
ip      27 28 29 9 10 11
mdrp[rp0,rnd,grey]  1
mdap[rnd]   1
f_deltap    1 11+8   1 14+8   1 17-8   1 18+8   1 24-8   1 25+8   1 26+8   1 27+8   
mirp[min,rnd,grey]  hstem 37
#
srp0    59
mirp[rp0,rnd,grey]  gap_162 43
mirp[min,rnd,grey]  hstem 41
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]  1
mirp[min,rnd,grey]  vstem_236   38
mirp[rnd,grey]  vheight 43
mirp[rp0,rnd,grey]  vheight_shoot   27
alignrp     29
mirp[min,rnd,grey]  sarastem 11
shp[rp2]    9
mdrp[rp0,min,rnd,grey]  28
mirp[rp0,min,rnd,grey]  sarastem 10
mdrp[rp0,rnd,white] 15
f_deltap    15 10+8 
mdrp[min,rnd,grey]  13
mirp[min,rnd,grey]  headstem_small 52
mirp[rp0,rnd,grey]  headdia_small 21
f_deltap    21 9+8   
mirp[min,rnd,grey]  headstem_small 46
srp2    38
ip      3
ip      38
f_deltap    3 12-4   3 13-4   3 15-4   3 16-4   3 17-4   3 20-8
IUP[y]
""",

    #kho_kwai
    "uni0E04": """
f_deltap    52 11+8   52 20+8   52 21+8   52 28+8   52 32+8   52 33+8   52 49+8
SRP0                51
MIRP[rp0,rnd,white] gap_113 32
mdrp[grey]      29
mirp[rp0,min,rnd,grey]  hstem 8
mdrp[grey]      28
ip      11
mdrp[rp0,rnd,grey]  20
mdap[rnd]   20
f_deltap    20 9-4 20 10-4 20 11-4 20 12-4  20 18+8   20 20-8 8 20-8  20 32-8   20 42+8   20 47-8 
mirp[min,rnd,grey]  headstem 42
mirp[rp0,rnd,grey]  headstem_plus_hole 48
f_deltap    48 18-8   48 19-8   48 27+8   48 33-8   48 34-8   
mdrp[grey]  14
mdrp[grey]  25
f_deltap    14 22+6   48 23-8 14 23-4   48 24-8 14 24-4   14 37+8 25 37+8   48 38-8   48 39-8   
#
srp0        52
mirp[rp0,rnd,white]  gap_162 38
mirp[min,rnd,grey]  hstem   1
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]           28
ALIGNRP             1
mdrp[rnd,grey]      11
MIRP[rp0,rnd,grey]  vheight_shoot  35
MIRP[rp0,min,rnd,grey]  vstem_236  5
f_deltap    5 16+4  5 17+2  5 18+2  5 19+2  5 23+4  5 24+4  5 25+4  5 31+4
MDRP[rp0,rnd,white] 17
mdap[rnd]   17
f_deltap    17 16-8
MIRP[min,rnd,grey]  headstem  45
MIRP[rp0,rnd,grey]  headdia  23
MIRP[min,rnd,grey]  headstem  39
IUP[y]                              
""",

    #kho_kon
    "uni0E05": """
f_deltap    55 11+8   55 20+8   55 21+8   55 28+8   55 32+8   55 33+8   55 49+8
SRP0                54
MIRP[rp0,rnd,white] gap_113 33
mdrp[grey]      39
mirp[rp0,min,rnd,grey]  hstem 9
mdrp[grey]      29
ip      12
mdrp[rp0,rnd,grey]  21
mdap[rnd]   21
f_deltap    21 9-4 21 11-4 21 12-4  21 14+8  21 18+8   21 20-8 9 20-8   21 32-8   21 42+8
mirp[min,rnd,grey]  headstem 45
mirp[rp0,rnd,grey]  headstem_plus_hole 51
f_deltap    51 18-8   51 19-8   51 27+8   51 33-8   51 34-8   51 38-8   
mdrp[min,rnd,grey]  15
mdrp[grey]  26
f_deltap    51 23-8   51 24-8   51 39-8   
#
srp0        55
mirp[rp0,rnd,white]  gap_162 41
mirp[min,rnd,grey]  hstem   1
srp1    9
sloop   7
ip      36 37 38 4 5 6 7
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]           1
ALIGNRP             29
mdrp[rnd,grey]      12
MIRP[rp0,rnd,grey]  vheight_shoot  36
alignrp     38
mdrp[grey]  7
shp[rp2]    4
mdrp[rp0,min,rnd,grey]  37
mdrp[rp0,grey]  5
MDRP[rp0,rnd,white]  18
mdap[rnd]   18
f_deltap    18 32-8
MIRP[min,rnd,grey]       headstem  48
MIRP[rp0,rnd,grey]       headdia  24
MIRP[min,rnd,grey]       headstem  42
IUP[y]      
""",

    #kho_rakang
    "uni0E06": """
f_deltap    80 9+8   80 19+8   80 20+8   80 21+8  80 32+8   80 33+8   
srp0    79
mdrp[rp0,rnd,grey]  30
f_deltap    30 11-8   30 14+8   30 19-8   30 27+8
mirp[min,rnd,grey]  headstem 58
mirp[rp0,rnd,grey]  headstem_plus_hole 64
mdrp[grey]  36
mdrp[grey]  25
srp0    30
mdrp[rp0,rnd,white]  19
mdrp[grey]  44
srp2    25
sloop   6
ip  39 40 41 21 22 23
srp0    30
mdrp[rp0,rnd,grey]  13
mirp[min,rnd,grey]  hstem 50
shp[rp2]    3
mdrp[rp0,rnd,grey]  9
mirp[min,rnd,grey]  headstem 76
mirp[rnd,grey]  headstem_plus_hole 70
#
srp0    80
mirp[rp0,rnd,white]  gap_162 54
mirp[min,rnd,grey]  hstem 52
shp[rp2]    1
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   1
mirp[min,rnd,grey]  vstem_236 52
mirp[rnd,grey]  vheight_lo  6
mirp[rnd,grey]  vheight 54
mirp[rp0,rnd,grey]  vheight_shoot 39
alignrp 41
mdrp[grey]  23
shp[rp2]    21
mdrp[rp0,min,rnd,grey]  40
mdrp[rp0,grey]  22
mdrp[rp0,rnd,white]  27
mdap[rnd]   27
f_deltap    27 9+8   27 10+8   27 11+8   27 13+8   27 14+8   27 15+8   27 16+8   
mirp[min,rnd,grey]  headstem 61
mirp[rp0,rnd,grey]  headdia 33
f_deltap    33 18+8   33 19+8   
mirp[min,rnd,grey]  headstem 55
srp0    6
mdrp[rp0,rnd,grey]  13
mirp[min,rnd,grey]  headstem 73
mirp[rnd,grey]  headstem_plus_hole 67
mdrp[rp0,rnd,grey]  50
mdrp[min,rnd,grey]  3
srp1    33
srp2    13
ip  15
ip  48
IUP[y]
""",

    #ngo_ngu
    "uni0E07": """
f_deltap    33 10+8  33 16-8
srp0    32
mirp[rp0,rnd,white] gap_20 4
mdrp[grey] 5
#
srp0    33
mirp[rp0,rnd,white]  gap_162 19
mirp[rp0,min,rnd,grey]  hstem 8
mdrp[grey]  1
mdrp[rp0,rnd,grey]  14
mirp[min,rnd,grey]  headstem 29
mirp[rnd,grey]  headstem_plus_hole 23
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   1
mirp[min,rnd,grey]  vstem_236 8
mirp[rp0,rnd,grey]  vheight_shoot 17
sloop   2
ip  5 4
mdrp[rp0,rnd,grey]  11
f_deltap    11 17+8  11 18+8  11 19+8
mirp[min,rnd,grey]  headstem 20
mirp[rnd,grey]  headstem_plus_hole 26
IUP[y]
""",

    #jo_jan
    "uni0E08": """
srp0    44
mirp[rp0,rnd,white] gap_113 7
ip  22
mirp[min,rnd,grey]  headstem 41
mirp[rp0,rnd,grey]  headstem_plus_hole 35
mdrp[grey]  12
mdrp[grey]  2
#
srp0    45
mirp[rp0,rnd,white] gap_143 29
mdrp[grey]  0
mirp[rp0,rnd,grey]  hstem 16
mdrp[grey]  1
ip  13
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]  1
mdrp[grey]  13
f_deltap    13 13-8   13 14-4 13 15-4 13 16-4   13 17-8 13 18-8 13 19-8   13 20-4   13 23-8 
mirp[rp0,rnd,grey]  vheight_shoot 26
mirp[min,rnd,grey]  vstem_236 19
f_deltap    19 16+4  19 17+2  19 18+2  19 19+2  19 23+4  19 24+4  19 25+4  19 31+4
srp1    0
ip  16
ip  29
mdrp[rp0,rnd,white]  10
mirp[min,rnd,grey]  headstem 38
mirp[rp0,rnd,grey]  headdia 4
mirp[min,rnd,grey]  headstem 32
IUP[y]
""",

    #cho_ching
    "uni0E09": """
f_deltap    66 9+8   66 13+8   66 14+8 
srp0    65
mirp[rp0,rnd,white] gap_88 7
f_deltap    7 11+4   7 12-8   7 13-8
mdrp[grey]  22
mirp[min,rnd,grey]  headstem 50
mirp[rnd,grey]  headstem_plus_hole 44
mdrp[rp0,rnd,grey]  1
mdap[rnd]   1
mirp[min,rnd,grey]  hstem 12
shp[rp2]    0
#
srp0    66
mirp[rp0,rnd,white]  gap_88 33
mirp[min,rnd,grey]  headstem 56
mirp[rnd,grey]  headstem_plus_hole 62
mdrp[rp0,rnd,grey]  29
mirp[min,rnd,grey]  hstem 15
shp[rp2]    39
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   0
mirp[min,rnd,grey]  vstem_236 13
mirp[rnd,grey]      vheight_lo  36
mirp[rp0,rnd,grey]  vheight_shoot  26
mdrp[grey]  23
mirp[rp0,min,rnd,grey]  vstem_236 19
f_deltap    19 16+4  19 17+2  19 18+2  19 19+2  19 23+4  19 24+4  19 25+4  19 31+4
mdrp[rp0,grey]  22
f_deltap    22 10+2
mdrp[rp0,min,rnd,white]  10
mdap[rnd]   10
mdrp[rp0,rnd,grey]  4
f_deltap    4 17+8  4 18+8  4 19+8
mirp[min,rnd,grey]  headstem 41
mirp[rnd,grey]  headstem_plus_hole 47
srp0    36
mdrp[min,rnd,grey]  53
mdrp[rp0,rnd,grey]  30
alignrp 15
mdrp[min,rnd,grey]  59
mdrp[min,rnd,grey]  39
IUP[y]
""",

    #cho_chang
    "uni0E0A": """
f_deltap    63 9+8   63 12+8   
srp0    62
mdrp[rp0,rnd,white] 13
mirp[min,rnd,grey]  headstem_small 53
mirp[rp0,rnd,grey]  headdia_small 19
mirp[min,rnd,grey]  headstem_small 59
srp0    13
mdrp[grey]  10
mdrp[rp0,rnd,white] 7
mdrp[grey]  25
mdrp[rp0,rnd,grey]  1
mdap[rnd]   1
f_deltap    1 10-8   1 29+8   1 28+8   1 34+8 
mirp[min,rnd,grey]  hstem 30
#
srp0    63
mirp[rp0,rnd,white] gap_195 47
mirp[min,rnd,grey]  hstem 34
srp1    25
ip      37
mdrp[rp0,grey]      42
mirp[min,rnd,grey]  hstem 41
srp0    37
mdrp[min,rnd,grey]  45
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   0
mirp[min,rnd,grey]  vstem_236 32
mirp[rp0,rnd,grey]  vheight_shoot 22
sloop   3
ip      38 45 37
mdrp[min,rnd,grey]  42
mirp[min,rnd,grey]  vstem_small 10
mdrp[min,rnd,grey]  56
mdrp[rp0,rnd,grey]  16
mirp[min,rnd,grey]  headstem_small 50
srp2    31
ip      3
ip      29
IUP[y]
""",

    #so_zo
    "uni0E0B": """
f_deltap    70 9+8
srp0    69
mdrp[rp0,rnd,grey]  18
f_deltap    18 11-8
mirp[min,rnd,grey]  headstem_small 60
mirp[rp0,rnd,grey]  headstem_small_plus_hole 66
mdrp[grey]  24
mdrp[grey]  13
srp0    18
mdrp[rp0,rnd,white] 7
f_deltap    7 17-4   7 20-8   7 28-8
mdrp[grey]  32
srp2    13
sloop   6
ip      27 28 29 9 10 11
mdrp[rp0,rnd,grey]  1
mdap[rnd]   1
f_deltap    1 11+8   1 14+8   1 17-8   1 18+8   1 24-8   1 25+8   1 26+8   1 27+8   
mirp[min,rnd,grey]  hstem 37
#
srp0    70
mirp[rp0,rnd,white] gap_195 54
mirp[min,rnd,grey]  hstem 41
srp1    32
ip      44
mdrp[rp0,grey]      49
mirp[min,rnd,grey]  hstem 48
srp0    44
mdrp[min,rnd,grey]  52
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]  1
mirp[min,rnd,grey]  vstem_236   38
mirp[rp0,rnd,grey]  vheight_shoot   27
alignrp     29
sloop   3
ip      45 52 44
mdrp[min,rnd,grey]  49
mirp[min,rnd,grey]  sarastem 11
shp[rp2]    9
mdrp[rp0,min,rnd,grey]  28
mirp[rp0,min,rnd,grey]  sarastem 10
mdrp[rp0,rnd,white] 15
f_deltap    15 10+8 
mdrp[min,rnd,grey]  13
mirp[min,rnd,grey]  headstem_small 63
mirp[rp0,rnd,grey]  headdia_small 21
f_deltap    21 9+8   
mirp[min,rnd,grey]  headstem_small 57
srp2    38
ip      3
ip      38
f_deltap    3 12-4   3 13-4   3 15-4   3 16-4   3 17-4   3 20-8
IUP[y]
""",

    #sho_sher
    "uni0E0C": """
f_deltap    76 9+8   
srp0    75
mirp[rp0,rnd,white] gap_186 34
mdrp[grey]  38
mdrp[rnd,grey]  37
mirp[rp0,min,rnd,grey]  hstem 23
mdrp[grey]  21
mdrp[rnd,grey]  19
mdrp[rp0,rnd,grey]  29
f_deltap    29 13-8   29 17-8   29 20-8   29 22-8   
mirp[min,rnd,grey]  headstem 54
mirp[rnd,grey]  headstem_plus_hole 60
#
srp0    76
mirp[rp0,rnd,white]  gap_162 50
mirp[min,rnd,grey]  hstem 48
shp[rp2]    1
srp1    34
ip  12
mdap[rnd]   12
mirp[min,rnd,grey]  hstem 45
shp[rp2]    3
srp2    29
ip  9
mdap[rnd]   9
mirp[min,rnd,grey]  headstem 72
mirp[rnd,grey]  headstem_plus_hole 66
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]  1
mirp[rnd,grey]  vheight_lo  6
shp[rp2]    32
mirp[rnd,grey]  vheight 50
mirp[min,rnd,grey]  vstem_236 48
mirp[rp0,rnd,grey]  vheight_shoot 42
mirp[min,rnd,grey]  vstem_236 16
f_deltap    16 16+4  16 17+2  16 18+2  16 19+2  16 23+4  16 24+4  16 25+4  16 31+4
srp0    32
mdrp[rp0,rnd,grey]  26
f_deltap    26 17-8  26 18-8  26 19-8
alignrp 12
alignrp 46
mdrp[min,rnd,grey]  3
mirp[min,rnd,grey]  headstem 57
shp[rp2]    69
mirp[rnd,grey]  headstem_plus_hole 51
shp[rp2]    63
IUP[y]
""",

    #yo_ying
    "uni0E0D": """
f_deltap    81 9+8   81 11+8   81 20+8   81 32+8
srp0    80
mirp[rp0,rnd,white] gap_186 23
mdrp[grey]  27
mdrp[rnd,grey]  26
mirp[rp0,min,rnd,grey]  hstem 12
mdrp[grey]  10
mdrp[rnd,grey]  8
mdrp[rp0,rnd,grey]  18
mirp[min,rnd,grey]  headstem 42
mirp[rnd,grey]  headstem_plus_hole 48
#
srp0    81
mirp[rp0,rnd,white]  gap_162 38
mirp[min,rnd,grey]  hstem 36
srp1    23
ip  1
mdap[rnd]   1
mirp[min,rnd,grey]  hstem 34
#
srp2    0
ip  66
mdrp[rp0,rnd,grey]  54
mirp[min,rnd,grey]  headstem_tiny 77
mirp[rp0,rnd,grey]  headdia_tiny 60
mirp[min,rnd,grey]  headstem_tiny 71
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]  1
mirp[min,rnd,grey]  vstem_236 35
mirp[rnd,grey]  vheight 38
mirp[rnd,grey]  vheight_lo  21
mirp[rp0,rnd,grey]  vheight_shoot 31
mirp[min,rnd,grey]  vstem_236 5
f_deltap    5 16+4  5 17+2  5 18+2  5 19+2  5 23+4  5 24+4  5 25+4  5 31+4
srp0    21
mdrp[rp0,rnd,grey]  15
f_deltap    15 17-8  15 18-8  15 19-8
mirp[min,rnd,grey]  headstem 45
mirp[rnd,grey]  headstem_plus_hole 39
#
srp0    1
mdrp[rp0,min,rnd,white] 57
mdrp[rnd,grey]  65
mirp[min,rnd,grey]  headstem_tiny 74
mirp[rp0,rnd,grey]  headstem_tiny_plus_hole 68
mdrp[rnd,grey]  51
IUP[y]
""",

    #yo_ying
    "uni0E0D.descless": """
f_deltap    52 9+8   52 11+8   52 20+8   52 32+8
srp0    51
mirp[rp0,rnd,white] gap_186 23
mdrp[grey]  27
mdrp[rnd,grey]  26
mirp[rp0,min,rnd,grey]  hstem 12
mdrp[grey]  10
mdrp[rnd,grey]  8
mdrp[rp0,rnd,grey]  18
mirp[min,rnd,grey]  headstem 42
mirp[rnd,grey]  headstem_plus_hole 48
#
srp0    52
mirp[rp0,rnd,white]  gap_162 38
mirp[min,rnd,grey]  hstem 36
srp1    23
ip  1
mdap[rnd]   1
mirp[min,rnd,grey]  hstem 34
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]  1
mirp[min,rnd,grey]  vstem_236 35
mirp[rnd,grey]  vheight 38
mirp[rnd,grey]  vheight_lo  21
mirp[rp0,rnd,grey]  vheight_shoot 31
mirp[min,rnd,grey]  vstem_236 5
f_deltap    5 16+4  5 17+2  5 18+2  5 19+2  5 23+4  5 24+4  5 25+4  5 31+4
srp0    21
mdrp[rp0,rnd,grey]  15
f_deltap    15 17-8  15 18-8  15 19-8
mirp[min,rnd,grey]  headstem 45
mirp[rnd,grey]  headstem_plus_hole 39
IUP[y]
""",

    #do_chada
    "uni0E0E": """
f_deltap    73 12+8   73 19+8   73 20+8   73 32+8
srp0    72
mirp[rp0,rnd,white] gap_88 35
mirp[min,rnd,grey]  headstem 61
mirp[rnd,grey]  headstem_plus_hole 55
mdrp[rp0,rnd,grey]  40
mdrp[grey]  44
mdrp[rnd,grey]  43
mirp[rp0,min,rnd,grey]  hstem 29
mdrp[grey]  27
mdrp[rnd,grey]  25
#
srp0    73
mirp[rp0,rnd,white]  gap_162 51
mirp[rp0,min,rnd,grey]  hstem 18
alignrp 1
mdrp[rp0,rnd,grey]  8
mirp[rp0,min,rnd,grey]  w_195 70
mdrp[rp0,rnd,white]  66
srp1    1
sloop 5
ip 13 14 15 16 3
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   72
mirp[rnd,grey]  vheight_lo 32
mirp[rnd,grey]  vheight_lu 1
f_deltap    1 11-8 1 12-8
shp[rp2]    5
mirp[rp0,rnd,grey]  vheight_shoot 48
mirp[min,rnd,grey]  vstem_236   22
f_deltap    22 16+4  22 17+2  22 18+2  22 19+2  22 23+4  22 24+4  22 25+4  22 31+4
srp0    32
mdrp[rp0,rnd,grey]  38
f_deltap    38 17-8  38 18-8  38 19-8
mirp[min,rnd,grey]  headstem 58
mirp[rnd,grey]  headstem_plus_hole 52
srp0    5
mirp[min,rnd,grey]  w_139 64
mdrp[rp0,grey]  11
sloop 8
ip 14 13 15 16 3 66 18 68
IUP[y]
""",

    #to_patak
    "uni0E0F": """
f_deltap    79 12+8   79 19+8   79 20+8   79 32+8
srp0    78
mirp[rp0,rnd,white] gap_88 41
mirp[min,rnd,grey]  headstem 67
mirp[rnd,grey]  headstem_plus_hole 61
mdrp[rp0,rnd,grey]  46
mdrp[grey]  50
mdrp[rnd,grey]  49
mirp[rp0,min,rnd,grey]  hstem 36
mdrp[grey]  33
mdrp[rnd,grey]  31
#
srp0    79
mirp[rp0,rnd,white]  gap_162 57
mirp[rp0,min,rnd,grey]  hstem 24
alignrp 1
mdrp[rp0,rnd,grey]  11
mirp[rp0,min,rnd,grey]  w_154 76
mdrp[rp0,rnd,white]  72
srp1    1
sloop 11
ip 16 17 18 19 21 22 23 2 3 4 6
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   78
mirp[rnd,grey]  vheight_lo 38
mirp[rnd,grey]  vheight_lu 1
f_deltap    1 11-8 1 12-8
shp[rp2]    3
shp[rp2]    8
mirp[rp0,rnd,grey]  vheight_shoot 54
mirp[min,rnd,grey]  vstem_236   28
f_deltap    28 16+4  28 17+2  28 18+2  28 19+2  28 23+4  28 24+4  28 25+4  28 31+4
srp0    38
mdrp[rp0,rnd,grey]  44
f_deltap    44 17-8  44 18-8  44 19-8
mirp[min,rnd,grey]  headstem 64
mirp[rnd,grey]  headstem_plus_hole 58
srp0    8
mirp[min,rnd,grey]  w_139 70
shp[rp2]    21
mdrp[rp0,grey]  14
sloop 10
ip 74 72 16 17 18 19 22 2 24 6
IUP[y]
""",

    #tho_than
    "uni0E10": """
f_deltap    114 9+8   
srp0    113
mirp[rp0,rnd,white] gap_113 7
mdrp[grey]  19
mdrp[rnd,grey]  39
mirp[min,rnd,grey]  headstem 54
mirp[rp0,rnd,grey]  headstem_plus_hole 48
mdrp[grey]  2
mdrp[grey] 12
f_deltap    2 12-4 12 12-8   12 20-8   
#
srp0    114
mirp[rp0,rnd,white] gap_172 42
mdrp[grey]  30
mdrp[grey]  0
mirp[rp0,min,rnd,grey]  hstem 16
mdrp[grey]  1
ip  13
#
srp0    42
alignrp 90
mirp[min,rnd,grey]  vstem_236 80
mdrp[rp0,rnd,grey]  84
mirp[min,rnd,grey]  headstem_tiny 102
mirp[rnd,grey]  headstem_tiny_plus_hole 96
srp0    80
mdrp[rp0,rnd,grey]  67
mirp[rp0,min,rnd,grey]  headstem 111
mdrp[rp0,rnd,white]  107
srp2    80
sloop   13
ip  72 73 74 75 76 77 78 79 58 59 60 61 62
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   1
mirp[min,rnd,grey]  vstem_236 13
f_deltap    13 12-2 13 16-8  13 17-8 13 18-4 13 20-4 13 23-8 13 24-8 13 25-8 13 26-8 13 29-8
mirp[rp0,rnd,grey]  vheight_shoot   22
mdrp[grey]  27
mdrp[grey]  29
mirp[rp0,min,rnd,grey]  vstem_236 37
f_deltap    37 16+4  37 17+2  37 18+2  37 19+2  37 23+4  37 24+4  37 25+4  37 31+4
mdrp[grey]  32
mdrp[grey]  30
mdrp[rp0,grey]  39
mdrp[rp0,grey]  19
mdrp[rp0,rnd,white] 10
mdap[rnd]   10
f_deltap    19 12+2   19 13+2   19 14+3   19 15+4   19 16+4   19 17+5   19 18+4   19 19+4   19 20+4   19 21+4   
mirp[min,rnd,grey]  headstem 51
mirp[rp0,rnd,grey]  headdia 4
mirp[min,rnd,grey]  headstem 45
f_deltap    10 18-8 51 18-8   4 19+8 45 19+8   4 23+8 45 23+8   4 24+8 45 24+8   
#
srp0    1
mdrp[rp0,min,rnd,white]  87
mirp[min,rnd,grey]  headstem_tiny 99
mirp[rp0,rnd,grey]  headdia_tiny 81
mirp[min,rnd,grey]  headstem_tiny 93
mdrp[rp0,rnd,white] 80
alignrp 76
alignrp 105
mirp[rp0,rnd,grey]  headstem_tiny 57
alignrp 60
alignrp 64
srp0    105
mdrp[rp0,rnd,white] 109
mirp[min,rnd,grey]  headstem_tiny 70
srp2    64
sloop   7
ip  107 72 73 74 75 62 59
IUP[y]
""",

    #tho_than.descless
    "uni0E10.descless": """
srp0    57
mirp[rp0,min,rnd,grey]  front_kai 19
mdrp[min,rnd,grey]  39
mirp[rp0,rnd,grey]  w_973 42
ip  7
mirp[rp0,min,rnd,grey]  hstem   16
mdrp[rp0,min,rnd,white] 12
ip  13
mdrp[min,rnd,grey]  2
srp0    42
mdrp[rp0,rnd,grey]  30
srp0    42
mdrp[rp0,rnd,grey]  1
mirp[min,rnd,grey]  hstem 0
mdap[rnd]   7
mirp[min,rnd,grey]  headstem 54
mirp[rnd,grey]  headstem_plus_hole 48
IUP[x]
SVTCA[y-axis]
mdap[rnd]   1
mirp[min,rnd,grey]  vstem_236 13
mirp[rp0,rnd,grey]  vheight_shoot   22
mirp[min,rnd,grey]  vstem_236 37
mdrp[rp0,rnd,grey]  29
mirp[min,rnd,grey]  vstem_236 30
mdrp[rp0,min,rnd,white]  27
mirp[rp0,rnd,grey]  vstem_236 32
mdrp[rp0,rnd,white] 40
mirp[rp0,min,rnd,grey]  headstem 18
mdrp[rp0,rnd,white] 10
mirp[min,rnd,grey]  headstem 51
mirp[rp0,rnd,grey]  headdia 4
mirp[min,rnd,grey]  headstem 45
srp1    22
srp2    1
sloop   5
ip  20 19 39 14 44
srp0    1
IUP[y]
""",

    #to_nangmonto
    "uni0E11": """
f_deltap    72 10+8  72 11+8  72 19+8  72 21+8  72 22+8  72 32+8
srp0    71
mdrp[rp0,rnd,grey]  29
f_deltap    29 11-8
mirp[min,rnd,grey]  headstem_small 62
mirp[rp0,rnd,grey]  headstem_small_plus_hole 68
mdrp[grey]  24
mdrp[grey]  35
srp0    29
mdrp[rp0,rnd,white] 18
f_deltap    18 17-4   18 20-8   18 28-8
mdrp[grey]  43
srp2    24
sloop   6
ip      38 39 40 20 21 22
mdrp[rp0,rnd,grey]  12
mdap[rnd]   12
f_deltap    12 11+8   12 14+8   12 17-8   12 18+8   12 24-8   12 25+8   12 26+8   12 27+8   
mirp[min,rnd,grey]  hstem 48
shp[rp2]    11
#
srp0    72
mirp[rp0,rnd,grey]  gap_162 58
mirp[min,rnd,grey]  hstem 1
srp1    43
ip  54
ip  6
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]  11
alignrp     1
mirp[min,rnd,grey]  vstem_236   49
mirp[rp0,rnd,grey]  vheight_shoot   56
alignrp     38
alignrp     40
mirp[min,rnd,grey]  vstem_236 4
srp0    38
mirp[min,rnd,grey]  sarastem 22
shp[rp2]    20
mdrp[rp0,min,rnd,grey]  39
mirp[rp0,min,rnd,grey]  sarastem 21
mdrp[rp0,rnd,white] 26
f_deltap    26 10+8 
mdrp[min,rnd,grey]  24
mirp[min,rnd,grey]  headstem_small 65
mirp[rp0,rnd,grey]  headdia_small 32
f_deltap    32 9+8   32 19+8
mirp[min,rnd,grey]  headstem_small 59
srp2    49
ip      14
ip      47
f_deltap    14 12-4   14 13-4   14 15-4   14 16-4   14 17-4   14 20-8
IUP[y]
""",

    #to_putao
    "uni0E12": """
f_deltap    81 9+8   81 10+8   81 11+8  81 21+8    
SRP0                 80
MIRP[rp0,rnd,white]  gap_113 42
mdrp[grey]  39
MIRP[rp0,min,rnd,grey]   hstem  20
mdrp[grey]  38
ip  23
srp0    42
mdrp[rp0,rnd,white] 29
f_deltap    29 12-4   29 13-8   20 20-8  29 21+8
mirp[min,rnd,grey]  headstem 65
mirp[rp0,rnd,grey]  headdia 35
mirp[min,rnd,grey]  headstem 59
mdrp[grey]  26
#
srp0    81
mirp[rp0,rnd,grey]  gap_162 55
mirp[min,rnd,grey]  hstem 53
shp[rp2]    1
#
srp1    42
ip      12
mdap[rnd]   12
f_deltap    12 27+8   12 28+8   12 33+8   
srp2    20
sloop   7
ip  45 46 47 15 16 17 18
mirp[min,rnd,grey]  hstem 50
shp[rp2]    3
mdrp[rp0,rnd,grey]  9
mirp[min,rnd,grey]  headstem 77
mirp[rnd,grey]  headstem_plus_hole 71
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]           38
ALIGNRP             1
mirp[min,rnd,grey]  vstem_236 23
shp[rp2]    53
f_deltap    23 14+4   23 15+4
mirp[rnd,grey]      vheight_lo  6
mirp[rnd,grey]      vheight 55
MIRP[rp0,rnd,grey]  vheight_shoot  45
alignrp     47
MIRP[grey]  vstem_236  18
shp[rp2]    15
mdrp[rp0,min,rnd,grey]  46
mdrp[rp0,grey]  17
mdrp[rp0,rnd,white]  32
mdap[rnd]   32
f_deltap    32 28+8   32 29+8   32 33+8   32 34+8
mirp[min,rnd,grey]  headstem 62
mirp[rp0,rnd,grey]  headdia 26
mirp[min,rnd,grey]  headstem 56
#
srp0    6
mdrp[min,rnd,grey]  68
mdrp[rp0,rnd,grey]  12
alignrp     51
mdrp[min,rnd,grey]  74
IUP[y]
""",

    #no_nen
    "uni0E13": """
f_deltap    76 9+8   76 20+8   
srp0    75
mirp[rp0,rnd,white] gap_186 23
mdrp[grey]  27
mdrp[rnd,grey]  26
mirp[rp0,min,rnd,grey]  hstem 12
mdrp[grey]  10
mdrp[rnd,grey]  8
mdrp[rp0,rnd,grey]  18
mirp[min,rnd,grey]  headstem 54
mirp[rnd,grey]  headstem_plus_hole 60
#
srp0    76
mirp[rp0,rnd,white]  gap_88 43
mirp[min,rnd,grey]  headstem 66
mirp[rnd,grey]  headstem_plus_hole 72
mdrp[rp0,rnd,grey]  39
mirp[min,rnd,grey]  hstem 37
shp[rp2]    49
#
srp1    23
ip  1
mdap[rnd]   1
mirp[min,rnd,grey]  hstem 34
shp[rp2]    0
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]  0
mirp[min,rnd,grey]  vstem_236 35
mirp[rnd,grey]  vheight 39
mirp[rnd,grey]  vheight_lo  21
shp[rp2]    46
mirp[rp0,rnd,grey]  vheight_shoot 31
mirp[min,rnd,grey]  vstem_236 5
f_deltap    5 16+4  5 17+2  5 18+2  5 19+2  5 23+4  5 24+4  5 25+4  5 31+4
srp0    21
mdrp[rp0,rnd,grey]  15
f_deltap    15 17-8  15 18-8  15 19-8
alignrp 37
alignrp 40
mirp[min,rnd,grey]  headstem 57
shp[rp2]    69
mirp[rnd,grey]  headstem_plus_hole 51
shp[rp2]    63
IUP[y]
""",

    #do_dek
    "uni0E14": """
f_deltap    50 11+8   50 20+8   50 21+8   50 28+8   50 32+8   50 33+8   
SRP0                 49
MIRP[rp0,rnd,white]  gap_113 30
mdrp[grey]  27
MIRP[rp0,min,rnd,grey]   hstem  8
mdrp[grey]  26
ip  11
srp0    30
mdrp[rp0,rnd,white] 17
f_deltap    17 12-4   17 13-8   8 20-8  17 21+8 
mirp[min,rnd,grey]  headstem 46
mirp[rp0,rnd,grey]  headdia 23
mirp[min,rnd,grey]  headstem 40
mdrp[grey]  14
f_deltap    40 38+8   40 39+8   40 40+8   
#
srp0    50
mirp[rp0,rnd,grey]  gap_162 36
mirp[min,rnd,grey]  hstem 1
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]           26
ALIGNRP             1
mirp[min,rnd,grey]  vstem_236 11
f_deltap    12 14+4   12 15+4
MIRP[rp0,rnd,grey]  vheight_shoot  33
MIRP[min,rnd,grey]  vstem_236  5
mdrp[rp0,rnd,white]  20
mirp[min,rnd,grey]  headstem 43
mirp[rp0,rnd,grey]  headdia 14
mirp[min,rnd,grey]  headstem 37
IUP[y]
""",

    #to_tao
    "uni0E15": """
f_deltap    53 9+8   53 11+8   53 20+8   53 21+8   53 28+8   53 32+8   53 33+8
SRP0                 52
MIRP[rp0,rnd,white]  gap_113 31
mdrp[grey]  28
MIRP[rp0,min,rnd,grey]   hstem  9
mdrp[grey]  27
ip  12
srp0    31
mdrp[rp0,rnd,white] 18
f_deltap    18 12-4   18 13-8   9 20-8  18 21+8
mirp[min,rnd,grey]  headstem 49
mirp[rp0,rnd,grey]  headdia 24
mirp[min,rnd,grey]  headstem 43
mdrp[grey]  15
#
srp0    53
mirp[rp0,rnd,grey]  gap_162 39
mirp[min,rnd,grey]  hstem 1
srp1    9
sloop   7
ip  34 35 36 4 5 6 7
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]           27
ALIGNRP             1
mirp[min,rnd,grey]  vstem_236 12
f_deltap    12 14+4   12 15+4
MIRP[rp0,rnd,grey]  vheight_shoot  34
alignrp     36
MIRP[grey]  vstem_236  7
shp[rp2]    4
mdrp[rp0,min,rnd,grey]  35
mdrp[rp0,grey]  5
mdrp[rp0,rnd,white]  21
mdap[rnd]   21
mirp[min,rnd,grey]  headstem 46
mirp[rp0,rnd,grey]  headdia 15
mirp[min,rnd,grey]  headstem 40
IUP[y]
""",

    #to_tung
    "uni0E16": """
f_deltap    48 10+8   48 13-8   48 15-8   48 16-8   48 21+8   48 31-8   48 32+8
srp0    47
mirp[rp0,rnd,white] gap_186 23
mdrp[grey]  27
mdrp[rnd,grey]  26
mirp[rp0,min,rnd,grey]  hstem  12
mdrp[grey]  10
mdrp[rnd,grey]  8
mdrp[rp0,rnd,grey]  18
mirp[min,rnd,grey]  headstem 38
mirp[rnd,grey]  headstem_plus_hole 44
#
srp0    48
mirp[rp0,rnd,white] gap_162 34
mirp[min,rnd,grey]  hstem  1
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]  1
mirp[rnd,grey]  vheight_lo  21
mirp[rp0,rnd,grey]  vheight_shoot  31
mirp[min,rnd,grey]  vstem_236  5
f_deltap    5 16+4  5 17+2  5 18+2  5 19+2  5 23+4  5 24+4  5 25+4  5 31+4
srp0    21
mdrp[rp0,rnd,grey]  15
f_deltap    15 17-8  15 18-8  15 19-8
mirp[min,rnd,grey]  headstem 41
mirp[rnd,grey]  headstem_plus_hole 35
IUP[y]
""",

    #tho_thahan
    "uni0E17": """
f_deltap    41 19+8   41 20+8   41 23+8
srp0    40
mirp[rp0,rnd,white] gap_88 14
mirp[min,rnd,grey]  headstem 37
mirp[rnd,grey]  headstem_plus_hole 31
mdrp[rp0,rnd,grey]  8
mirp[min,rnd,grey]  hstem 19
shp[rp2]     7
#
srp0    41
mirp[rp0,rnd,white] gap_162 27
mirp[min,rnd,grey]  hstem 1
srp1   19
ip  21
ip  6
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]  7
alignrp 1
mdrp[rnd,grey]  20
mirp[rp0,rnd,grey]  vheight_shoot 24
alignrp 17
mirp[min,rnd,grey]  vstem_236 4
f_deltap    4 16+4  4 17+2  4 18+2  4 19+2  4 23+4  4 24+4  4 25+4  4 31+4
srp0    17
mdrp[rp0,rnd,grey]  11
f_deltap    11 17+8  11 18+8  11 19+8
mirp[min,rnd,grey]  headstem 28
mirp[rnd,grey]  headstem_plus_hole 34
IUP[y]
""",

    #to_thong
    "uni0E18": """
f_deltap    38 10+8   38 15-8
srp0    37
mirp[rp0,rnd,white] gap_195 1
mdrp[grey]  11
mdrp[rnd,grey]  31
mdrp[rp0,rnd,grey]  1
mirp[min,rnd,grey]  hstem 3
#
srp0    38
mirp[rp0,rnd,white] gap_162 34
mirp[min,rnd,grey]  hstem 7
mdrp[grey]  22
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]  1
mirp[min,rnd,grey]  vstem_236 4
mirp[rp0,rnd,grey]  vheight_shoot 14
mdrp[grey]  12
mirp[rp0,min,rnd,grey]  vstem_236 29
f_deltap    29 16+4  29 17+2  29 18+2  29 19+2  29 23+4  29 24+4  29 25+4  29 31+4
mdrp[rp0,grey]  11
ip  31
mdrp[grey]  2
IUP[y]
""",

    #no_nu
    "uni0E19": """
f_deltap    54 12+8   54 13+8   54 14+8   54 15+8   54 22+8 
srp0    53
mirp[rp0,rnd,white] gap_88 7
mirp[min,rnd,grey]  headstem 38
mirp[rnd,grey]  headstem_plus_hole 32
mdrp[rp0,rnd,grey]  1
mirp[rp0,min,rnd,grey]  hstem 12
alignrp 0
#
srp0    54
mirp[rp0,rnd,white] gap_88 21
mirp[min,rnd,grey]  headstem 44
mirp[rnd,grey]  headstem_plus_hole 50
mdrp[rp0,rnd,grey]  17
mirp[rp0,min,rnd,grey]  hstem 15
shp[rp2]    27
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]  1
mirp[min,rnd,grey]  vstem_236 13
mirp[rnd,grey]  vheight_lo 24
mirp[rnd,grey]  vheight 17
mirp[rp0,rnd,grey]  vheight_shoot 10
mdrp[rp0,rnd,grey]  4
f_deltap    4 17+8  4 18+8  4 19+8
mirp[min,rnd,grey]  headstem 29
mirp[rnd,grey]  headstem_plus_hole 35
srp0    24
mdrp[min,rnd,grey]  27
mdrp[min,rnd,grey]  41
mdrp[rp0,rnd,grey]  18
alignrp 15
mdrp[min,rnd,grey]  47
IUP[y]
""",

    #bo_baimai
    "uni0E1A": """
f_deltap    30 14+8   30 21+8   30 22+8
srp0    29
mirp[rp0,rnd,white] gap_88 7
mirp[min,rnd,grey]  headstem 26
mirp[rnd,grey]  headstem_plus_hole 20
mdrp[rp0,rnd,grey]  1
mirp[min,rnd,grey]  hstem 12
#
srp0    30
mirp[rp0,rnd,white] gap_162 16
mirp[min,rnd,grey]  hstem 14
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]  1
mirp[min,rnd,grey]  vstem_236 13
mirp[rnd,grey]  vheight 16
mirp[rp0,rnd,grey]  vheight_shoot 10
mdrp[rp0,rnd,grey]  4
f_deltap    4 17+8  4 18+8  4 19+8
mirp[min,rnd,grey]  headstem 17
mirp[rnd,grey]  headstem_plus_hole 23
IUP[y]
""",

    #po_pla
    "uni0E1B": """
f_deltap    30 14+8   30 21+8   30 22+8
srp0    29
mirp[rp0,rnd,white] gap_88 7
mirp[min,rnd,grey]  headstem 26
mirp[rnd,grey]  headstem_plus_hole 20
mdrp[rp0,rnd,grey]  1
mirp[min,rnd,grey]  hstem 12
#
srp0    30
mirp[rp0,rnd,white] gap_162 16
mirp[min,rnd,grey]  hstem 14
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]  1
mirp[min,rnd,grey]  vstem_236 13
mirp[rnd,grey]  vheight_po 16
mirp[rp0,rnd,grey]  vheight_shoot 10
mdrp[rp0,rnd,grey]  4
f_deltap    4 17+8  4 18+8  4 19+8
mirp[min,rnd,grey]  headstem 17
mirp[rnd,grey]  headstem_plus_hole 23
IUP[y]
""",

    #po_pung
    "uni0E1C": """
f_deltap    35 9+8   35 10+8   35 16-8   
srp0    34
mirp[rp0,rnd,white] gap_143 4
mirp[rp0,min,rnd,grey]  hstem 15
alignrp  3
mdrp[rp0,rnd,grey]  10
mirp[min,rnd,grey]  headstem 25
mirp[rnd,grey]  headstem_plus_hole 31
#
srp0    35
mirp[rp0,rnd,white] gap_162 21
mirp[min,rnd,grey]  hstem   19
shp[rp2]    1
srp1    15
sloop   3
ip  17 18 2
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   1
alignrp     3
mirp[min,rnd,grey]  vstem_236 19
shp[rp2]    16
mirp[rnd,grey]  vheight 21
mirp[rp0,rnd,grey]  vheight_shoot 7
mdrp[rp0,rnd,grey]  13
f_deltap    13 17+8  13 18+8  13 19+8
mirp[min,rnd,grey]  headstem 22
mirp[rnd,grey]  headstem_plus_hole 28
srp2    19
ip  17
ip  2
IUP[y]
""",

    #fo_fa
    "uni0E1D": """
f_deltap    35 9+8   35 10+8   35 16-8
srp0    34
mirp[rp0,rnd,white] gap_143 4
mirp[rp0,min,rnd,grey]  hstem 15
alignrp  3
mdrp[rp0,rnd,grey]  10
mirp[min,rnd,grey]  headstem 25
mirp[rnd,grey]  headstem_plus_hole 31
#
srp0    35
mirp[rp0,rnd,white] gap_162 21
mirp[min,rnd,grey]  hstem   19
shp[rp2]    1
srp1    15
sloop   3
ip  17 18 2
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   1
alignrp     3
mirp[min,rnd,grey]  vstem_236 19
shp[rp2]    16
mirp[rnd,grey]  vheight_po 21
mirp[rp0,rnd,grey]  vheight_shoot 7
mdrp[rp0,rnd,grey]  13
f_deltap    13 17+8  13 18+8  13 19+8
mirp[min,rnd,grey]  headstem 22
mirp[rnd,grey]  headstem_plus_hole 28
srp2    19
ip  17
ip  2
IUP[y]
""",

    #po_pan
    "uni0E1E": """
f_deltap    35 9+8   35 10+8   35 19+8   35 20+8   
srp0    34
mirp[rp0,rnd,white] gap_88 10
mirp[min,rnd,grey]  headstem 31
mirp[rnd,grey]  headstem_plus_hole 25
mdrp[rp0,rnd,grey]  4
mirp[min,rnd,grey]  hstem 15
shp[rp2]    3
#
srp0    35
mirp[rp0,rnd,white] gap_162 21
mirp[min,rnd,grey]  hstem   19
shp[rp2]    1
srp1    15
sloop   3
ip  17 18 2
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   1
alignrp     3
mdrp[min,rnd,grey]  19
shp[rp2]    16
mirp[min,rnd,grey]  vheight 21
shp[rp2]     18
ip  2
mirp[rp0,rnd,grey]  vheight_shoot 13
mdrp[rp0,rnd,grey]  7
f_deltap    7 17+8  7 18+8  7 19+8
mirp[min,rnd,grey]  headstem 22
mirp[rnd,grey]  headstem_plus_hole 28
IUP[y]
""",

    #fo_fun
    "uni0E1F": """
f_deltap    35 9+8   35 10+8   35 19+8   35 20+8
srp0    34
mirp[rp0,rnd,white] gap_88 10
mirp[min,rnd,grey]  headstem 31
mirp[rnd,grey]  headstem_plus_hole 25
mdrp[rp0,rnd,grey]  4
mirp[min,rnd,grey]  hstem 15
shp[rp2]    3
#
srp0    35
mirp[rp0,rnd,white] gap_162 21
mirp[min,rnd,grey]  hstem   19
shp[rp2]    1
srp1    15
sloop   3
ip  17 18 2
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   1
alignrp     3
mdrp[min,rnd,grey]  19
shp[rp2]    16
mirp[min,rnd,grey]  vheight_po 21
shp[rp2]     18
ip  2
mirp[rp0,rnd,grey]  vheight_shoot 13
mdrp[rp0,rnd,grey]  7
f_deltap    7 17+8  7 18+8  7 19+8
mirp[min,rnd,grey]  headstem 22
mirp[rnd,grey]  headstem_plus_hole 28
IUP[y]
""",

    #po_sampao
    "uni0E20": """
f_deltap    48 12+8   48 19+8   48 20+8   48 32+8
srp0    47
mirp[rp0,rnd,white] gap_88 18
mirp[min,rnd,grey]  headstem 44
mirp[rnd,grey]  headstem_plus_hole 38
mdrp[rp0,rnd,grey]  23
mdrp[grey]  27
mdrp[rnd,grey]  26
mirp[rp0,min,rnd,grey]  hstem 12
mdrp[grey]  10
mdrp[rnd,grey]  8
#
srp0    48
mirp[rp0,rnd,white]  gap_162 34
mirp[rp0,min,rnd,grey]  hstem 1
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   1
mirp[rnd,grey]  vheight_lo 15
mirp[rp0,rnd,grey]  vheight_shoot 31
mirp[min,rnd,grey]  vstem_236   5
f_deltap    5 16+4  5 17+2  5 18+2  5 19+2  5 23+4  5 24+4  5 25+4  5 31+4
srp0    15
mdrp[rp0,rnd,grey]  21
f_deltap    21 17-8  21 18-8  21 19-8
mirp[min,rnd,grey]  headstem 41
mirp[rnd,grey]  headstem_plus_hole 35
IUP[y]
""",

    #mo_ma
    "uni0E21": """
f_deltap    56 13+8   56 20+8   56 21+8   56 32+8  56 35+8
srp0    55
mirp[rp0,rnd,white]  gap_88 9
alignrp 20
mirp[min,rnd,grey]  headstem 52
shp[rp2]    40
mirp[rnd,grey]  headstem_plus_hole 46
shp[rp2]    34
mdrp[rp0,rnd,grey]  14
mirp[min,rnd,grey]  hstem 25
shp[rp2]    3
#
srp0    56
mirp[rp0,rnd,white] gap_162 30
mirp[min,rnd,grey]  hstem   28
shp[rp2]    1
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   1
mirp[rnd,grey]  vheight_lo 6
mirp[rnd,grey]  vheight 30
mirp[min,rnd,grey]  vstem_236 28
mirp[rp0,rnd,grey]  vheight_shoot 23
mdrp[rp0,rnd,grey]  17
f_deltap    17 17+8  17 18+8  17 19+8
mirp[min,rnd,grey]  headstem 31
mirp[rnd,grey]  headstem_plus_hole 37
srp0    6
mdrp[min,rnd,grey]  3
mdrp[rp0,rnd,grey]  12
mirp[min,rnd,grey]  headstem 49
mirp[rnd,grey]  headstem_plus_hole 43
mdrp[rnd,grey]  26
IUP[y]
""",

    #yo_yak
    "uni0E22": """
f_deltap    45 9+8   45 11+8   45 20+8   45 21+8   45 23+8  45 26+8  45 32+8   45 33+8
srp0    44
mirp[rp0,rnd,white] gap_162 1
mirp[min,rnd,grey]  hstem 28
#mdrp[grey]  8
mdrp[grey]  5
mdrp[rp0,rnd,grey]  14
f_deltap    14 9-2   14 10-4   
mirp[min,rnd,grey]  headstem 35
mirp[rnd,grey]  headstem_plus_hole 41
srp2    28
ip  23
mdrp[rp0,grey]  19
mdrp[grey]  8
#
srp0    45
mirp[rp0,rnd,white] gap_162 31
mirp[min,rnd,grey]  hstem 29
IUP[x]
#
SVTCA[y-axis]
mdap[rnd] 1
mirp[min,rnd,grey]  vstem_236 28
mirp[rnd,grey]      vheight 31
mirp[rp0,rnd,grey]  vheight_shoot 11
mdrp[rp0,rnd,grey]  17
f_deltap    17 17+8  17 18+8  17 19+8
mirp[min,rnd,grey]  headstem 32
mirp[rnd,grey]  headstem_plus_hole 38
f_deltap    38 12-8
srp2    28
ip      24
mdap[rnd]   24
f_deltap    24 14+8   24 15+8
mirp[min,rnd,grey]  w_195 23
ip      5
IUP[y]
""",

    #ro_ruar
    "uni0E23": """
srp0    50
mirp[rp0,white] gap_88 12
mdrp[grey]  32
#
srp0    51
mirp[rp0,rnd,white] gap_172 35
mdrp[grey]  23
mirp[rp0,min,rnd,grey]  hstem 8
mdrp[rp0,rnd,grey]  3
mirp[min,rnd,grey]  headstem 47
mirp[rnd,grey]  headstem_plus_hole 41
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]  50
mirp[rnd,grey]  vheight_lo 0
mirp[rp0,rnd,grey]  vheight_shoot 15
mdrp[grey]  13
mirp[rp0,min,rnd,grey]  vstem_236 30
f_deltap    30 16+4  30 17+2  30 18+2  30 19+2  30 23+4  30 24+4  30 25+4  30 31+4
mdrp[grey]  12
srp0    0
mdrp[rp0,rnd,grey]  6
f_deltap    6 17-8  6 18-8  6 19-8
mirp[min,rnd,grey]  headstem 44
mirp[rnd,grey]  headstem_plus_hole 38
IUP[y]
""",

    #lo_ru
    "uni0E24": """
f_deltap    48 10+8   48 13-8   48 15-8   48 16-8   48 21+8   48 31-8   48 32+8
srp0    47
mirp[rp0,rnd,white] gap_186 23
mdrp[grey]  27
mdrp[rnd,grey]  26
mirp[rp0,min,rnd,grey]  hstem  12
mdrp[grey]  10
mdrp[rnd,grey]  8
mdrp[rp0,rnd,grey]  18
mirp[min,rnd,grey]  headstem 38
mirp[rnd,grey]  headstem_plus_hole 44
#
srp0    48
mirp[rp0,rnd,white] gap_162 34
mirp[min,rnd,grey]  hstem  1
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]  47
mirp[rnd,grey]  vheight_lo  21
mirp[rnd,grey]  vheight_lu  1
mirp[rp0,rnd,grey]  vheight_shoot  31
mirp[min,rnd,grey]  vstem_236  5
f_deltap    5 16+4  5 17+2  5 18+2  5 19+2  5 23+4  5 24+4  5 25+4  5 31+4
srp0    21
mdrp[rp0,rnd,grey]  15
f_deltap    15 17-8  15 18-8  15 19-8
mirp[min,rnd,grey]  headstem 41
mirp[rnd,grey]  headstem_plus_hole 35
IUP[y]
""",

    #lo_ling
    "uni0E25": """
f_deltap    53 9+8   53 32+8   53 33+8   
srp0    52
mirp[rp0,rnd,white] gap_113 18
mdrp[grey]  32
mirp[rp0,min,rnd,grey]  hstem 7
mdrp[rp0,rnd,grey]  13
mirp[min,rnd,grey]  headstem 43
mirp[rnd,grey]  headstem_plus_hole 49
#
srp0    53
mirp[rp0,rnd,white] gap_162 39
mirp[min,rnd,grey]  hstem 25
shp[rp2]    1
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]  1
mdrp[min,rnd,grey]  25
mirp[rnd,grey]  vheight_lo 16
mirp[rp0,rnd,grey]  vheight_shoot 36
mdrp[grey]  33
mirp[rp0,min,rnd,grey]  vstem_236 29
f_deltap    29 16+4  29 17+2  29 18+2  29 19+2  29 23+4  29 24+4  29 25+4  29 31+4
mdrp[rp0,grey]  32
mdap[rnd]   22
f_deltap    22 10-8   22 17-8   
mirp[min,rnd,grey]  vstem_236  4
f_deltap    4 16+4  4 17+2  4 18+2  4 19+2  4 23+4  4 24+4  4 25+4  4 31+4
srp0    16
mdrp[rp0,rnd,grey]  10
f_deltap    10 17-8  10 18-8  10 19-8
mirp[min,rnd,grey]  headstem 46
mirp[rnd,grey]  headstem_plus_hole 40
IUP[y]
""",

    #ro_lu
    "uni0E26": """
f_deltap    48 12+8   48 19+8   48 20+8   48 32+8
srp0    47
mirp[rp0,rnd,white] gap_88 18
mirp[min,rnd,grey]  headstem 44
mirp[rnd,grey]  headstem_plus_hole 38
mdrp[rp0,rnd,grey]  23
mdrp[grey]  27
mdrp[rnd,grey]  26
mirp[rp0,min,rnd,grey]  hstem 12
mdrp[grey]  10
mdrp[rnd,grey]  8
#
srp0    48
mirp[rp0,rnd,white]  gap_162 34
mirp[rp0,min,rnd,grey]  hstem 1
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   47
mirp[rnd,grey]  vheight_lu 1
mirp[rnd,grey]  vheight_lo 15
mirp[rp0,rnd,grey]  vheight_shoot 31
mirp[min,rnd,grey]  vstem_236   5
f_deltap    5 16+4  5 17+2  5 18+2  5 19+2  5 23+4  5 24+4  5 25+4  5 31+4
srp0    15
mdrp[rp0,rnd,grey]  21
f_deltap    21 17-8  21 18-8  21 19-8
mirp[min,rnd,grey]  headstem 41
mirp[rnd,grey]  headstem_plus_hole 35
IUP[y]
""",

    #wo_wan
    "uni0E27": """
srp0    37
mirp[rp0,rnd,white] gap_88 15
#
srp0    38
mirp[rp0,rnd,white] gap_162 22
mirp[rp0,min,rnd,grey]  hstem 8
mdrp[rp0,rnd,grey]  3
mirp[min,rnd,grey]  headstem 34
mirp[rnd,grey]  headstem_plus_hole 28
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]    37
mirp[rnd,grey]  vheight_lo 0
mirp[rp0,rnd,grey]  vheight_shoot 19
mdrp[grey]  16
mirp[rp0,min,rnd,grey]  vstem_236   12
f_deltap    12 16+4  12 17+2  12 18+2  12 19+2  12 23+4  12 24+4  12 25+4  12 31+4
mdrp[grey]  15
srp0    0
mdrp[rp0,rnd,grey]  6
mirp[min,rnd,grey]  headstem 31
mirp[rnd,grey]  headstem_plus_hole 25
IUP[y]
""",

    #so_sala
    "uni0E28": """
f_deltap    64 11+8   64 20+8   64 21+8   64 23+8   64 28+8   64 32+8   64 33+8   64 49+8   
SRP0         63
MIRP[rp0,rnd,white]  gap_113 38
mdrp[grey]      35
mirp[rp0,min,rnd,grey]  hstem 14
mdrp[grey]      34
ip      17
srp0    38
mdrp[rp0,rnd,grey]  26
f_deltap    26 11-6   26 12-4   26 13-8   14 20-8   26 25-8   26 27+8   26 32-8 14 32-8   26 46-8   
mirp[min,rnd,grey]  headstem 54
mirp[rp0,rnd,grey]  headstem_plus_hole 60
f_deltap    60 18-8   60 19-8    26 23+8 54 23+8   60 24-8 14 24-8   60 27+8   
mdrp[grey]  20
mdrp[grey]  31
#
srp0        64
mirp[rp0,rnd,white] gap_162 50
srp2    38
sloop   4
ip      43 45 46 48
mirp[min,rnd,grey]  hstem   1
srp1    14
sloop   4
ip      4 6 7 9
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]           34
ALIGNRP             1
mdrp[rnd,grey]  17
MIRP[rp0,rnd,grey]  vheight_shoot  41
MIRP[rp0,min,rnd,grey]  vstem_236  11
f_deltap    11 16+4  11 17+2  11 18+2  11 19+2  11 23+4  11 24+4  11 25+4  11 31+4
MDRP[rp0,rnd,white] 23
mdap[rnd]   23
f_deltap    23 16-8   23 25-8   
MIRP[min,rnd,grey]  headstem  57
MIRP[rp0,rnd,grey]  headdia  29
MIRP[min,rnd,grey]  headstem  51
IUP[y]             
""",

    #so_lusi
    "uni0E29": """
f_deltap    64 13+8
srp0    63
mirp[rp0,rnd,white] gap_88 7
mirp[min,rnd,grey]  headstem 48
mirp[rnd,grey]  headstem_plus_hole 42
mdrp[rp0,rnd,grey]  1
mirp[rp0,min,rnd,grey]  hstem 12
#
srp0    64
mirp[rp0,rnd,white] gap_195 32
alignrp     38
mdrp[grey]  36
mirp[min,rnd,grey]  hstem 30
shp[rp2]    14  
#srp1    12
#sloop   4
#ip  20 60 54 26
mdrp[grey]  36
ip  35
mdap[rnd]   20
f_deltap    20 15+8
mirp[min,rnd,grey]  headstem_tiny 60
mirp[rp0,rnd,grey]  headdia_tiny 26
mirp[min,rnd,grey]  headstem_tiny 54
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   1
mirp[min,rnd,grey]  vstem_236 13
mirp[rnd,grey]  vheight 32
#srp1    14
#sloop   10 
#ip  23 57 51 17 30 15 33 38 35 36
#srp1    14
#ip  23
mirp[rp0,rnd,grey]  vheight_shoot 10
mdrp[rp0,rnd,grey]  4
f_deltap    4 17+8  4 18+8  4 19+8
mirp[min,rnd,grey]  headstem 39
mirp[rnd,grey]  headstem_plus_hole 45
mdap[rnd]   23
mirp[min,rnd,grey]  headstem_tiny 57
mdrp[rp0,rnd,grey]  17
f_deltap     17 14+8   17 20+8   
ip  35
ip  36
mdrp[rnd,grey]  51
mdrp[min,rnd,grey]  25
IUP[y]
""",

    #so_sua
    "uni0E2A": """
f_deltap    65 9+8   65 32+8   65 33+8
srp0    64
mirp[rp0,rnd,white] gap_113 18
mdrp[grey]  38
mirp[rp0,min,rnd,grey]  hstem 7
mdrp[rp0,rnd,grey]  13
mirp[min,rnd,grey]  headstem 55
mirp[rnd,grey]  headstem_plus_hole 61
#
srp0    65
mirp[rp0,rnd,white] gap_162 51
srp2    38
sloop   4
ip      44 46 47 49
mirp[min,rnd,grey]  hstem 25
shp[rp2]    1
srp1    38
sloop   4
ip      28 30 31 33
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]  1
mdrp[min,rnd,grey]  25
mirp[rnd,grey]  vheight_lo 16
mirp[rp0,rnd,grey]  vheight_shoot 42
mdrp[grey]  39
mirp[rp0,min,rnd,grey]  vstem_236 35
f_deltap    35 16+4  35 17+2  35 18+2  35 19+2  35 23+4  35 24+4  35 25+4  35 31+4
mdrp[rp0,grey]  38
mdap[rnd]   22
f_deltap    22 10-8   22 17-8
mirp[min,rnd,grey]  vstem_236  4
f_deltap    4 16+4  4 17+2  4 18+2  4 19+2  4 23+4  4 24+4  4 25+4  4 31+4
srp0    16
mdrp[rp0,rnd,grey]  10
f_deltap    10 17-8  10 18-8  10 19-8
mirp[min,rnd,grey]  headstem 58
mirp[rnd,grey]  headstem_plus_hole 52
IUP[y]
""",

    #ho_hip
    "uni0E2B": """
f_deltap    63 19+8   63 20+8   63 23+8   63 32+8   63 35+8
srp0    62
mirp[rp0,rnd,white] gap_88 14
mirp[min,rnd,grey]  headstem 47
mirp[rnd,grey]  headstem_plus_hole 41
mdrp[rp0,rnd,grey]  8
mirp[min,rnd,grey]  hstem 19
shp[rp2]     7
#
srp0    63
mirp[rp0,rnd,white] gap_162 37
mirp[min,rnd,grey]  hstem 1
srp1   19
ip  21
ip  6
mdrp[rp0,rnd,grey]  32
mdrp[min,rnd,grey]  53
mdrp[rp0,rnd,grey]  26
f_deltap    26 10-4  26 11-4   26 16+8   26 22-8   26 23-8   26 37-8   
ip  23
ip  35
mdrp[min,rnd,grey]  59
f_deltap   59 20-8 53 20+8   
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]  7
alignrp 1
mdrp[rnd,grey]  20
mirp[rp0,rnd,grey]  vheight_shoot 29
alignrp 17
mdrp[min,rnd,grey]  56
mdrp[rp0,rnd,grey]  4
f_deltap    4 10+4   4 11+4   4 14+8   4 17-8    56 20+8   4 25-8   4 37-8  
mdrp[min,rnd,grey]  50
ip  23
ip  35
srp0    17
mdrp[rp0,rnd,grey]  11
f_deltap    11 17+8  11 18+8  11 19+8
mirp[min,rnd,grey]  headstem 38
mirp[rnd,grey]  headstem_plus_hole 44
IUP[y]
""",

    #lo_chula
    "uni0E2C": """
f_deltap    61 9+8   61 17+8   61 32+8  
srp0    60
mirp[rp0,rnd,white] gap_88 10
mirp[min,rnd,grey]  headstem 45
mirp[rnd,grey]  headstem_plus_hole 39
mdrp[rp0,rnd,grey]  4
mirp[min,rnd,grey]  hstem 15
shp[rp2]    3
#
srp0    61
mirp[rp0,rnd,white] gap_186 35
mdrp[grey]  31
mirp[min,rnd,grey]  hstem   19
shp[rp2]    1
srp1    15
sloop   3
ip  17 18 2
mdrp[rp0,rnd,grey]  23
mirp[min,rnd,grey]  headstem 57
mirp[rnd,grey]  headstem_plus_hole 51
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   1
alignrp     3
mirp[min,rnd,grey]  vstem_236 19
shp[rp2]    16
mirp[rp0,rnd,grey]  vheight_shoot 13
mdrp[min,rnd,grey]  26
mdrp[rp0,rnd,grey]  7
f_deltap    7 17+8  7 18+8  7 19+8
mirp[min,rnd,grey]  headstem 36
mirp[rnd,grey]  headstem_plus_hole 42
srp0    26
mdrp[rp0,rnd,grey]  20
ip  30
ip  31
srp1    19
ip  18
ip  2
mirp[min,rnd,grey]  headstem 48
mirp[rnd,grey]  headstem_plus_hole 54
IUP[y]
""",

    #o_ang
    "uni0E2D": """
f_deltap    42 10+8   42 11+8   42 13+8   42 15-8   42 18-8   42 19+8   42 20+8   42 22+8   42 27-8   42 32+8   42 33+8   
srp0    41
mirp[rp0,rnd,white] gap_113 1
mdrp[grey]  20
mirp[rp0,min,rnd,grey]  hstem   12
mdrp[rp0,rnd,grey]  7
mirp[min,rnd,grey]  headstem   32
mirp[rnd,grey]  headstem_plus_hole  38
#
srp0    42
mirp[rp0,rnd,white] gap_162 28
mirp[min,rnd,grey]  hstem   14
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   0
mirp[min,rnd,grey]  vstem_236   14
mirp[rp0,rnd,grey]  vheight_shoot  25
mdrp[grey]  22
mirp[rp0,min,rnd,grey]  vstem_236   18
f_deltap    18 16+4  18 17+2  18 18+2  18 19+2  18 23+4  18 24+4  18 25+4  18 31+4
mdrp[rp0,grey]  21
mdrp[rp0,rnd,white]  4
mdap[rnd]   4
f_deltap    4 9-4   4 10+4   4 16-8   4 29-8   4 38-8
mdrp[rp0,rnd,grey]  10
f_deltap    10 17+8   10 18+8   10 19+8   
mirp[min,rnd,grey]  headstem    29
mirp[rnd,grey]  headstem_plus_hole 35
IUP[y]
""",

    #ho_nokhuk
    "uni0E2E": """
f_deltap    54 11+8   54 16-8   54 20+8   54 32+8
srp0    53
mirp[rp0,rnd,white] gap_113 1
mdrp[grey]  22
mirp[rp0,min,rnd,grey]  hstem   12
mdrp[rp0,rnd,grey]  7
mirp[min,rnd,grey]  headstem   36
mirp[rnd,grey]  headstem_plus_hole  42
srp0    22
mdrp[min,rnd,grey]  51
mdap[rnd]   51
#
srp0    54
mirp[rp0,rnd,white] gap_162 32
srp2    22
sloop   4
ip  27 28 29 30
mirp[min,rnd,grey]  hstem   14
srp1    51
ip  47
ip  17
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   0
mirp[min,rnd,grey]  vstem_236   14
mirp[rp0,rnd,grey]  vheight_shoot  25
ip  4
mdrp[min,rnd,grey]  49
srp1    25
srp2    4
sloop   4
ip  27 28 29 30
mdap[rnd]   4
f_deltap    4 12-8
srp2    49
ip  45
ip  47
srp2    45
ip  19
ip  17
mdrp[rp0,rnd,grey]  10
f_deltap    10 9+8   10 10+8   10 17+8   10 18+8   10 19+8   10 22+8   10 23+8  10 24+8   10 31+8   
mirp[min,rnd,grey]  headstem    33
mirp[rnd,grey]  headstem_plus_hole 39
IUP[y]
""",

    #paiyan
    "uni0E2F": """
f_deltap    37 10+8   
srp0    36
mdrp[rp0,rnd,grey]  14
mirp[min,rnd,grey]  headstem 27
mirp[rnd,grey]  headstem_plus_hole 33
mdrp[grey]  8
mdrp[min,rnd,grey]  17
#
srp0    37
mirp[rp0,rnd,white] gap_172 23
mirp[min,rnd,grey]  hstem   22
shp[rp2]    1
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   1
mirp[rp0,rnd,grey]  vheight_shoot 11
alignrp 22
mirp[min,rnd,grey]  headstem 30
mirp[rp0,rnd,grey]  headdia 17
mirp[min,rnd,grey]  headstem 24
srp0    11
mdrp[rp0,rnd,grey]  5
mirp[min,rnd,grey]  w_195 19
mdrp[grey]  2
IUP[y]
""",

    #sara_a
    "uni0E30": """
srp0    58
mirp[rp0,rnd,white]  gap_88 3
alignrp 32
mdrp[min,rnd,grey]  26
shp[rp2]    55
mdrp[rp0,rnd,grey]  9
alignrp 38
mirp[min,rnd,grey]  headstem 20
shp[rp2]    49
mdrp[rp0,grey]  11
alignrp 40
#
srp0    59
mirp[rp0,rnd,white]  gap_172 15
alignrp 44
mdrp[grey]  14
shp[rp2]    43
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   58
mdrp[rp0,rnd,grey]  6
mirp[min,rnd,grey]  headstem 23
mirp[rnd,grey]  headstem_plus_hole 17
mdrp[rp0,grey]  0
ip  14
ip  15
mdrp[grey]  10
#
mdap[rnd]   58
mirp[rp0,rnd,grey]  vheight 35
mirp[min,rnd,grey]  headstem 52
mirp[rnd,grey]  headstem_plus_hole 46
mdrp[rp0,grey]  29
ip  43
ip  44
mdrp[grey]  40
IUP[y]
""",

    #sara_maihanakat
    "uni0E31": """
mdap[rnd]   9
mdrp[rnd,grey]  15
mirp[min,rnd,grey]  headstem 20
mirp[rp0,rnd,grey]  headdia 3
mirp[min,rnd,grey]  headstem 26
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   17
f_deltap   17 12+8  17 16+8  17 18+8  17 38+8  
mdrp[grey]  11
mdrp[grey]  0
mirp[rp0,rnd,grey]  headstem_plus_hole 6
f_deltap    6 12-4   6 18+4   6 19+4   6 23+4 6 24+4
ip  14
ip  15
mirp[min,rnd,grey]  headstem 23
IUP[y]
""",

    #sara_aa
    "uni0E32": """
srp0    16
mirp[white]  gap_88 8
#
srp0    17
mirp[rp0,rnd,white] gap_162 15
mirp[min,rnd,grey]  hstem 1
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   1
mirp[rp0,rnd,grey]  vheight_shoot 12
mdrp[grey]  9
mirp[min,rnd,grey]  vstem_236   5
f_deltap    5 16+4  5 17+2  5 18+2  5 19+2  5 23+4  5 24+4  5 25+4  5 31+4
mdrp[grey]  8
IUP[y]
""",

    #sara_am
    #uni0E33: use sara_aa with nikahit
    
    #sara_i
    "uni0E34": """
mdap[rnd]   0
mirp[min,rnd,grey]  vstem_258 11
mirp[rp0,rnd,grey]  w_926 3
mirp[min,rnd,grey]  vstem_236 17
IUP[x]
SVTCA[y-axis]
mdap[rnd]   3
f_deltap   3 12+8  3 16+8  3 18+8  3 38+8  
#mirp[rp0,min,rnd,grey]  w_154 17
mdrp[rp0,rnd,white]  14
ip  17
mirp[min,rnd,grey]  w_154 7
IUP[y]
""",

    #sara_ii
    "uni0E35": """
mdap[rnd]   0
mirp[min,rnd,grey]  w_195 10
mirp[min,rnd,grey]  vstem_258 12
mirp[rp0,rnd,grey]  w_926 3
mirp[min,rnd,grey]  vstem_236 18
IUP[x]
SVTCA[y-axis]
mdap[rnd]   3
f_deltap   3 12+8  3 16+8  3 18+8  3 38+8  
mdrp[rp0,rnd,white]  15
ip  18
mirp[rp0,min,rnd,grey]  w_154 7
mdrp[min,rnd,grey]  10
IUP[y]
""",

    #sara_ue
    "uni0E36": """
mdap[rnd]   0
mirp[min,rnd,grey]  vstem_258 21
mirp[rp0,rnd,grey]  w_926 3
mirp[min,rnd,grey]  vstem_236 27
srp0    0
mdrp[rp0,rnd,grey]  15
f_deltap    15 12+4   15 13+4
mirp[min,rnd,grey]  headstem_tiny   33
mirp[rp0,rnd,grey]  headdia_tiny   9
f_deltap    9 14-8   9 15-8   
ip  18
mirp[min,rnd,grey]  headstem_tiny   39
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   3
f_deltap   3 12+8  3 16+8  3 18+8  3 38+8  
mdrp[rp0,rnd,white]  24
ip  27
mirp[rp0,min,rnd,grey]  w_154 7
mdrp[rp0,min,rnd,grey]  12
mirp[min,rnd,grey]  headstem_tiny   36
mirp[rnd,grey]  headstem_tiny_plus_hole 30
IUP[y]
""",

    #sara_uee
    "uni0E37": """
mdap[rnd]   0
mirp[rp0,min,rnd,grey]  w_195 15
mdrp[rp0,min,rnd,white] 12
mirp[min,rnd,grey]  w_195 10
srp0    0
mirp[min,rnd,grey]  vstem_258 17
mirp[rp0,rnd,grey]  w_926 3
mirp[min,rnd,grey]  vstem_236 23
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   3
f_deltap   3 12+8  3 16+8  3 18+8  3 38+8
mdrp[rp0,rnd,white]  20
ip  23
mirp[rp0,min,rnd,grey]  w_154 7
mdrp[min,rnd,grey]  10
shp[rp2]    15
IUP[y]
""",

    #sara_u
    "uni0E38": """
mdap[rnd]   1
mirp[rp0,rnd,grey]  vstem_236 13
mdrp[rp0,rnd,grey]  7
mirp[min,rnd,grey]  headstem_tiny 23
mirp[rnd,grey]  headstem_tiny_plus_hole 17
IUP[x]
SVTCA[y-axis]
mdap[rnd]   26
mdrp[rp0,min,rnd,white]  10
mdrp[rp0,rnd,grey]  4
mirp[min,rnd,grey]  headstem_tiny 14
mirp[rnd,grey]  headstem_tiny_plus_hole 20
mdrp[min,rnd,grey]  0
IUP[y]
""",

    #sara_uu
    "uni0E39": """
mdap[rnd]   0
mirp[rp0,rnd,grey]  w_195 16
mdrp[rp0,rnd,white] 14
mirp[rp0,rnd,grey]  w_195 1
srp0    14
mdrp[rp0,rnd,grey]  7
mirp[min,rnd,grey]  headstem_tiny 27
mirp[rnd,grey]  headstem_tiny_plus_hole 21
IUP[x]
SVTCA[y-axis]
mdap[rnd]   30
mdrp[rp0,min,rnd,white] 10
mdrp[rnd,grey]  16
mdrp[rp0,rnd,grey]  4
mdrp[rnd,grey]  14
mdrp[min,rnd,grey]  1
mirp[min,rnd,grey]  headstem_tiny 18
mirp[rnd,grey]  headstem_tiny_plus_hole 24
IUP[y]
""",

    #pinthu
    "uni0E3A": """
mdap[rnd]   9
mdrp[rp0,min,rnd,grey]  3
IUP[x]
SVTCA[y-axis]
mdap[rnd]   12
mdrp[rp0,min,rnd,white]  6
mdrp[rp0,min,rnd,grey]  0
IUP[y]
""",

    #thai_baht
    "uni0E3F": """
srp0    43
mirp[rp0,rnd,white] gap_186  3
mdrp[rp0,rnd,grey]  21
sloop   3
alignrp  5 32 1
mdrp[min,rnd,grey]  23
shp[rp2]    34
mdrp[rp0,min,rnd,grey]  31
sloop   3
alignrp 7 42 20
mdrp[rp0,rnd,grey]  17
mdrp[min,rnd,grey]  28
mirp[rnd,grey]  gap_162 44
mdrp[rp0,rnd,grey]  11
mdrp[min,rnd,grey]  39
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   20
alignrp 3
mdrp[min,rnd,grey]  1
mdrp[min,rnd,grey]  25
shp[rp2]    24
mdrp[rp0,rnd,grey]  4
alignrp     8
mdrp[min,rnd,grey]  6
mdrp[min,rnd,grey]  42
shp[rp2]    34
mdrp[rp0,rnd,grey]  31
alignrp     23
mdrp[min,rnd,grey]  36
ip  14
IUP[y]
""",

    #sara_ae
    "uni0E40": """
srp0    26
mirp[rp0,rnd,white] gap_88 10
mirp[min,rnd,grey]  headstem 16
mirp[rnd,grey]  headstem_plus_hole 22
mdrp[rp0,rnd,grey]  4
mirp[min,rnd,grey]  hstem 2
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   25
mirp[rnd,grey]  vheight 4
mirp[rp0,rnd,grey]  vheight_lo 0
mdrp[rp0,rnd,grey]  7
f_deltap    7 17-8  7 18-8  7 19-8
mirp[min,rnd,grey]  headstem 19
mirp[rnd,grey]  headstem_plus_hole 13
IUP[y]
""",

    #sara_ae
    #use sara_a reference: uni0E40

    #sara_o
    "uni0E42": """
srp0    52
mdrp[rp0,rnd,grey]  28
mdrp[grey]  6
#
srp0    53
mirp[rp0,rnd,grey]  gap_88 37
alignrp 18
mirp[min,rnd,grey]  headstem 43
mirp[rnd,grey]  headstem_plus_hole 49
mdrp[rp0,rnd,grey]  31
mirp[min,rnd,grey]  hstem 2
IUP[x]
SVTCA[y-axis]
mdap[rnd]   52
mirp[rnd,grey]  vheight_lo 0
mirp[rp0,rnd,grey]  vheight_o 10
mdrp[grey]  7
mirp[min,rnd,grey]  vstem_236 25
f_deltap    25 16+4  25 17+2  25 18+2  25 19+2  25 23+4  25 24+4  25 25+4  25 31+4
mdrp[grey]  6
ip  28
srp0    0
mdrp[rp0,rnd,grey]  34
f_deltap    34 17-8  34 18-8  34 19-8
mirp[min,rnd,grey]  headstem   46
mirp[rnd,grey]  headstem_plus_hole   40
IUP[y]
""",

    #sara_i_moun
    "uni0E43": """
srp0    66
mdrp[rp0,rnd,grey]  16
mdrp[grey]  13
mirp[min,rnd,grey] headstem 57
mirp[rp0,rnd,grey] headstem_plus_hole 63
mdrp[grey]  22
srp0    16
mdrp[rp0,min,rnd,white] 8
mdrp[grey]  28
#
srp0    67
mirp[rp0,rnd,white] gap_88 39
mirp[min,rnd,grey]  headstem 45
mirp[rnd,grey]  headstem_plus_hole 51
mdrp[rp0,rnd,grey]  33
mirp[min,rnd,grey]  hstem 2
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   66
mirp[rnd,grey]  vheight_lo 0
mirp[rp0,rnd,grey]  vheight_o 25
mirp[rp0,min,rnd,grey]  w_154 11
mdrp[rp0,rnd,white]  13
mirp[min,rnd,grey]  headstem 60
mirp[rp0,rnd,grey]  headdia 19
mirp[min,rnd,grey]  headstem 54
srp0    0
mdrp[rp0,rnd,grey]  36
f_deltap    36 17-8  36 18-8  36 19-8
mirp[min,rnd,grey]  headstem 48
mirp[rnd,grey]  headstem_plus_hole 42
IUP[y]
""",

    #sara_i_mlai
    "uni0E44": """
f_deltap    50 10-8   50 13+8   
srp0    49
mdrp[rp0,rnd,grey]  9
alignrp 19
sloop   5
ip  14 15 12 17 11
mirp[min,rnd,grey]  w_291 22
#
srp0    50
mdrp[rp0,rnd,white]  34
mirp[min,rnd,grey]  headstem 40
mirp[rnd,grey]  headstem_plus_hole 46
mdrp[rp0,rnd,grey]  28
mirp[min,rnd,grey]  hstem 2
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   49
mirp[rnd,grey]  vheight_lo 0
mirp[rp0,rnd,grey]  vheight_o 20
mdrp[grey]  15
mirp[min,rnd,grey]  w_195 9
mdrp[rp0,rnd,grey]  11
mirp[min,rnd,grey]  w_139   17
srp0    0
mdrp[rp0,rnd,grey]  31
f_deltap    31 17-8  31 18-8  31 19-8
mirp[min,rnd,grey]  headstem 43
mirp[rnd,grey]  headstem_plus_hole 37
IUP[y]
""",

    #lakkhangyao
    "uni0E45": """
srp0    16
mdrp[grey]  8
#
srp0    17
mirp[rp0,rnd,white] gap_195 15
mirp[min,rnd,grey]  hstem 1
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   16
mirp[rnd,grey]  vheight_lu 1
mirp[rp0,rnd,grey]  vheight_shoot 12
mdrp[grey]  9
mirp[min,rnd,grey]  vstem_236 5
f_deltap    5 16+4  5 17+2  5 18+2  5 19+2  5 23+4  5 24+4  5 25+4  5 31+4
mdrp[grey]  8
IUP[y]
""",

    #maiyamok
    "uni0E46": """
srp0    39
mdrp[rp0,rnd,grey]  12
mdrp[grey]  9
mirp[min,rnd,grey]  headstem  30
mirp[rp0,rnd,grey]  headstem_plus_hole  36
mdrp[grey]  18
#
srp0    40
mirp[rp0,rnd,white] gap_172 26
mirp[min,rnd,grey]  hstem 1
srp1    9
sloop   7
ip  21 22 23 4 5 6 7
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   39
mirp[rnd,grey]  vheight_lu 1
mirp[rp0,rnd,grey]  vheight_shoot 21
alignrp 23
mirp[min,rnd,grey]  w_195 7
shp[rp2]    4
mdrp[rp0,min,rnd,grey]  22
mirp[rp0,min,rnd,grey]  w_154 5
mdrp[rp0,rnd,white]  9
mirp[min,rnd,grey]  headstem  33
mirp[rp0,rnd,grey]  headdia 15
mirp[min,rnd,grey]  headstem 27
IUP[y]
""",

    #maitaikhu
    "uni0E47": """
mdap[rnd]  11
mirp[min,rnd,grey]  w_195 26
#
mdap[rnd]  42
mdrp[grey]  19
mirp[min,rnd,grey]  headstem_sara 48
mirp[rp0,rnd,grey]  headdia_sara 35
mirp[min,rnd,grey]  headstem_sara 54
srp2    26
ip  8
ip  28
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   0
f_deltap   0 9+8  0 12+8  0 14+8  0 16+8  0 18+8  0 38+8  
alignrp 8
mdrp[grey]  35
shp[rp2]    28
mirp[min,rnd,grey]  headstem_sara 45
shp[rp2]    5
mirp[rp0,rnd,grey]  headdia_sara 39
mirp[min,rnd,grey]  headstem_sara 51
ip  31
f_deltap    39 9-8
mdrp[rp0,min,rnd,white]  22
f_deltap    22 9-6 22 10-6 22 11-6 22 12-6  22 13-6
mdrp[grey]  19
mirp[rp0,min,rnd,grey]  sarastem 15
mdrp[grey]  18
IUP[y]
""",

    #maiek
    "uni0E48": """
mdap[rnd]   0
mdrp[grey]  1
IUP[x]
SVTCA[y-axis]
MDAP[rnd]   0
f_deltap   0 9+8   0 12+8  0 14+8  0 16+8  0 18+8  0 38+8
f_deltap   0 9+8   0 10+8   0 11+8   0 12+8  0 13+8   0 20+8  0 21+8  0 22+8  0 29+8  0 30+8
alignrp 1
mdrp[grey]  3
shp[rp2]    2
""",

    #maiek
    "uni0E48.low": """
mdap[rnd]   0
mirp[min,rnd,grey]  vstem_236 2
IUP[x]
SVTCA[y-axis]
MDAP[rnd]   0
f_deltap   0 9+8   0 12+8  0 14+8  0 16+8  0 18+8  0 38+8  
mirp[min,rnd,grey]  w_385 2
IUP[y]
""",

    #maitho
    "uni0E49": """
mdap[rnd]   14
mdrp[rnd,grey]  32
mdrp[grey]  20
IUP[x]
SVTCA[y-axis]
MDAP[rnd]   0
f_deltap   0 9+8   0 12+8  0 14+8  0 16+8  0 18+8  0 38+8
f_deltap   0 9+8   0 10+8   0 11+8   0 12+8  0 13+8   0 20+8  0 21+8  0 22+8  0 29+8  0 30+8
mdrp[rnd,grey]  23
mdrp[rnd,grey]  11
ip  19
ip  20
IUP[y]
""",

    #maitho
    "uni0E49.low": """
MDAP[rnd]   20
mdrp[rp0,rnd,grey]  26
sloop   3
ip  19 14 16
mdrp[rp0,rnd,grey]  8
sloop   3
ip  5 32 1
IUP[x]
SVTCA[y-axis]
MDAP[rnd]   0
f_deltap   0 9+8   0 12+8  0 14+8  0 16+8  0 18+8  0 38+8  
mirp[min,rnd,grey]  sarastem 2
alignrp 16
mdrp[rp0,rnd,grey]  11
ip  19
ip  20
mirp[min,rnd,grey]  headstem_sara 29
mirp[rp0,rnd,grey]  headdia_sara 5
mirp[min,rnd,grey]  headstem_sara 23
IUP[y]
""",

    #maitri
    "uni0E4A": """
mdap[rnd]   26
mdrp[grey]  32
mdrp[rnd,grey]  12
mdrp[rnd,grey]  44
IUP[x]
SVTCA[y-axis]
MDAP[rnd]   0
f_deltap   0 9+8   0 12+8  0 14+8  0 16+8  0 18+8  0 38+8
f_deltap   0 9+8   0 10+8   0 11+8   0 12+8  0 13+8   0 20+8  0 21+8  0 22+8  0 29+8  0 30+8
alignrp 15
mdrp[rnd,grey]  41
mdrp[rnd,grey]  21
alignrp 23
ip  31
IUP[y]
""",

    #maitri
    "uni0E4A.low": """
mdap[rnd]   26
mdrp[grey]  32
ip  31
mirp[min,rnd,grey]  w_154 3
mdrp[rp0,rnd,grey]  18
mdrp[rp0,rnd,grey]  12
mirp[min,rnd,grey]  headstem_sara 38
mirp[rnd,grey]  headstem_sara_plus_hole 44
IUP[x]
SVTCA[y-axis]
MDAP[rnd]   0
f_deltap   0 9+8   0 12+8  0 14+8  0 16+8  0 18+8  0 38+8  
alignrp 15
mdrp[rp0,rnd,grey]  21
alignrp 23
sloop
ip  7 22 6 5 1 28 31 32
srp0    15
mirp[min,rnd,grey]  headstem_sara 35
mirp[rp0,rnd,grey]  headdia_sara 9
mirp[min,rnd,grey]  headstem_sara 41
IUP[y]
""",

    #maichattawa
    "uni0E4B": """
mdap[rnd]   0
IUP[x]
SVTCA[y-axis]
MDAP[rnd]   11
f_deltap   11 9+8   11 12+8  11 14+8  11 16+8  11 18+8  11 38+8
f_deltap   11 9+8   11 10+8   11 11+8   11 12+8  11 13+8   11 20+8  11 21+8  11 22+8  11 29+8  11 30+8
IUP[y]
""",

    #maichattawa
    "uni0E4B.low": """
mdap[rnd]  0
alignrp    7
mdrp[grey]  10
mirp[rp0,rnd,grey]  w_154 2
alignrp    6
mdrp[grey]  3
IUP[x]
SVTCA[y-axis]
MDAP[rnd]   11
f_deltap   11 9+8   11 12+8  11 14+8  11 16+8  11 18+8  11 38+8  
alignrp     3
mdrp[grey]   0
mirp[rp0,rnd,grey]  w_154 8
alignrp 4
mdrp[grey]   7
IUP[y]
""",

    #thanthakhat
    "uni0E4C": """
mdap[rnd]   17
mdrp[grey]  29
IUP[x]
SVTCA[y-axis]
MDAP[rnd]   13
f_deltap   13 9+8   13 12+8  13 14+8  13 16+8  13 18+8  13 38+8
f_deltap   13 9+8   13 10+8   13 11+8   13 12+8  13 13+8   13 20+8  13 21+8  13 22+8  13 29+8  13 30+8
mdrp[grey]  20
IUP[y]
""",

    #thanthakhat
    "uni0E4C.low": """
srp0    10
mdrp[rp0,rnd,grey]  17
mirp[min,rnd,grey]  headstem_tiny 23
mirp[rp0,rnd,grey]  headdia_tiny 3
mirp[min,rnd,grey]  headstem_tiny 29
IUP[x]
SVTCA[y-axis]
MDAP[rnd]   0
f_deltap   0 9+8   0 12+8  0 14+8  0 16+8  0 18+8  0 38+8  
mirp[min,rnd,grey]  headstem_tiny 20
mirp[rnd,grey]  headstem_tiny_plus_hole 26
mdrp[rp0,rnd,grey]  13
mdrp[grey]  9
IUP[y]
""",

    #nikhahit
    "uni0E4D": """
MDAP[rnd]   9
mirp[min,rnd,grey]  headstem 15
mirp[rp0,rnd,grey]  headdia 3
mirp[min,rnd,grey]  headstem 21
IUP[x]
SVTCA[y-axis]
MDAP[rnd]   0
f_deltap   0 9+8  0 12+8  0 14+8  0 16+8  0 18+8  0 38+8  
mirp[min,rnd,grey]  headstem 12
mirp[rp0,rnd,grey]  headdia 6
mirp[min,rnd,grey]  headstem 18
IUP[y]
""",

    #nikhahit
    "uni0E4D.high": """
MDAP[rnd]   0
mdrp[rp0,rnd,grey]  9
mdrp[min,rnd,grey]  15
mdrp[rp0,rnd,grey]  3
mdrp[min,rnd,grey]  21
IUP[x]
SVTCA[y-axis]
MDAP[rnd]   0
mdrp[min,rnd,grey]  12
mdrp[rp0,rnd,grey]  6
mdrp[min,rnd,grey]  18
IUP[y]
""",

    #yamakkan
    "uni0E4E": """
mdap[rnd]   15
mdrp[rp0,rnd,grey]  4
ip  26
ip  0
mdrp[min,rnd,grey]  30
mdrp[rp0,rnd,grey]  10
mdrp[min,rnd,grey]  21
IUP[x]
SVTCA[y-axis]
MDAP[rnd]   0
f_deltap   0 9+8  0 12+8  0 14+8  0 16+8  0 18+8  0 38+8  
mdrp[min,rnd,grey]  34
mdrp[rp0,rnd,grey]  25
mdrp[min,rnd,grey]  26
ip  7
mdrp[rp0,rnd,grey]  13
mdrp[min,rnd,grey]  18
ip  15
ip  16
IUP[y]
""",

    #fongman
    "uni0E4F": """
srp0        56
mirp[rp0,rnd,grey]  gap_162 5
mirp[rp0,min,rnd,grey]  w_195 29
mdrp[min,rnd,grey]  35
#
srp0    5
mdrp[rp0,rnd,grey]  15
mirp[rnd,grey]  gap_162 57
mirp[rp0,min,rnd,grey]  w_195 23
mdrp[min,rnd,grey]  41
#
srp1    35
ip  53
ip  47
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   0
mirp[rp0,min,rnd,grey]  w_195 20
mdrp[min,rnd,grey]  32
#
srp0    0
mdrp[rp0,rnd,grey]  10
mirp[rp0,min,rnd,grey]  w_195 26
mdrp[min,rnd,grey]  38
#
srp1    32
ip  44
ip  50
IUP[y]
""",

    #thaidigit_zero
    "uni0E50": """
f_deltap    29 9+8   
SRP0    28
mirp[rp0,rnd,white] gap_113 4
mirp[min,rnd,grey]  w_307 25
#
srp0    29
mirp[rp0,rnd,white]  gap_113 12
mirp[min,rnd,grey]  w_307 19
IUP[x]
SVTCA[y-axis]
MDAP[rnd]   28
mirp[rnd,grey]  vheight_lo  0
mirp[rp0,rnd,grey]  vheight_num 8
mirp[min,rnd,grey]  vstem_236 22
srp0    0
mirp[min,rnd,grey]  vstem_236 16
IUP[y]
""",

    #thaidigit_one
    "uni0E51": """
f_deltap    49 11+8   49 12+8  49 13+8  49 14+8 
SRP0    48
mirp[rp0,rnd,white] gap_113 3
mirp[rp0,min,rnd,grey]  w_307 22
mdrp[rp0,rnd,white]  27
mdrp[grey]  25
mirp[min,rnd,grey]  headstem 45
mirp[rnd,grey]  headstem_plus_hole 39
#
srp0    49
mirp[rp0,rnd,grey]  gap_113 9
mdrp[grey]  12
mirp[rp0,min,rnd,grey]  w_307 16
mdrp[grey]  11
srp2    39
ip  33
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   13
mdrp[grey]  12
mdrp[grey] 0
mirp[rp0,rnd,grey]  vheight_num 6
mirp[min,rnd,grey]  vstem_236 19
mdrp[rp0,rnd,grey]  30
mirp[min,rnd,grey]  headstem 42
mirp[rnd,grey]  headstem_plus_hole 36
IUP[y]
""",

    #thaidigit_two
    "uni0E52": """
f_deltap    56 9+8   56 12+8   
SRP0    55
mirp[rp0,rnd,white] gap_143 4
mdrp[grey]  7
mdrp[grey]  11
mdrp[rp0,rnd,grey]  26
mdrp[grey]  23
mirp[min,rnd,grey]  headstem 46
mirp[rnd,grey]  headstem_plus_hole 52
mdrp[grey]  32
#
srp0    56
mirp[rp0,rnd,white] gap_113 40
mirp[min,rnd,grey]  w_307 17
srp1    23
sloop 6
ip  35 36 37 19 20 21
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   0
mirp[min,rnd,grey]  vstem_236 14
mirp[rp0,rnd,grey]  vheight_num 35
alignrp 37
mdrp[grey]  8
mirp[min,rnd,grey]  w_195 21
shp[rp2]    19
mdrp[rp0,min,rnd,grey]  36
mirp[min,rnd,grey]  w_154 20
mdrp[rp0,rnd,white] 23
mirp[min,rnd,grey]  headstem 49
mirp[rp0,rnd,grey]  headdia 29
mirp[min,rnd,grey]  headstem 43
IUP[y]
""",

    #thaidigit_three
    "uni0E53": """
f_deltap    57 9+8   57 11+8   57 12+8   57 17+8   
SRP0    56
mirp[rp0,rnd,white] gap_113 31
mirp[rp0,min,rnd,grey]  w_307 17
mdrp[rp0,rnd,grey]  19
mirp[min,rnd,grey]  headstem 53
mirp[rp0,rnd,grey]  headdia 25
mirp[min,rnd,grey]  headstem 47
#
srp0    57
mirp[rp0,rnd,white] gap_113 41
mirp[min,rnd,grey]  w_307 4
srp1    17
ip  11
#
mdap[rnd]  11
mirp[min,rnd,grey]  w_307 9
ip  36
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   1
mirp[rnd,grey]  vheight_lo 28
mirp[rp0,rnd,grey]  vheight_num 38
alignrp 34
mirp[min,rnd,grey]  vstem_236 7
shp[rp2]    14
srp0    28
mdrp[rnd,grey]  19
mirp[min,rnd,grey]  headstem 44
mirp[rp0,rnd,grey]  headdia 22
mirp[min,rnd,grey]  headstem 50
srp2    14
ip  11
IUP[y]
""",

    #thaidigit_four
    "uni0E54": """
SRP0    55
mirp[rp0,rnd,white] gap_113 8
mirp[min,rnd,grey]  w_307 23
mdrp[rp0,rnd,grey]  36
mirp[min,rnd,grey]  headstem 46
mirp[rnd,grey]  headstem_plus_hole 52
mdrp[grey]  30
sloop 3
ip 28 39 3
#
srp0    56
mirp[rp0,rnd,grey]  gap_172 42
mdrp[grey]  16
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   55
mirp[rp0,rnd,grey]  vheight_lo 0
alignrp 5
mirp[min,rnd,grey]  vstem_236 42
shp[rp2]    26
mirp[rp0,rnd,grey]  vheight_num 12
mirp[min,rnd,grey]  vstem_236 19
srp1    42
sloop   3
ip  33 49 43
mdrp[rp0,rnd,grey]  15
mirp[min,rnd,grey]  vstem_236 16
IUP[y]
""",

    #thaidigit_five
    "uni0E55": """
SRP0    76
mirp[rp0,rnd,white]  gap_113 8
mirp[min,rnd,grey]  w_307 32
mdrp[rp0,rnd,grey]  45
mirp[min,rnd,grey]  headstem 55
mirp[rnd,grey]  headstem_plus_hole 61
mdrp[grey]  39
sloop 3
ip 37 48 3
srp0    8
mdrp[rp0,rnd,grey]  13
mirp[min,rnd,grey]  headstem 73
mirp[rp0,rnd,grey]  headdia 19
ip  11
ip  21
mirp[min,rnd,grey]  headstem 67
#
srp0    77
mirp[rp0,rnd,white]  gap_172 51
mdrp[grey]  25
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   76
mirp[rp0,rnd,grey]  vheight_lo 0
alignrp 5
mirp[min,rnd,grey]  vstem_236 51
shp[rp2]    35
mirp[rp0,rnd,grey]  vheight_num 21
mirp[min,rnd,grey]  vstem_236 28
srp1    51
sloop   3
ip  42 58 52
mdrp[rp0,rnd,grey]  24
mirp[min,rnd,grey]  vstem_236 25
srp0    21
mdrp[rp0,rnd,grey]  16
mirp[min,rnd,grey]  headstem 70
mirp[rnd,grey]  headstem_plus_hole 64
IUP[y]
""",

    #thaidigit_six
    "uni0E56": """
f_deltap    49 11+8   
SRP0    48
mirp[rp0,rnd,white] gap_236 3
alignrp 20
ip  23
ip  24
mdrp[grey]  27
mirp[min,rnd,grey]  headstem 45
mirp[rp0,rnd,grey]  headdia 9
mirp[min,rnd,grey]  headstem 39
#
srp0    49
mirp[rp0,rnd,white]  gap_113 33
mirp[min,rnd,grey]  w_307 14
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   48
mirp[rnd,grey]  vheight_lo 0
mirp[min,rnd,grey]  vstem_236 11
mirp[rp0,rnd,grey]  vheight_num 30
ip  6
mdrp[grey]  27
mdrp[min,rnd,grey]  24
mirp[rp0,min,rnd,grey]  vstem_236 17
mdrp[grey]  20
mdap[rnd]   6
f_deltap    6 10-4   6 11-4   
mirp[min,rnd,grey]  headstem 42
mirp[rnd,grey]  headstem_plus_hole 36
IUP[y]
""",

    #thaidigit_seven
    "uni0E57": """
f_deltap    70 9+8   70 11+8   70 12+8   70 16-8   70 17+8   
SRP0    69
mirp[rp0,rnd,white] gap_113 31
mirp[min,rnd,grey]  w_307 17
mdrp[rp0,rnd,grey]  19
mirp[min,rnd,grey]  headstem 66
mirp[rp0,rnd,grey]  headdia 25
mirp[min,rnd,grey]  headstem 60
#
srp0    70
mirp[rp0,rnd,white] gap_113 54
mirp[min,rnd,grey]  w_307 47
mdrp[rp0,min,rnd,grey]  41
mirp[min,rnd,grey]  w_307 4
srp1    17
ip  11
mdap[rnd]  11
mirp[min,rnd,grey]  w_307 10
ip  36
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   0
mdrp[min,rnd,grey]  44
mirp[rnd,grey]  vheight_lo 28
mirp[rp0,rnd,grey]  vheight_num 38
alignrp 34
mirp[min,rnd,grey]  vstem_236 7
shp[rp2]    14
ip  36
mdrp[min,rnd,grey]  50
ip  51
srp0    28
mdrp[rnd,grey]  19
mirp[min,rnd,grey]  headstem 57
mirp[rp0,rnd,grey]  headdia 22
mirp[min,rnd,grey]  headstem 63
mdrp[grey]  19
srp2    14
ip  11
IUP[y]
""",

    #thaidigit_eight
    "uni0E58": """
f_deltap    54 11+8   
SRP0    53
mirp[rp0,rnd,white] gap_113 7
mirp[min,rnd,grey]  w_307 22
#
srp0    54
mirp[rp0,rnd,white]  gap_143 38
mdrp[grey]  15
mirp[min,rnd,grey]  headstem 44
mirp[rp0,rnd,grey]  headdia 32
mirp[min,rnd,grey]  headstem 50
srp2    22
sloop 5
ip 25 26 27 3 4
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   53
mirp[rp0,rnd,grey]  vheight_lo 4
alignrp     0
mirp[min,rnd,grey]  vstem_236 25
shp[rp2]    3
mirp[rp0,rnd,grey]  vheight_num 11
mirp[min,rnd,grey]  vstem_236 18
srp1    25
ip  26
ip  27
mdrp[rp0,rnd,grey]  14
mirp[min,rnd,grey] vstem_258 15
srp0    0
mdrp[rp0,rnd,grey]  35
mirp[min,rnd,grey]  headstem 47
mirp[rnd,grey]  headstem_plus_hole 41
IUP[y]
""",

    #thaidigit_nine
    "uni0E59": """
f_deltap    61 13+8   61 14+8   61 15+8   61 16+8   61 18+8   61 23+8   
SRP0    60
mirp[rp0,rnd,white] gap_113 21
mirp[min,rnd,grey]  w_307 7
mdrp[rp0,rnd,grey]  9
mirp[min,rnd,grey]  headstem 57
mirp[rp0,rnd,grey]  headdia 15
mirp[min,rnd,grey]  headstem 51
#
srp0    61
mirp[rp0,rnd,white]  gap_88 37
mdrp[grey]  36
mdrp[rp0,rnd,grey]  1
sloop 4
ip 27 33 40 45
mirp[min,rnd,grey]  w_307 0
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   1
mirp[rnd,grey]  vheight_lo 18
mirp[rp0,rnd,grey]  vheight_num 30
alignrp 24
mirp[min,rnd,grey]  vstem_236 43
shp[rp2]    4
sloop 4
ip  27 33 45 40
mdrp[rp0,rnd,grey]  36
ip  37
srp0    18
mdrp[rp0,rnd,grey]  12
mirp[min,rnd,grey]  headstem 54
mirp[rnd,grey]  headstem_plus_hole 48
IUP[y]
""",

#    #angkhankhu
    "uni0E5A": """
f_deltap    37 9+8   37 10+8   37 11+8   37 12+8   
srp0    40
mdrp[rp0,rnd,grey]  14
mirp[min,rnd,grey]  headstem 27
mirp[rnd,grey]  headstem_plus_hole 33
mdrp[grey]  8
mdrp[min,rnd,grey]  17
#
srp0    41
mirp[rp0,rnd,white] gap_172 39
mirp[rp0,rnd,grey]  hstem   37
mdrp[rp0,min,rnd,grey]  23
mirp[min,rnd,grey]  hstem   22
shp[rp2]    1
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   1
mirp[rp0,rnd,grey]  vheight_shoot 11
alignrp 22
mirp[min,rnd,grey]  headstem 30
mirp[rp0,rnd,grey]  headdia 17
mirp[min,rnd,grey]  headstem 24
srp0    11
mdrp[rp0,rnd,grey]  5
mirp[min,rnd,grey]  w_195 19
mdrp[grey]  2
IUP[y]
""",

#    #khomut
    "uni0E5B": """
SRP0    73
mirp[rp0,rnd,white]  gap_162 3
mirp[min,rnd,grey]  w_307 26
mdrp[rp0,rnd,grey]  15
mirp[min,rnd,grey]  headstem 70
mirp[rnd,grey]  headstem_plus_hole 64
mdrp[grey]  9
mdrp[rp0,rnd,grey]  34
sloop   6
ip  20 9 32 33 58 57
mdrp[rp0,rnd,grey]  39
sloop   4
ip  37 38 54 53
#
srp0    74
mirp[rp0,rnd,white]  gap_162 46
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   73
mirp[rp0,rnd,grey]  vheight_lo  0
mirp[min,rnd,grey]  vstem_236 29
mirp[rp0,rnd,grey]  vheight_shoot 6
mirp[min,rnd,grey]  vstem_236 23
srp1    29
sloop   10
ip  20 12 32 33 34 57 58 54 50 46
mdap[rnd]   12
mdrp[rp0,rnd,grey]  18
mirp[min,rnd,grey]  headstem 67
mirp[rnd,grey]  headstem_plus_hole 61
mdap[rnd]   32
alignrp 37
alignrp 42
mdap[rnd]   33
alignrp 38
alignrp 43
mdap[rnd]   34
alignrp 39
mdap[rnd]   57
alignrp 53
mdap[rnd]   46
mirp[min,rnd,grey]  vstem_236 47
IUP[y]
""",

#    #CHAR_NAME
#    "uni0EXX": """
#SRP0    0
#
#IUP[x]
#SVTCA[y-axis]
#MDAP[rnd]   0
#
#IUP[y]
#""",


}

if __name__=="__main__":
    if sys.argv[1] == "--all":
        #$0 --all = ENCODE ALL CHARS
        sfd_file = os.path.basename(sys.argv[0]).split('.',1)[0] + '.sfd'
        print "Encoding all character in %s" % (sfd_file)
        dfont.inst_encode_all( sfd_file, pseudo_code_dict, cvt_dict )
    else:
        #$0 uni0E01 > x.txt = PRINT INSTRUCTION CODE OF uni0E01 TO x.txt
        print '\n'.join(dfont.inst_encode( pseudo_code_dict[sys.argv[1]], cvt_dict ))
