#!/usr/bin/env python
#Usage: $0 uni0E01 > code.txt
#or:    $0 --all

import os
import sys
import dfont

# cvt value
#NEW VALUE ***
#    "headdia":          257,    #384
#    "headstem":         258,    #120
#    "w_896":            256,    #896    =ko_kai
cvt_dict = {
    "w_1001":           71,     #1001   =
    "w_340":            38,
    "w_102":            9,      #102 
    "w_60":             260,    #60
#
#LAO'S
    "w_115":            69,     #115    =gap1
    "w_186":            70,     #186    =gap2
    "w_184":            8,      #184    =hstem
    "w_195":            18,     #195    =hstem_curve
    "w_156":            135,    #156    =vstem
    "w_1147":           184,    #1147   =vheight_shoot
    "w_1556":           151,    #1556   =vheight_po
    "w_29":             140,    #29     =vheight_lo
    "w_1120":           188,    #1120   =vheight
    "w_426":            189,    #426    =vheight_lu
#
    "base":             10,     #0
    "hstem":            8,      #184
    "hstem_curve":      18,     #195    =big curve hstem
#
    "vstem":            169,    #143    =straight vstem
    "vstem_curve":      185,    #156    =curve vstem
    "vstem":            96,     #154 
    "vstem_small":      27,     #135 
    "vstem_tiny":       9,      #102 
    "vstem_thick":      130,    #266 
    "headstem":         258,    #116
    "headstem_plus_hole":   259, #268
    "headstem_small":   11,     #113    =kho
    "headstem_small_plus_hole":   130,     #266    =kho
    "headstem_tiny":    148,    #84
    "headstem_wan":     260,    #60
    "sarastem":         90,     #127
#
    "headdia":          257,    #384
    "headdia_small":    180,    #377    =kho
    "headdia_plus":     261,    #442 
    "headdia_full":     157,    #451 
    "headdia_tiny":     0,      #309
    "headhole":         107,    #152    
    "headneck_kho":     39,     #180    =kho
#
    "hnext_1":          111,    #469    =next spline of sho_sher
    "hnext_2":          68,     #479    =next spline of yo_ying
#
    "vheight":          188,    #1120   =normal height 
    "vheight_shoot":    184,    #1147   =overshoot height
    "vheight_hi":       49,     #1208   =ko 
    "vheight_hi_kho":   47,     #1204   =kho 
    "vheight_po":       151,    #1556   =po_pla, fo_fa
    "vheight_o":        179,    #1638   =sara_o, sara_i
    "vheight_lo":       140,    #29 
    "vheight_lu":       176,    #410    =lo_lu
    "vheight_below_do": 176,    #410
    "vheight_num":      209,    #905
    "vheight_sara1":    250,    #1262
#
    "gap_51":           32,     #51
    "gap_84":           148,    #84
    "gap_102":          9,
    "gap_113":          11,     #113    =front spacing of ko_kai
    "gap_127":          90,
    "gap_143":          84,
    "gap_152":          107,    #152
    "gap_164":          85,     #164
    "gap_186":          70,
    "gap_197":          194,    #197    =gap front/rear
    "gap_205":          100,    #205    =gap front/rear
    "gap_240":          24,    
    "gap_315":          207,
    "gap_340":          38,
    "gap_377":          180,
#special
    "special_1":        230,    #45
    "special_2":        88,     #20
}

#SKEL
#hd: headstem delta shift at 13-16 ppem
#f_deltap    x 12-4 x 13-4 x 14-1 x 15-1 x 16-1
#f_deltap    y1 14-1 y1 15-1 y1 16-1   y2 14+1 y2 15+1 y2 16+1
#f_deltap    x 12+4 x 13+4 x 14+1 x 15+1 x 16+1

#vd: vstem_curve delta shift at 18-25 ppem
#shpix   16 y
#f_deltap    y 17-4   y 18+4 y 19+3 y 20+2 y 21+2 y 22+2 y 23+2 y 24+2 y 25+2   y 26+1   y 29+6 y 30+6 y 31+6 y 32+6 y 33+6 y 34+6 y 35+6


######### PSUEDO-CODE ##########
pseudo_code_dict = {
    #ko_kai
    "uni0E01": """
f_deltap    27 10+8   27 14-8   27 20-8   27 26+8
srp0                26
mirp[rp0,rnd,grey]  gap_197 14
mirp[min,rnd,grey]  hstem  12
mdrp[rp0,grey]  18
mdrp[min,rnd,grey]  8
srp0            12
mdrp[rp0,grey]  10
mdrp[min,rnd,grey]  17
#
srp0    27
mirp[rp0,rnd,grey]  gap_164 25
mirp[min,rnd,grey]  hstem  1
IUP[x]
shpix   -16 8
shpix   16  17
#
SVTCA[y-axis]
mdap[rnd]           1
alignrp             13
mirp[rp0,rnd,grey]  vheight_shoot    22
mdrp[grey]  19
mirp[rp0,min,rnd,grey]  vstem_curve  5
#tcurve
shpix   16 5
#f_deltap    5 17-4   5 29+6 5 30+6 5 31+6 5 32+6 5 33+6 5 34+6 5 35+6
f_deltap    5 17-4   5 18+4 5 19+3 5 20+2 5 21+2 5 22+2 5 23+2 5 24+2 5 25+2   5 26+1   5 29+6 5 30+6 5 31+6 5 32+6 5 33+6 5 34+6 5 35+6
mdrp[grey]  18
ip  8
#srp1                0
#sloop               10
#ip      19 8 18 9 17 10 2 25 15 12
IUP[y]
""",

    #kho_khai
    "uni0E02":  """
f_deltap    54 9+8   54 11+8   54 15-8   54 17+8  54 18+8   54 22+8  54 36+8   54 37+8   
srp0                53
mdrp[rp0,rnd,grey]  15
f_deltap    15 12-8  15 13-8
mdrp[grey]  12
mirp[min,rnd,grey]  headstem 44
f_deltap    44 27+4 44 28+4 44 29+4
mirp[rp0,rnd,grey]  headstem_plus_hole 50
f_deltap    50 12+8  50 13+8  50 27+4 50 28+4 50 29+4
mdrp[grey]  21
srp0    15
mdrp[rp0,min,rnd,white]  7
mdrp[grey]  27
ip  10
mdrp[rp0,rnd,grey]  1
mdap[rnd]   1
f_deltap    1 9-8  1 10-8   1 13+8
mirp[min,rnd,grey]  hstem 32
#
srp0    54
mirp[rp0,rnd,grey]  gap_164 38
mirp[rp0,min,rnd,grey] hstem 36
shpix   8   7
IUP[x]
shpix   9   22
shpix   18  20
shpix   9   19
shpix   -9  17
shpix   -18 16
shpix   -18 14
shpix   -9  13
#
SVTCA[y-axis]
mdap[rnd]           1
mirp[rnd,grey]      vheight 38
mirp[min,rnd,grey]  vstem 34
mirp[rp0,rnd,grey]  vheight_shoot 24
mirp[rp0,grey]  headstem 10
mdrp[rp0,rnd,white] 12
mdap[rnd]   12
mdrp[rp0,rnd,grey]  18
f_deltap    18 9+8  18 10+8  18 11+8  18 14+8 18 15+8 18 16+8   18 27+8 18 28+8 18 29+8
mirp[min,rnd,grey]  headstem 41
f_deltap    41 27-4 41 28-4 41 29-4
mirp[rnd,grey]      headstem_plus_hole 47
f_deltap    47 27-4 47 28-4 47 29-4
srp2    1
ip  3
ip  31
shpix   16 47
IUP[y]
""",

    #kho_khuad
    "uni0E03": """
f_deltap    58 10+8   58 12+8    58 18+8 58 20+8   58 33+8
srp0    57
mdrp[rp0,rnd,grey]  18
mdrp[grey]  13
f_deltap    13 14-4 13 15-4 13 16-4
mirp[min,rnd,grey]  headstem 48
f_deltap    48 27+4 48 28+4 48 29+4
mirp[rnd,grey]  headstem_plus_hole 54
f_deltap    54 27+4 54 28+4 54 29+4
mdrp[grey]  24
srp0    18
mdrp[rp0,min,rnd,white]  7
mdrp[grey]  31
srp2    13
sloop   6
ip  27 28 29 9 10 11
mdrp[rp0,rnd,grey]  1
mdap[rnd]   1
f_deltap    1 15+8
mirp[min,rnd,grey]  hstem 36
#
srp0    58
mirp[rp0,rnd,grey]  gap_164 42
mirp[rp0,min,rnd,grey]  hstem 40
shpix   8   7
IUP[x]
shpix   9   25
shpix   18  23
shpix   9   22
shpix   -9  20
shpix   -18 19
shpix   -18 17
shpix   -9  16
f_deltap    16 15-4
#
SVTCA[y-axis]
mdap[rnd]  0
mirp[min,rnd,grey]  vstem   38
mirp[rnd,grey]  vheight 42
mirp[rp0,rnd,grey]  vheight_shoot   27
alignrp     29
mirp[grey]  sarastem 11
shp[rp2]    9
mdrp[rp0,min,rnd,grey] 28
mirp[rp0,grey] headstem 10
mdrp[rp0,rnd,white] 15
mdap[rnd]   15
f_deltap    15 9+8 15 10+8 15 11+8 15 12+8 15 13+8 15 14+8 15 15+8 15 16+8
mdrp[grey]  13
mirp[min,rnd,grey]  headstem 51
f_deltap    51 27+4 51 28+4 51 29+4
mirp[rp0,rnd,grey]  headdia 21
f_deltap    21 9+8 21 10+8 21 11+8   21 19+8   21 24+8 21 25+8 21 26+8   21 40+8 21 41+8
mirp[min,rnd,grey]  headstem 45
f_deltap    45 27-4 45 28-4 45 29-4
srp2    1
ip  3
ip  35
f_deltap    28 9-4 28 10-4 28 11-2 28 12-2   28 13-2 10 13+2   10 14+4   10 15+4   10 16+4
shpix   18  51
IUP[y]
""",

    #kho_kwai
    "uni0E04": """
f_deltap    52 9+8  52 10+8   52 15-8   52 20-8   52 26+8   52 32+8
srp0                51
mirp[rp0,rnd,grey]  gap_164 29
mdrp[rnd,grey]  32
shpix   -8  32
f_deltap    32 17+3 32 18+3 32 19+3 32 20+3 32 21+3 
mirp[rp0,min,rnd,grey]  hstem 28
mdrp[rnd,grey]  8
shpix   -8  8
ip  11
mdrp[rp0,rnd,grey]  20
f_deltap    20 11-8  20 12+8 20 13+8  20 14+8  20 15+8   20 26-8  20 27-8 20 29-8  20 33-8 20 38-8 
mirp[min,rnd,grey]  headstem 42
f_deltap    42 27+4 42 28+4 42 29+4
mirp[rp0,rnd,grey]  headstem_plus_hole 48
f_deltap    48 27+4 48 28+4 48 29+4
mdrp[grey]  14
mdrp[grey]  25
#
srp0    52
mirp[rp0,rnd,grey]  gap_164 38
mirp[min,rnd,grey]  hstem 1
f_deltap    20 12-8 20 13-8
IUP[x]
shpix   9   16
shpix   -9  18
shpix   -18 19
shpix   -18 21
shpix   -9  22
shpix   9   24
shpix   -9  48
#
SVTCA[y-axis]
MDAP[rnd]           0
ALIGNRP             28 
MIRP[rp0,rnd,grey]  vheight_shoot  35     
MIRP[min,rnd,grey]  vstem_curve  5      
shpix   16  5
f_deltap    5 17-4   5 18+4 5 19+3 5 20+2 5 21+2 5 22+2 5 23+2 5 24+2 5 25+2   5 26+1   5 29+6 5 30+6 5 31+6 5 32+6 5 33+6 5 34+6 5 35+6
MDRP[rp0,rnd,grey]  17         
f_deltap    17 9-8
MIRP[min,rnd,grey]  headstem  45    
f_deltap    45 27+4 45 28+4 45 29+4
MIRP[rp0,rnd,grey]  headdia  23    
f_deltap    23 19+8  23 24+8 23 25+8 23 26+8   23 40+8 23 41+8   23 44-8 23 45-8
mdrp[grey]  11
mdrp[grey]  25
f_deltap    11 14-5 26 14+3   11 15-5 26 15+3   11 16-5 26 16+3 27 16+8
MIRP[min,rnd,grey]  headstem  39    
f_deltap    39 27-4 39 28-4 39 29-4
shpix   -18 39
IUP[y]
""",

    #kho_kon
    "uni0E05": """
f_deltap    57 9+8  57 10+8   57 15-8   57 20-8   57 26+8   57 32+8
srp0                56
mirp[rp0,rnd,grey]  gap_164 32
mdrp[rnd,grey]  35
shpix   -8  35
f_deltap    35 17+3 35 18+3 35 19+3 35 20+3 35 21+3 
mirp[rp0,min,rnd,grey]  hstem 31
mdrp[rnd,grey]  11
shpix   -8  11
ip  14
mdrp[rp0,rnd,grey]  23
f_deltap    23 11-8  23 12+8 23 13+8  23 14+8  23 15+8   23 26-8   23 27-8 23 29-8  23 33-8 23 38-8 
mirp[min,rnd,grey]  headstem 47
f_deltap    47 27+4 47 28+4 47 29+4
mirp[rp0,rnd,grey]  headstem_plus_hole 53
f_deltap    53 27+4 53 28+4 53 29+4
mdrp[grey]  17
mdrp[grey]  28
#
srp0    57
mirp[rp0,rnd,grey]  gap_164 43
mirp[min,rnd,grey]  hstem 1
srp1    11
sloop   7
ip  38 39 40 5 6 7 8
f_deltap    23 12-8 23 13-8
IUP[x]
shpix   9   19
shpix   -9  21
shpix   -18 22
shpix   -18 24
shpix   -9  25
shpix   9   27
shpix   -9  53
#
SVTCA[y-axis]
MDAP[rnd]           0
ALIGNRP             31 
MIRP[rp0,rnd,grey]  vheight_shoot  38     
alignrp     40
MIRP[min,rnd,grey]  vstem_curve  8      
shpix   16  8
f_deltap    8 17-4   8 18+4 8 19+3 8 20+2 8 21+2 8 22+2 8 23+2 8 24+2 8 25+2   8 26+1   8 29+6 8 30+6 8 31+6 8 32+6 8 33+6 8 34+6 8 35+6
shp[rp2]    5
mdrp[rp0,min,rnd,grey]  39
mdrp[rp0,rnd,grey]  7
MDRP[rp0,min,rnd,white]  20         
f_deltap    20 9+8   20 10+8
MIRP[min,rnd,grey]  headstem  50    
f_deltap    50 27+4 50 28+4 50 29+4
MIRP[rp0,rnd,grey]  headdia  26    
f_deltap    26 19+8  26 24+8 26 25+8 26 26+8   26 40+8 26 41+8   26 44-8 26 45-8
mdrp[grey]  14
mdrp[grey]  28
f_deltap    14 14-5 28 14+3   14 15-5 28 15+3   14 16-5 29 16+3 30 16+8
MIRP[min,rnd,grey]  headstem  44    
f_deltap    44 27-4 44 28-4 44 29-4
shpix   -18 44
IUP[y]
""",

    #kho_rakang
    "uni0E06": """
f_deltap    80 9+8   80 15-8  80 36+8  
srp0    79
mdrp[rp0,rnd,grey]  31
mdrp[grey]  26
mirp[min,rnd,grey]  headstem 58
f_deltap    58 27+4 58 28+4 58 29+4
mirp[rp0,rnd,grey]  headstem_plus_hole 64
f_deltap    64 27+4 64 28+4 64 29+4
mdrp[grey]  37
srp0    31
mdrp[rp0,rnd,grey]  20
srp1    26
sloop   6
ip      40 41 42 22 23 24
mdrp[grey]  44
mdrp[rp0,rnd,grey]  14
f_deltap    14 16+8  14 17+8  14 27+8  14 28+8
mirp[rp0,min,rnd,grey]  hstem 49
alignrp     3
mdrp[rp0,rnd,grey]  9
f_deltap    9 12+8   9 16+8   9 20-8   9 25+8   9 34+8 
mirp[min,rnd,grey]  headstem 76
mirp[rnd,grey]  headstem_plus_hole 70
#
srp0    80
mirp[rp0,rnd,grey]  gap_164 54
mirp[min,rnd,grey]  hstem 52
shp[rp2]    1
shpix   8   20
IUP[x]
shpix   9   38
shpix   18  36
shpix   9   35
shpix   -9  33
shpix   -18 32
shpix   -18 30
shpix   -9  29
shpix   -8  64
shpix   9   70
#
SVTCA[y-axis]
mdap[rnd]   1
mirp[min,rnd,grey]  vstem 52
mirp[rnd,grey]  vheight_lo  6
mirp[rnd,grey]  vheight 53
mirp[rp0,rnd,grey]  vheight_shoot 40
alignrp 42
mdrp[grey]  24
shpix   8  24
shp[rp2]    22
mdrp[rp0,min,rnd,grey]  41
mirp[rp0,grey]  headstem 23
mdrp[rp0,rnd,white]  28
mdap[rnd]   28
f_deltap    28 9+8 28 10+8 28 11+8 28 12+8 28 13+8 28 14+8 28 15+8 28 16+8
mirp[min,rnd,grey]  headstem 61
f_deltap    61 27+4  61 28+4  61 29+4    61 44+8 61 45+8
mirp[rp0,rnd,grey]  headdia 34
f_deltap    34 9+8 34 10+8 34 11+8  34 19+8  34 24+8 34 25+8 34 26+8   34 40+8 34 41+8 
mirp[min,rnd,grey]  headstem 55
f_deltap    55 27-4 55 28-4 55 29-4
srp0    6
mdrp[min,rnd,grey]  67
f_deltap    67 27-4
mdrp[rp0,rnd,grey]  12
f_deltap    12 18-8 12 19-8   12 23-8 12 24-8  12 33-8 12 34-8   12 38-8 12 39-8 12 40-8 
mirp[min,rnd,grey]  headstem 73
f_deltap    73 27+4
mdrp[rp0,rnd,grey]  50
mdrp[grey]  3
srp1    34
srp2    12
ip  16
ip  48
f_deltap    23 12+3  23 13+3  23 14+3  23 15+3  23 16+4      
shpix   18  61
shpix   18  3
IUP[y]
""",

    #ngo_ngu
    "uni0E07": """
f_deltap    33 9+8   33 22+8   33 23+8
srp0    32
mdrp[rp0,grey]  4
mdrp[grey]  5
#
srp0    33
mirp[rp0,rnd,grey]  gap_164 19
mirp[rp0,min,rnd,grey]  hstem 8
mdrp[grey]  1
srp0    19
mirp[rp0,rnd,grey]  headdia_plus 14
mirp[min,rnd,grey]  headstem 29
f_deltap    29 27-4 29 28-4 29 29-4
mirp[rnd,grey]  headstem_plus_hole 23
f_deltap    23 27-4 23 28-4 23 29-4
f_deltap    14 12+4  14 13+4
IUP[x]
shpix   -9  18
shpix   9   16
shpix   18  15
shpix   18  13
shpix   9   12
#
SVTCA[y-axis]
mdap[rnd]   1
mdrp[grey]  8
mirp[rp0,rnd,grey]  vheight_shoot 17
ip  5
ip  4
mirp[min,rnd,grey]  headstem 26
f_deltap    26 27+4 26 28+4 26 29+4
mirp[rp0,rnd,grey]  headdia 11
f_deltap    11 19+8   11 24+8 11 25+8 11 26+8   11 40+8 11 41+8   11 44-8 11 45-8
mirp[min,rnd,grey]  headstem 20
f_deltap    20 27+4 20 28+4 20 29+4
f_deltap    5 14-2 8 14-2   5 15-2 8 15-2   5 16-2 8 16-2   
#
f_deltap    20 27-4 20 28-4 20 29-4
shpix -18 20
IUP[y]
""",

    #jo_jan
    "uni0E08": """
f_deltap    45 9+8   45 10+8   45 11+8   45 13+8   45 17+8   45 25-8   45 28+8
srp0    44
mirp[rp0,rnd,grey]  gap_127 7
mdrp[grey]  22
mirp[min,rnd,grey]  headstem 41
f_deltap    41 27-4 41 28-4 41 29-4
mirp[rp0,rnd,grey]  headstem_plus_hole 35
f_deltap    35 27-4 35 28-4 35 29-4
mdrp[grey]  2
mdrp[grey]  12
f_deltap    12 9-2  12 12-2  12 13-2  12 14-2  12 15-2  12 16-2  
#
srp0    45
mirp[rp0,rnd,grey]  gap_113 29
mirp[min,rnd,grey]  hstem 16
mdrp[rp0,grey]  0
mdrp[grey]  1
srp1    16
srp2    1
ip  13
srp1    12
srp2    13
ip  11
srp1    0
srp2    13
ip  1
f_deltap    7 12+4  7 13+4
IUP[x]
shpix    9   9
shpix    18  8
shpix    18  6
shpix    9   5
#
SVTCA[y-axis]
mdap[rnd]  1
mirp[grey]  vstem 13
mirp[rp0,rnd,grey]  vheight_shoot 26
mdrp[grey]  23
mirp[rp0,min,rnd,grey]  vstem_curve 19
shpix   16 19
f_deltap    19 17-4   19 18+4 19 19+3 19 20+2 19 21+2 19 22+2 19 23+2 19 24+2 19 25+2   19 26+1   19 29+6 19 30+6 19 31+6 19 32+6 19 33+6 19 34+6 19 35+6
mdrp[grey]  22
mdrp[rp0,min,rnd,white]  10
mdap[rnd]   10
f_deltap    10 23-8  10 24-8  10 25-8  10 37+8 
mirp[min,rnd,grey]  headstem 38
f_deltap    38 27+4 38 28+4 38 29+4
mirp[rp0,rnd,grey]  headdia 4
f_deltap    4 19+8   4 24+8 4 25+8 4 26+8   4 40+8 4 41+8   4 44-8 4 45-8
mirp[min,rnd,grey]  headstem 32
f_deltap    32 27-4 32 28-4 32 29-4
shpix    -18 32
f_deltap    13 14-4  13 15-8  13 16-2 
f_deltap    2 10+8  2 11+6  2 13+2  2 14+4  2 15+8  2 16+6  
f_deltap    14 14-6 14 15-8 14 16-4
IUP[y]
""",


    #cho_ching
    "uni0E09": """
f_deltap    68 16+8   68 18+8   
srp0    67
mirp[rp0,rnd,white] gap_84 7
f_deltap    7 12-8 7 13-8
mirp[min,rnd,grey]  headstem 52
f_deltap    52 27-4 52 28-4 52 29-4
mirp[rnd,grey]  headstem_plus_hole 46
f_deltap    46 27-4 46 28-4 46 29-4
mirp[rp0,rnd,grey]  headdia_plus 12
SHP[rp2]    0
mirp[min,rnd,grey]  hstem 1
#
srp0    68
mirp[rp0,rnd,grey]  gap_205 29
mirp[min,rnd,grey]  hstem 15
mdrp[rp0,rnd,grey]  33
f_deltap    33 23-8  33 24-8
mirp[min,rnd,grey]  headstem 58
f_deltap    58 27+4 58 28+4 58 29+4
mirp[rp0,min,rnd,grey]  headdia 39
f_deltap    39 19+8   39 24+8  39 25+8 39 26+8
mirp[min,rnd,grey]  headstem 64
f_deltap    64 27-4 64 28-4 64 29-4
f_deltap    7 12+4 7 13+4
IUP[x]
shpix    -9  11
shpix    9   9
shpix    18  8
shpix    18  6
shpix    9   5
#
shpix   -9  32
shpix   -18 34
shpix   -9  35
shpix   9   37
shpix   18  38
#
SVTCA[y-axis]
mdap[rnd]   0
mirp[min,rnd,grey]  vstem_curve 13
mirp[rnd,grey]      vheight_lo  36
mirp[rp0,rnd,grey]  vheight_shoot  26
mdrp[grey]  23
mirp[rp0,min,rnd,grey]  vstem_curve 19
shpix   16  19
f_deltap    19 17-4   19 18+4 19 19+3 19 20+2 19 21+2 19 22+2 19 23+2 19 24+2 19 25+2   19 26+1   19 29+6 19 30+6 19 31+6 19 32+6 19 33+6 19 34+6 19 35+6
mdrp[grey]  22
mdrp[rp0,rnd,grey]  10
mdap[rnd]   10
f_deltap    10 22-8 10 25-8 10 37+8
mirp[min,rnd,grey]  headstem 49
f_deltap    49 27+4 49 28+4 49 29+4
mirp[rp0,rnd,grey]  headdia 4
f_deltap    4 19+8   4 24+8 4 25+8 4 26+8   4 40+8 4 41+8   4 44-8 4 45-8
mirp[min,rnd,grey]  headstem 43
f_deltap    43 27-4 43 28-4 43 29-4
srp0    36
mirp[min,rnd,grey]  headstem 55
f_deltap    55 27-4 55 28-4 55 29-4
mdrp[rp0,rnd,grey]  30
f_deltap    30 19-8   30 25-8 30 26-8    30 35+8   30 40+8 
alignrp 15
mdrp[grey]  41
mirp[min,rnd,grey]  headstem 61
f_deltap    61 27+4 61 28+4 61 29+4
#
shpix    -18 43
shpix   18 61
shpix   18 41
#f_deltap    41 14+2  41 15+3  41 16+2
IUP[y]
""",

    #cho_chang
    "uni0E0A": """
f_deltap    63 9+8   63 11+8   63 17+8  63 18+8  63 19+8   63 23-8  63 24-8   63 26+8   63 27+8  63 28+8  63 36+8   63 37+8   63 38+8   
srp0                62
mdrp[rp0,rnd,grey]  15
f_deltap    15 12-8  15 13-8
mdrp[grey]  12
mirp[min,rnd,grey]  headstem 53
f_deltap    53 27+4 53 28+4 58 29+4
mirp[rp0,rnd,grey]  headstem_plus_hole 59
f_deltap    59 12+8  59 13+8   59 27+4 59 28+4 59 29+4
mdrp[grey]  21
srp0    15
mdrp[rp0,min,rnd,white]  7
mdrp[grey]  27
ip  10
mdrp[rp0,rnd,grey]  1
mdap[rnd]   1
f_deltap    1 9-8  1 10-8   1 13+8  1 30+8  1 36-8
mirp[min,rnd,grey]  hstem 32
#
srp0    63
mirp[rp0,rnd,grey]  gap_205 47
mirp[min,rnd,grey] hstem 36
srp1    27
ip  39
srp0    39
mdrp[grey]  45
srp0    47
mdrp[rp0,rnd,grey]  43
mirp[min,rnd,grey]  hstem 42
#
shpix   8   7
f_deltap    45 14-4 45 15-4 45 16-4
IUP[x]
shpix   9   22
shpix   18  20
shpix   9   19
shpix   -9  17
shpix   -18 16
shpix   -18 14
shpix   -9  13
#
SVTCA[y-axis]
mdap[rnd]           1
mirp[min,rnd,grey]  vstem 34
mirp[rp0,rnd,grey]  vheight_shoot 24
sloop   3
ip  40 45 39
mdrp[min,rnd,grey]  42
mirp[rp0,grey]  headstem 10
mdrp[rp0,rnd,white] 12
mdap[rnd]   12
mdrp[rp0,rnd,grey]  18
f_deltap    18 9+8  18 10+8  18 11+8  18 14+8 18 15+8 18 16+8   18 27+8 18 28+8 18 29+8
mirp[min,rnd,grey]  headstem 50
f_deltap    50 27-4 50 28-4 50 29-4
mirp[rnd,grey]      headstem_plus_hole 56
f_deltap    56 27-4 56 28-4 56 29-4
srp2    33
ip  3
ip  31
shpix   16 56
IUP[y]
""",

    #so_zo
    "uni0E0B": """
f_deltap    67 10+8   67 12+8    67 18+8 67 20+8   67 33+8
srp0    66
mdrp[rp0,rnd,grey]  18
mdrp[grey]  13
f_deltap    13 14-4 13 15-4 13 16-4
mirp[min,rnd,grey]  headstem 57
f_deltap    57 27+4 57 28+4 57 29+4
mirp[rnd,grey]  headstem_plus_hole 63
f_deltap    63 27+4 63 28+4 63 29+4
mdrp[grey]  24
srp0    18
mdrp[rp0,min,rnd,white]  7
mdrp[grey]  31
srp2    13
sloop   6
ip  27 28 29 9 10 11
mdrp[rp0,rnd,grey]  1
mdap[rnd]   1
f_deltap    1 15+8
mirp[min,rnd,grey]  hstem 36
#
srp0    67
mirp[rp0,rnd,grey]  gap_205 51
mirp[rp0,min,rnd,grey]  hstem 40
srp1    31
ip  43
srp0    43
mdrp[grey]  49
f_deltap    49 14-4 49 15-4 49 16-4
srp0    51
mdrp[rp0,rnd,grey]  47
mirp[min,rnd,grey]  hstem 46
#
shpix   8   7
IUP[x]
shpix   9   25
shpix   18  23
shpix   9   22
shpix   -9  20
shpix   -18 19
shpix   -18 17
shpix   -9  16
f_deltap    16 15-4
#
SVTCA[y-axis]
mdap[rnd]  0
mirp[min,rnd,grey]  vstem   38
mirp[rp0,rnd,grey]  vheight_shoot   27
alignrp     29
sloop   3
ip  44 49 43
mdrp[min,rnd,grey]  46
mirp[grey]  sarastem 11
shp[rp2]    9
mdrp[rp0,min,rnd,grey] 28
mirp[rp0,grey] headstem 10
mdrp[rp0,rnd,white] 15
mdap[rnd]   15
f_deltap    15 9+8 15 10+8 15 11+8 15 12+8 15 13+8 15 14+8 15 15+8 15 16+8
mdrp[grey]  13
mirp[min,rnd,grey]  headstem 60
f_deltap    60 27+4 60 28+4 60 29+4
mirp[rp0,rnd,grey]  headdia 21
f_deltap    21 9+8 21 10+8 21 11+8   21 19+8   21 24+8 21 25+8 21 26+8   21 40+8 21 41+8
mirp[min,rnd,grey]  headstem 54
f_deltap    54 27-4 54 28-4 54 29-4
srp2    37
ip  3
ip  35
f_deltap    28 9-4 28 10-4 28 11-2 28 12-2   28 13-2 10 13+2   10 14+4   10 15+4   10 16+4
shpix   18  60
IUP[y]
""",

    #sho_sher
    "uni0E0C": """
f_deltap    78 12+8   78 18-8
srp0    77
mirp[rp0,rnd,grey]  gap_197 36
mdrp[grey]  40
mdrp[grey]  21
mirp[rp0,min,rnd,grey]  hstem 25
mdrp[grey]  23
mdrp[grey]  39
srp0    36
mirp[rp0,rnd,grey]  headdia_plus 31
mirp[min,rnd,grey]  headstem 56
f_deltap    56 27+4 56 28+4 56 29+4
mirp[rnd,grey]  headstem_plus_hole 62 
f_deltap    62 27+4 62 28+4 62 29+4
#
srp0    78
mirp[rp0,rnd,grey]  gap_164 52
mirp[min,rnd,grey]  hstem 50
shp[rp2]    1
srp1    36
ip      14
#
mdap[rnd]   14
mirp[min,rnd,grey]  hstem 47
srp2    31
ip      11
mdap[rnd]   11
mirp[min,rnd,grey]  headstem 74
f_deltap    74 27-4 74 28-4 74 29-4
mirp[rp0,rnd,white] headdia 5
mirp[min,rnd,grey]  headstem 68
f_deltap    68 19-8  68 24-8  68 25-8  68 26-8  68 27+4  68 28+4  68 29+4  68 40-8  68 41-8  68 44+8 68 45+8 
f_deltap    31 12-4  31 13-4 
IUP[x]
shpix    9   35
shpix    -9  33
shpix    -18 32
shpix    -18 30
shpix    -9  29
#
shpix   9   13
shpix   18  12
shpix   18  10
shpix   9   9
shpix   -9  7
shpix   -18 6
#
shpix   -16 21
shpix   16  39
#
SVTCA[y-axis]
mdap[rnd]  1
mirp[rnd,grey]  vheight_lo  8
shp[rp2]    34
mirp[rnd,grey]  vheight 52
mirp[min,rnd,grey]  vstem_curve 50
mirp[rp0,rnd,grey]  vheight_shoot 44
mdrp[grey]  41
mirp[rp0,min,rnd,grey]  vstem_curve 18
shpix   16  18
f_deltap    18 17-4   18 18+4 18 19+3 18 20+2 18 21+2 18 22+2 18 23+2 18 24+2 18 25+2   18 26+1   18 29+6 18 30+6 18 31+6 18 32+6 18 33+6 18 34+6 18 35+6
mdrp[grey]  40
ip  21
srp0    8
mirp[min,rnd,grey] headstem 65
f_deltap    65 27-4 65 28-4 65 29-4
shp[rp2] 53
mirp[rp0,rnd,grey] headdia 14
f_deltap    14 19-8   14 24-8 14 25-8 14 26-8   14 40-8 14 41-8   14 44+8 14 45+8
alignrp 28
mirp[min,rnd,grey]  headstem 71
f_deltap    71 27+4 71 28+4 71 29+4
shpix    18  71
shp[rp2] 59
mdrp[rp0,rnd,grey]  48
mdrp[min,rnd,grey]  3
shpix   18 3
IUP[y]
""",

    #yo_ying
    "uni0E0D": """
f_deltap    83 15-8  83 21-8
srp0    82
mirp[rp0,rnd,grey]  gap_197 23
mdrp[grey]  27
mdrp[grey]  8
mirp[rp0,min,rnd,grey]  hstem 12
mdrp[grey]  10
mdrp[grey]  26
srp0    23
mirp[rp0,rnd,grey]  headdia_plus 18
mirp[min,rnd,grey]  headstem 42
f_deltap    42 27+4 42 28+4 42 29+4
mirp[rnd,grey]  headstem_plus_hole 48
f_deltap    48 27+4 48 28+4 48 29+4
#
srp0    83
mirp[rp0,rnd,grey]  gap_164 38
mirp[min,rnd,grey]  hstem 36
srp1    23
ip      1
#
mdap[rnd]   1
mirp[min,rnd,grey]  hstem 34
#
#srp0    1
mdrp[rp0,rnd,grey]  54
mirp[min,rnd,grey]  headstem_tiny 79
mirp[rp0,rnd,grey]  headdia_tiny 60
f_deltap    60 30-8 60 31-8 60 32-8
mirp[min,rnd,grey]  headstem_tiny 73
srp0    38
mdrp[rp0,rnd,grey]  67
mdrp[grey]  66
f_deltap    18 12-4  18 13-4
IUP[x]
shpix    9   22
shpix    -9  20
shpix    -18 19
shpix    -18 17
shpix    -9  16
#
shpix   -16 8
shpix   16  26
#
SVTCA[y-axis]
mdap[rnd]  1
mirp[rnd,grey]  vheight_lo 21
mirp[min,rnd,grey]  vstem 35
mirp[rnd,grey]  vheight 38
mirp[rp0,rnd,grey]  vheight_shoot 31
mdrp[grey]  28
mirp[rp0,min,rnd,grey]  vstem_curve 5
shpix   16  5
f_deltap    5 17-4   5 18+4 5 19+3 5 20+2 5 21+2 5 22+2 5 23+2 5 24+2 5 25+2   5 26+1   5 29+6 5 30+6 5 31+6 5 32+6 5 33+6 5 34+6 5 35+6
mdrp[grey]  27
ip  8
srp0    21
mirp[min,rnd,grey] headstem 39
f_deltap    39 27-4 39 28-4 39 29-4
mirp[rp0,rnd,grey] headdia 15
f_deltap    15 19-8   15 24-8 15 25-8 15 26-8   15 40-8 15 41-8   15 44+8 15 45+8
mirp[min,rnd,grey]  headstem 45
f_deltap    45 27+4 45 28+4 45 29+4
#
srp0    1
mdrp[rp0,min,rnd,white] 57
mirp[min,rnd,grey]  headstem_tiny 76
mdrp[rp0,rnd,grey]  66
mdrp[grey]  67
srp0    57
mdrp[rp0,rnd,grey]  51
f_deltap    51 15+8   51 16+8   51 21+8 51 22+8 51 23+8 
mdrp[min,rnd,grey]  70
f_deltap    70 25-8 70 26-8
ip  63
shpix    18  45
IUP[y]
""",

    #yo_ying
    "uni0E0D.descless": """
f_deltap    52 15-8  52 21-8
srp0    51
mirp[rp0,rnd,grey]  gap_197 23
mdrp[grey]  27
mdrp[grey]  8
mirp[rp0,min,rnd,grey]  hstem 12
mdrp[grey]  10
mdrp[grey]  26
srp0    23
mirp[rp0,rnd,grey]  headdia_plus 18
mirp[min,rnd,grey]  headstem 42
f_deltap    42 27+4 42 28+4 42 29+4
mirp[rnd,grey]  headstem_plus_hole 48
f_deltap    48 27+4 48 28+4 48 29+4
#
srp0    52
mirp[rp0,rnd,grey]  gap_164 38
mirp[min,rnd,grey]  hstem 36
srp1    23
ip      1
#
mdap[rnd]   1
mirp[min,rnd,grey]  hstem 34
#
f_deltap    18 12-4  18 13-4
IUP[x]
shpix    9   22
shpix    -9  20
shpix    -18 19
shpix    -18 17
shpix    -9  16
#
shpix   -16 8
shpix   16  26
#
SVTCA[y-axis]
mdap[rnd]  1
mirp[rnd,grey]  vheight_lo 21
mirp[min,rnd,grey]  vstem 35
mirp[rnd,grey]  vheight 38
mirp[rp0,rnd,grey]  vheight_shoot 31
mdrp[grey]  28
mirp[rp0,min,rnd,grey]  vstem_curve 5
shpix   16  5
f_deltap    5 17-4   5 18+4 5 19+3 5 20+2 5 21+2 5 22+2 5 23+2 5 24+2 5 25+2   5 26+1   5 29+6 5 30+6 5 31+6 5 32+6 5 33+6 5 34+6 5 35+6
mdrp[grey]  27
ip  8
srp0    21
mirp[min,rnd,grey] headstem 39
f_deltap    39 27-4 39 28-4 39 29-4
mirp[rp0,rnd,grey] headdia 15
f_deltap    15 19-8   15 24-8 15 25-8 15 26-8   15 40-8 15 41-8   15 44+8 15 45+8
mirp[min,rnd,grey]  headstem 45
f_deltap    45 27+4 45 28+4 45 29+4
#
shpix    18  45
IUP[y]
""",

    #do_chada
    "uni0E0E": """
f_deltap    75 10-8   75 15-8   75 16-8    75 19-8   75 21-8
srp0    74
mirp[rp0,rnd,grey]  gap_340 40
mdrp[grey]  44
mdrp[grey]  25
mirp[rp0,min,rnd,grey]  hstem 29
mdrp[grey]  27
mdrp[grey]  43
mirp[rp0,rnd,grey]  headdia_plus 35
mirp[min,rnd,grey]  headstem 61
f_deltap    61 27-4 61 28-4 61 29-4
mirp[rnd,grey]  headstem_plus_hole 55
f_deltap    55 27-4 55 28-4 55 29-4
#
srp0    75
mirp[rp0,rnd,white]  gap_164 51
mirp[min,rnd,grey]  hstem 18
shp[rp2]    1
#
mdrp[rp0,rnd,grey]  8
mirp[min,rnd,grey]  sarastem 71
srp1    18
sloop   6
ip  66 13 14 3 16 15
f_deltap    35 12+4  35 13+4
shpix   18   8
IUP[x]
shpix    -9  31
shpix    9   33
shpix    18  34
shpix    18  36
shpix    9   37
#
shpix   16   66
shpix   -16  16
#
shpix   -16 25
shpix   16 43
#
SVTCA[y-axis]
mdap[rnd]   74
mirp[rnd,grey]  vheight_lo 32
mirp[rnd,grey]  vheight_lu 1
shp[rp2]    5
mirp[rp0,rnd,grey]  vheight_shoot 48
mdrp[grey]  45
mirp[rp0,min,rnd,grey]  vstem_curve   22
shpix   16  22
f_deltap    22 17-4   22 18+4 22 19+3 22 20+2 22 21+2 22 22+2 22 23+2 22 24+2 22 25+2   22 26+1   22 29+6 22 30+6 22 31+6 22 32+6 22 33+6 22 34+6 22 35+6
mdrp[grey]  44
ip  25
srp0    32
mirp[min,rnd,grey]  headstem 52
f_deltap    52 27-4 52 28-4 52 29-4
mirp[rp0,rnd,grey]  headdia 38
f_deltap    38 19-8   38 24-8 38 25-8 38 26-8   38 40-8 38 41-8   38 44+8 38 45+8
mirp[min,rnd,grey]  headstem 58
f_deltap    58 27+4 58 28+4 58 29+4
srp0    5
mirp[min,rnd,grey]  headstem   64
mdrp[rp0,rnd,grey]  11
sloop   6
ip  14 15 13 16 66 3
mirp[min,rnd,grey]  headstem   68
srp0    1
mdrp[grey]  18
shpix    18  58
shpix   -9  11
shpix   9   5
IUP[y]
shpix   -9  13
shpix   9   3
""",

    #to_patak
    "uni0E0F": """
f_deltap    79 10-8   79 15-8   79 16-8    79 19-8   79 21-8
srp0    78
mirp[rp0,rnd,grey]  gap_340 46
mdrp[grey]  50
mdrp[grey]  31
mirp[rp0,min,rnd,grey]  hstem 35
mdrp[grey]  33
mdrp[grey]  49
mirp[rp0,rnd,grey]  headdia_plus 41
mirp[min,rnd,grey]  headstem 67
f_deltap    67 27-4 67 28-4 67 29-4
mirp[rnd,grey]  headstem_plus_hole 61
f_deltap    61 27-4 61 28-4 61 29-4
#
srp0    79
mirp[rp0,rnd,white]  gap_164 57
mirp[min,rnd,grey]  hstem 24
shp[rp2]    1
#
mdrp[rp0,rnd,grey]  11
mirp[min,rnd,grey]  headstem 76
srp1    24
sloop   12
ip  72 16 17 18 19 21 22 23 2 3 4 6
f_deltap    41 12+4  41 13+4
shpix   18   11
IUP[x]
shpix    -9  37
shpix    9   39
shpix    18  40
shpix    18  42
shpix    9   43
#
shpix   9   72
shpix   -9  19
#
shpix   -18 31
shpix   18  49
#
SVTCA[y-axis]
mdap[rnd]   78
mirp[rnd,grey]  vheight_lo 38
mirp[rnd,grey]  vheight_lu 1
shp[rp2]    4
shp[rp2]    8
mirp[rp0,rnd,grey]  vheight_shoot 54
mdrp[grey]  51
mirp[rp0,min,rnd,grey]  vstem_curve   28
shpix   16  28
f_deltap    28 17-4   28 18+4 28 19+3 28 20+2 28 21+2 28 22+2 28 23+2 28 24+2 28 25+2   28 26+1   28 29+6 28 30+6 28 31+6 28 32+6 28 33+6 28 34+6 28 35+6
mdrp[grey]  50
ip  31
srp0    38
mirp[min,rnd,grey]  headstem 58
f_deltap    58 27-4 58 28-4 58 29-4
mirp[rp0,rnd,grey]  headdia 44
f_deltap    44 19-8   44 24-8 44 25-8 44 26-8   44 40-8 44 41-8   44 44+8 44 45+8
mirp[min,rnd,grey]  headstem 64
f_deltap    64 27+4 64 28+4 64 29+4
srp0    8
mirp[min,rnd,grey]  headstem   70
mdrp[rp0,rnd,grey]  14
sloop   9
ip  72 16 17 19 21 22 24 2 6
mirp[min,rnd,grey]  headstem   74
shpix    18  64
shpix   -9  14
shpix   9   8
IUP[y]
shpix   -9  16
shpix   9   6
""",

    #tho_than
    "uni0E10": """
f_deltap    118 9+8   118 10+8   118 21-8
srp0    117
mirp[rp0,rnd,grey]  gap_164 7
mdrp[grey]  19
mdrp[grey]  41
mirp[min,rnd,grey]  headstem 56
f_deltap    56 27-4 56 28-4 56 29-4
mirp[rp0,rnd,grey]  headstem_plus_hole 50
f_deltap    50 27-4 50 28-4 50 29-4
mdrp[grey]  12
f_deltap    12 18+2
mdrp[grey]  2
#
srp0    118
mirp[rp0,rnd,grey]  gap_164   44
mdrp[grey]  31
mirp[min,rnd,grey]  hstem   16
srp1    12
ip      13
srp0    13
mdrp[grey]  1
mdrp[grey]  0
srp1    12
srp2    13
ip      11
#
srp0    44
mdrp[rp0,rnd,grey]  96
mdrp[min,rnd,grey]  85
mdrp[min,rnd,grey]  100
mdrp[rp0,rnd,grey]  91
f_deltap    91 27+8  91 28+8  91 29+8 91 35+8 
mdrp[min,rnd,grey]  106
srp0    96
mdrp[rp0,min,rnd,grey]  70
mdrp[min,rnd,grey]  115
srp1    115
srp2    85
sloop   13
ip      111 75 77 65 80 78 63 82 62 83 61 84 60
IUP[x]
shpix   -9  11
shpix   9   9
shpix   18  8
shpix   18  6
shpix   9   5
#
shpix   -16 41
#
SVTCA[y-axis]                       
mdap[rnd]   1
mirp[grey]  vstem_curve 13
mirp[rp0,rnd,grey]  vheight_shoot   23
mdrp[grey]  28
mdrp[grey]  30
mdrp[grey]  20
mirp[rp0,min,rnd,grey]  vstem_curve 38
shpix   16 38
f_deltap    38 17-4   38 18+4 38 19+3 38 20+2 38 21+2 38 22+2 38 23+2 38 24+2 38 25+2   38 26+1   38 29+6 38 30+6 38 31+6 38 32+6 38 33+6 38 34+6 38 35+6
mdrp[grey]  33
mdrp[grey]  31
mdrp[rp0,grey]  19
ip  41
mdrp[grey]  18
srp0    41
mdrp[grey]  42
#
srp0    19
mdrp[rp0,rnd,white] 10
mdap[rnd]   10
f_deltap    10 14-8 10 15-8 10 16-8  10 18-8 10 19-8  10 23-8  10 24-8  10 40-8 
mirp[min,rnd,grey]  headstem    53
f_deltap    53 27+4 53 28+4 53 29+4
mirp[rp0,rnd,grey]  headdia 4
f_deltap    4 19+8  4 24+8  4 25+8 4 26+8  4 40+8 4 41+8
mirp[min,rnd,grey]  headstem 47
f_deltap    47 27-4 47 28-4 47 29-4
#
f_deltap    4 9+8  4 10+8 
f_deltap    13 14-4  13 15-4 13 16-4 
shpix   -18 47
#
srp0    1
mdrp[rp0,min,rnd,white]  94
mdrp[min,rnd,grey]  103
mdrp[rp0,rnd,grey]  88
f_deltap 88 39+8 88 40+8 88 41+8 88 42+8 
mdrp[min,rnd,grey]  97
mdrp[rp0,rnd,grey]  59
f_deltap    59 9+8   59 10+8   59 11+8   
alignrp 62
alignrp 67
srp0    67
mdrp[rp0,rnd,grey]  73
ip  109
ip  113
srp1    73
srp2    67
sloop   10
ip  77 75 78 111 80 83 65 82 85 61
#
IUP[y]
f_deltap    2 14+8  2 15+8  2 16+8
f_deltap    14 14-4 14 15-4
shpix   16  2
""",

    #tho_than_descless
    "uni0E10.descless": """
srp0    59
mirp[rp0,rnd,grey]  gap_164 7
mdrp[grey]  19
mdrp[grey]  41
mirp[min,rnd,grey]  headstem 56
f_deltap    56 27-4 56 28-4 56 29-4
mirp[rp0,rnd,grey]  headstem_plus_hole 50
f_deltap    50 27-4 50 28-4 50 29-4
mdrp[grey]  12
f_deltap    12 18+2
mdrp[grey]  2
#
srp0    60
mirp[rp0,rnd,grey]  gap_164   44
mdrp[grey]  31
mirp[min,rnd,grey]  hstem   16
srp1    12
ip      13
srp0    13
mdrp[grey]  1
mdrp[grey]  0
srp1    12
srp2    13
ip      11
#
IUP[x]
shpix   -9  11
shpix   9   9
shpix   18  8
shpix   18  6
shpix   9   5
#
shpix   -16 41
#
SVTCA[y-axis]                       
mdap[rnd]   1
mirp[grey]  vstem_curve 13
mirp[rp0,rnd,grey]  vheight_shoot   23
mdrp[grey]  28
mdrp[grey]  30
mdrp[grey]  20
mirp[rp0,min,rnd,grey]  vstem_curve 38
shpix   16 38
f_deltap    38 17-4   38 18+4 38 19+3 38 20+2 38 21+2 38 22+2 38 23+2 38 24+2 38 25+2   38 26+1   38 29+6 38 30+6 38 31+6 38 32+6 38 33+6 38 34+6 38 35+6
mdrp[grey]  33
mdrp[grey]  31
mdrp[rp0,grey]  19
ip  41
mdrp[grey]  18
srp0    41
mdrp[grey]  42
#
srp0    19
mdrp[rp0,rnd,white] 10
mdap[rnd]   10
f_deltap    10 14-8 10 15-8 10 16-8  10 18-8 10 19-8  10 23-8  10 24-8  10 40-8 
mirp[min,rnd,grey]  headstem    53
f_deltap    53 27+4 53 28+4 53 29+4
mirp[rp0,rnd,grey]  headdia 4
f_deltap    4 19+8  4 24+8  4 25+8 4 26+8  4 40+8 4 41+8
mirp[min,rnd,grey]  headstem 47
f_deltap    47 27-4 47 28-4 47 29-4
#
f_deltap    4 9+8  4 10+8 
f_deltap    13 14-4  13 15-4 13 16-4 
shpix   -18 47
#
IUP[y]
f_deltap    2 14+8  2 15+8  2 16+8
f_deltap    14 14-4 14 15-4
shpix   16  2
""",

    #tho_nangmontho
    "uni0E11": """
f_deltap    67 16-8   67 20+8   
srp0    66
mdrp[rp0,rnd,grey]  27
mdrp[grey]  22
f_deltap    22 14-4 22 15-4 22 16-4
mirp[min,rnd,grey]  headstem 57
f_deltap    57 27+4 57 28+4 57 29+4
mirp[rp0,rnd,grey]  headstem_plus_hole 63
f_deltap    63 27+4 63 28+4 63 29+4
mdrp[grey]  33
srp0    27
mdrp[rp0,min,rnd,white]  16
mdrp[grey]  40
srp2    22
sloop   6
ip  36 37 38 18 19 20
mdrp[rp0,rnd,grey]  10
mdap[rnd]   10
f_deltap    10 14+8  10 15+8
mirp[min,rnd,grey]  hstem 45
shp[rp2]    9
#
srp0    67
mirp[rp0,rnd,grey]  gap_164 53
mirp[min,rnd,grey]  hstem 1
srp1    40
ip  49
srp0    49
mdrp[grey]  6
#
shpix   8   16
IUP[x]
#
shpix   9   34
shpix   18  32
shpix   9   31
shpix   -9  29
shpix   -18 28
shpix   -18 26
shpix   -9  25
f_deltap    25 15-4
#
SVTCA[y-axis]
mdap[rnd]   9
alignrp     1
mirp[min,rnd,grey]  vstem_curve   46
mirp[rp0,rnd,grey]  vheight_shoot   36
alignrp     38
alignrp     51
mirp[min,rnd,grey]  vstem_curve 4
shpix   16 4
f_deltap    4 17-4   4 18+4 4 19+3 4 20+2 4 21+2 4 22+2 4 23+2 4 24+2 4 25+2   4 26+1   4 29+6 4 30+6 4 31+6 4 32+6 4 33+6 4 34+6 4 35+6
srp0    36
mirp[grey]  sarastem 20
shp[rp2]    18
mdrp[rp0,min,rnd,grey] 37
mdrp[rp0,grey]  19
mdrp[rp0,rnd,white] 24
mdap[rnd]   24
f_deltap    24 9+8 24 10+8 24 11+8 24 12+8 24 13+8 24 14+8 24 15+8 24 16+8
mdrp[grey]  22
mirp[min,rnd,grey]  headstem 60
f_deltap    60 27+4 60 28+4 60 29+4
mirp[rp0,rnd,grey]  headdia 30
f_deltap    30 9+8 30 10+8 30 11+8   30 19+8   30 24+8 30 25+8 30 26+8
mirp[min,rnd,grey]  headstem 54
f_deltap    54 27-4 54 28-4 54 29-4
srp2    46
ip  12
ip  44
f_deltap    37 9-4 37 10-4 37 11-2 37 12-2   37 13-2 19 13+2   19 14+4   19 15+4   19 16+4
shpix   18  60
IUP[y]
SVTCA[x-axis]
""",

    #to_putao
    "uni0E12": """
f_deltap    83 9+8  83 12+8  83 15-8  83 16-8  83 17+8  
SRP0                82
mirp[rp0,rnd,white] gap_186 41
mdrp[rp0,rnd,grey]  44
mirp[min,rnd,grey]  hstem   22
srp0    41
mirp[rp0,min,rnd,grey]  hstem 40
srp1    22
ip  25
mdrp[rp0,rnd,grey]  37
f_deltap     37 12+8  37 17-8  37 18-8  37 19-8  37 22-8   37 27-8 37 28-8   37 32-8   37 37-8   37 40-8
mirp[min,rnd,grey]  headstem 61
f_deltap    61 27+4 61 28+4 61 29+4
mirp[rp0,rnd,grey]  headdia 31
f_deltap    31 19+8  31 24+8 31 25+8 31 26+8 
ip  28
mirp[min,rnd,grey]  headstem 67
f_deltap    67 27-4 67 28-4 67 29-4
#
srp0    83
mirp[rp0,rnd,white] gap_164 57
mirp[min,rnd,grey]  hstem 55
shp[rp2]    1
srp1    41
ip  14
mdap[rnd]   14
srp2    22
sloop   7
ip      47 48 49 17 18 19 20
mirp[min,rnd,grey]  hstem 52
shp[rp2]    3
mdrp[rp0,rnd,grey]   11
f_deltap    11 16+8 11 17+8 11 18+8   11 27+8 11 28+8 11 29+8
mirp[min,rnd,grey]  headstem 79
f_deltap    79 27-4 79 28-4 79 29-4
mirp[rp0,rnd,grey]  headdia 5
f_deltap    5 24-8 5 25-8
mirp[min,rnd,grey]  headstem 73
f_deltap    73 19-8   73 26-8   73 27+4 73 28+4 73 29+4
f_deltap    25 14-1 26 14+4  25 15-1 26 15+4  25 16-1  26 16+4
f_deltap    26 14-3 39 14-3  26 15-2 39 15-2  26 16-1 39 16-1
IUP[x]
shpix   -9  38
shpix   -27 36
shpix   -9  35
shpix   9   33
shpix   27  32
shpix   27  30
shpix   27  29
#
shpix   9   13
shpix   18  12
shpix   18  10
shpix   9   9
shpix   -9  7
shpix   -18 6
#
SVTCA[y-axis]
MDAP[rnd]           1
alignrp     40
mirp[min,rnd,grey]  vstem 55
shp[rp2]    25
mirp[rnd,grey]  vheight_lo  8
mirp[rnd,grey]  vheight 57
mirp[rp0,rnd,grey]  vheight_shoot 47
alignrp     49
mirp[min,rnd,grey]  vstem_curve 20
shpix   16 20
f_deltap    20 17-4   20 18+4 20 19+3 20 20+2 20 21+2 20 22+2 20 23+2 20 24+2 20 25+2   20 26+1   20 29+6 20 30+6 20 31+6 20 32+6 20 33+6 20 34+6 20 35+6
shp[rp2]    17
mdrp[rp0,min,rnd,grey]  48
mdrp[rp0,grey]  19
mdrp[rp0,min,rnd,white] 34
mdap[rnd]   34
f_deltap    34 9+8  34 10+8  34 11+8   34 38-8
mirp[min,rnd,grey]  headstem 64
f_deltap    64 27+4 64 28+4 64 29+4
mirp[rp0,rnd,grey]  headdia 28
f_deltap    28 19+8   28 24+8 28 25+8 28 26+8
mirp[min,rnd,grey]  headstem 58
f_deltap    58 27-4 58 28-4 58 29-4
f_deltap    28 9+8 28 10+8
#
srp0    8
mirp[min,rnd,grey]  headstem 70
f_deltap   70 27-4 70 28-4 70 29-4
mirp[rp0,rnd,grey]  headdia 14
f_deltap    14 19-8   14 24-8 14 25-8 14 26-8
alignrp 53
mirp[min,rnd,grey]  headstem 76
f_deltap   76 27+4 76 28+4 76 29+4
srp0    53
mdrp[min,grey]  3
shpix   16 28
shpix   -16 14
shpix   -16 53
shpix   16 3
#
shpix   -18 48
shpix   -18 19
IUP[y]
""",

    #no_nane
    "uni0E13": """
f_deltap    78 18+8
srp0    77
mirp[rp0,rnd,grey]  gap_197 23
mdrp[grey]  27
mdrp[grey]  8
mirp[rp0,min,rnd,grey]  hstem 12
mdrp[grey]  10
mdrp[grey]  26
srp0    23
mirp[rp0,rnd,grey]  headdia_plus    18
mirp[min,rnd,grey]  headstem 56
f_deltap    56 27+4 56 28+4 56 29+4
mirp[rnd,grey]  headstem_plus_hole 62
f_deltap    62 27+4 62 28+4 62 29+4
#
srp0    78
mirp[rp0,rnd,grey]  gap_205 39
f_deltap    39 26+8
mirp[min,rnd,grey]  hstem 37
srp1    23
ip      1
mdrp[rp0,rnd,grey] 43
f_deltap    43 22-8 43 23-8 43 24-8 43 25-8   43 26-8
mirp[min,rnd,grey]  headstem 68
f_deltap    68 27+4 68 28+4 68 29+4
mirp[rp0,rnd,grey]  headdia 49
f_deltap    49 19+8   49 24+8 49 25+8
mirp[min,rnd,grey]  headstem 74
f_deltap    74 26+8   74 27-4 74 28-4 74 29-4   
#
mdap[rnd]   1
mirp[min,rnd,grey]  hstem  34
shp[rp2]    0
f_deltap    18 12-4  18 13-4
IUP[x]
shpix    9   22
shpix    -9  20
shpix    -18 19
shpix    -18 17
shpix    -9  16
#
shpix   -9  42
shpix   -18 44
shpix   -9  45
shpix   9   47
shpix   18  48
#
shpix   -18 8
shpix   18  26
#
SVTCA[y-axis]
mdap[rnd]  0
mirp[min,rnd,grey]  vstem_curve 35
mirp[rnd,grey]  vheight_lo 21
shp[rp2]    46
mirp[rnd,grey]  vheight 39
mirp[rp0,rnd,grey]  vheight_shoot 31
mdrp[grey]  28
mirp[rp0,min,rnd,grey]  vstem_curve 5
shpix   16 5
f_deltap    5 17-4   5 18+4 5 19+3 5 20+2 5 21+2 5 22+2 5 23+2 5 24+2 5 25+2   5 26+1   5 29+6 5 30+6 5 31+6 5 32+6 5 33+6 5 34+6 5 35+6
mdrp[grey]  27
ip  8
srp0    21
mirp[min,rnd,grey] headstem 53
f_deltap    53 27-4 53 28-4 53 29-4
shp[rp2]    65
mirp[rp0,rnd,grey] headdia 15
f_deltap    15 19-8   15 24-8 15 25-8 15 26-8   15 40-8 15 41-8   15 44+8 15 45+8
alignrp     37
alignrp     40
mirp[min,rnd,grey] headstem 59
f_deltap    59 27+4 59 28+4 59 29+4
shpix    18  59
shp[rp2]    71
IUP[y]
shpix   18 51
shpix   -18 37
""",

    #do_dek
    "uni0E14": """
f_deltap    50 9+8   50 10+8   50 12+8
SRP0    49
MIRP[rp0,rnd,grey]   gap_186 27
f_deltap    27 14+8 27 15+8 27 16+8   27 28-8
mdrp[rp0,rnd,grey]      30
f_deltap    30 13+8
shpix   -8 30
mirp[min,rnd,grey]  hstem 8
srp0    27
mirp[rp0,min,rnd,grey]  hstem 26
srp1    8
ip  11
mdrp[rp0,rnd,grey]  23
f_deltap   23 12+8   23 18-8   23 19-8    23 23-8   23 26-8   23 28-8 23 29-8   23 39-8 
mirp[min,rnd,grey]  headstem 40
f_deltap    40 27+4 40 28+4 40 29+4
mirp[rp0,rnd,grey]  headdia 17
f_deltap    17 19+8   17 24+8   17 25+8  17 26+8
ip  14
mirp[min,rnd,grey]  headstem 46
f_deltap    46 27-4 46 28-4 46 29-4
#
srp0    50
mirp[rp0,rnd,grey]  gap_164 36
mirp[min,rnd,grey]  hstem 1
f_deltap    11 14-1 12 14+4  11 15-1 12 15+4  11 16-1  12 16+4
IUP[x]
#
shpix   -9  24
shpix   -27 22
shpix   -9  21
shpix   9   19
shpix   27  18
shpix   27  16
shpix   27   15
#
shpix   16  14
#
SVTCA[y-axis]
MDAP[rnd]   26
ALIGNRP     1
mirp[grey]  vstem 11
shpix   -16 11
MIRP[rp0,rnd,grey]  vheight_shoot  33
MIRP[min,rnd,grey]  vstem_curve  5
shpix   16 5
f_deltap    5 17-4   5 18+4 5 19+3 5 20+2 5 21+2 5 22+2 5 23+2 5 24+2 5 25+2   5 26+1   5 29+6 5 30+6 5 31+6 5 32+6 5 33+6 5 34+6 5 35+6
mdrp[rp0,min,rnd,white]      20
mdap[rnd]   20
f_deltap    20 9-8   20 16-8 
mirp[min,rnd,grey]      headstem 43
f_deltap    43 27+4 43 28+4 43 29+4
mirp[rp0,rnd,grey]      headdia 14
f_deltap    14 19+8   14 24+8 14 25+8 14 26+8
mirp[min,rnd,grey]      headstem 37
f_deltap    37 27-4 37 28-4 37 29-4
#f_deltap    11 16-7 25 16-7
shpix   -18 37
IUP[y]
""",

    #to_tao
    "uni0E15": """
f_deltap    53 9+8   53 10+8   53 12+8
SRP0    52
MIRP[rp0,rnd,grey]   gap_186 28
f_deltap    28 14+8 28 15+8 28 16+8   28 28-8
mdrp[rp0,rnd,grey]   31
f_deltap    31 13+8
shpix   -16 31
mirp[min,rnd,grey]  hstem 9
srp0    28
mirp[rp0,rnd,grey]  hstem   27
srp1    9
ip  12
mdrp[rp0,rnd,grey]  24
f_deltap   24 12+8   24 18-8   24 19-8    24 23-8   24 26-8   24 28-8 24 29-8   24 39-8 
mirp[min,rnd,grey]  headstem 43
f_deltap    43 27+4 43 28+4 43 29+4
mirp[rp0,rnd,grey]  headdia 18
f_deltap    18 19+8   18 24+8   18 25+8  18 26+8
ip  15
mirp[min,rnd,grey]  headstem 49
f_deltap    49 27-4 49 28-4 49 29-4
#
srp0    53
mirp[rp0,rnd,grey]  gap_164 39
mirp[min,rnd,grey]  hstem 1
srp1    9
sloop   7
ip  34 35 36 4 5 6 7
f_deltap    12 14-1 13 14+4  12 15-1 13 15+4  12 16-1  13 16+4
IUP[x]
#
shpix   -9  25
shpix   -27 23
shpix   -9  22
shpix   9   20
shpix   27  19
shpix   27  17
shpix   27  16
#
shpix   16  15
#
SVTCA[y-axis]
MDAP[rnd]   27
ALIGNRP     1
mirp[grey]  vstem 12
shpix   -16 12
MIRP[rp0,rnd,grey]  vheight_shoot  34
alignrp 36
MIRP[min,rnd,grey]  vstem_curve  7
shpix   16 7
f_deltap    7 17-4   7 18+4 7 19+3 7 20+2 7 21+2 7 22+2 7 23+2 7 24+2 7 25+2   7 26+1   7 29+6 7 30+6 7 31+6 7 32+6 7 33+6 7 34+6 7 35+6
shp[rp2]    4
mdrp[rp0,min,rnd,grey]  35
mdrp[rp0,grey]  6
shpix   -16 6
shpix   -16 35
mdrp[rp0,min,rnd,white]     21
mdap[rnd]   21
mirp[min,rnd,grey]      headstem 46
f_deltap    46 27+4 46 28+4 46 29+4
mirp[rp0,rnd,grey]      headdia 15
f_deltap    15 19+8   15 24+8 15 25+8 15 26+8
mirp[min,rnd,grey]      headstem 40
f_deltap    40 27-4 40 28-4 40 29-4
shpix   -18 40
IUP[y]
""",

    #to_tung
    "uni0E16": """
f_deltap    48 14-8   48 20-8   48 25-8   48 26+8 
srp0                47
mirp[rp0,rnd,grey]  gap_197 23
mdrp[grey]  27
mdrp[grey]  8
mirp[rp0,min,rnd,grey]  hstem  12
mdrp[grey]  10
mdrp[grey]  26
srp0    23
mirp[rp0,rnd,grey]  headdia_plus 18
mirp[min,rnd,grey]  headstem 38
f_deltap    38 27+4 38 28+4 38 29+4
mirp[rnd,grey]  headstem_plus_hole 44
f_deltap    44 27+4 44 28+4 44 29+4
#
srp0    48
mirp[rp0,rnd,grey]  gap_164 34
mirp[min,rnd,grey]  hstem  1
f_deltap    18 12-4  18 13-4
IUP[x]
shpix    9   22
shpix    -9  20
shpix    -18 19
shpix    -18 17
shpix    -9  16
#
shpix   -16 8
shpix   16  26
SVTCA[y-axis]
mdap[rnd]           1
mirp[rnd,grey]      vheight_lo  21
mirp[rp0,rnd,grey]  vheight_shoot    31
mdrp[grey]  28
mirp[rp0,min,rnd,grey]  vstem_curve  5
shpix   16 5
f_deltap    5 17-4   5 18+4 5 19+3 5 20+2 5 21+2 5 22+2 5 23+2 5 24+2 5 25+2   5 26+1   5 29+6 5 30+6 5 31+6 5 32+6 5 33+6 5 34+6 5 35+6
mdrp[grey]  27
ip  8
srp0    21
mirp[min,rnd,grey]  headstem 35
mirp[rp0,rnd,grey]  headdia 15
f_deltap    15 19-8   15 24-8 15 25-8 15 26-8   15 40-8 15 41-8   15 44+8 15 45+8
mirp[min,rnd,grey]  headstem 41
f_deltap    41 27+4 41 28+4 41 29+4
shpix    18  41
IUP[y]
""",

    #to_tahan
    "uni0E17": """
f_deltap    41 11-8  41 14-8  41 15-8  41 20-8  
srp0    40
mirp[rp0,rnd,white]  gap_340 9
mirp[rp0,min,rnd,grey]  hstem 20
alignrp 8
mirp[rp0,rnd,grey]  headdia_plus 15
mirp[min,rnd,grey]  headstem 37
f_deltap    37 27-4 37 28-4 37 29-4
mirp[rnd,grey]  headstem_plus_hole 31
f_deltap    31 27-4 31 28-4 31 29-4
#
srp0    41
mirp[rp0,rnd,grey]  gap_164 27
mirp[min,rnd,grey]  hstem 1
srp1   20
ip  23
srp0    23
mdrp[grey]  6
#
f_deltap    15 12+4  15 13+4
IUP[x]
shpix    -9  19
shpix    9   17
shpix    18  16
shpix    18  14
shpix    9   13
#
SVTCA[y-axis]
mdap[rnd]  1
alignrp 8
mirp[rp0,rnd,grey]  vheight_shoot 25
alignrp 18
ip  21
f_deltap    21 13-4  21 14-5  21 15-5
mirp[min,rnd,grey]  vstem_curve 4
shpix   16 4
f_deltap    4 17-4   4 18+4 4 19+3 4 20+2 4 21+2 4 22+2 4 23+2 4 24+2 4 25+2   4 26+1   4 29+6 4 30+6 4 31+6 4 32+6 4 33+6 4 34+6 4 35+6
srp0    18
mirp[min,rnd,grey]  headstem 34
f_deltap    34 27+4 34 28+4 34 29+4
mirp[rp0,rnd,grey]  headdia 12
f_deltap    12 19+8   12 24+8 12 25+8 12 26+8   12 40+8 12 41+8   12 44-8 12 45-8
mirp[min,rnd,grey]  headstem 28
f_deltap    28 27-4 28 28-4 28 29-4
shpix    -18 28
shpix    -18 21
IUP[y]
""",

    #to_thong
    "uni0E18": """
f_deltap    40 10+8   40 14-8   40 21-8
srp0    39
mirp[rp0,min,rnd,grey] gap_205 1
mdrp[grey]  11
mdrp[grey]  33
shpix   -16 33
mirp[rp0,min,rnd,grey]  hstem 3
#
srp0    40
mirp[rp0,rnd,grey]  gap_164 36
mirp[min,rnd,grey]  hstem 7
mdrp[grey]  23
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]  0
mirp[min,rnd,grey]  vstem 5
mirp[rp0,rnd,grey]  vheight_shoot 15
mdrp[grey]  20
ip  22
mdrp[grey]  12
mirp[rp0,min,rnd,grey]  vstem_curve 30
shpix   16 30
f_deltap    30 17-4   30 18+4 30 19+3 30 20+2 30 21+2 30 22+2 30 23+2 30 24+2 30 25+2   30 26+1   30 29+6 30 30+6 30 31+6 30 32+6 30 33+6 30 34+6 30 35+6
mdrp[grey]  25
ip  23
mdrp[rp0,grey]  11
mdrp[grey]  10
mdrp[rp0,grey]  33
mdrp[grey]  34
srp0    11
mdrp[grey]  3
IUP[y]
""",

    #no_nu
    "uni0E19": """
f_deltap    56 10-8  56 17+8
srp0    55
mirp[rp0,rnd,white] gap_340 1
mirp[rp0,min,rnd,grey]  hstem 12
alignrp     0
mirp[rp0,rnd,grey]  headdia_plus 7
mirp[min,rnd,grey]  headstem 40
f_deltap    40 27-4 40 28-4 40 29-4
mirp[rnd,grey]  headstem_plus_hole 34
f_deltap    34 27-4 34 28-4 34 29-4
#
srp0    56
mirp[rp0,rnd,white]  gap_240 17
f_deltap    17 20-8
mirp[min,rnd,grey]  hstem 15
mdrp[rp0,rnd,grey]  21
f_deltap    21 21-8  21 27-8
mirp[min,rnd,grey]  headstem 46
f_deltap    46 27+4 46 28+4 46 29+4
mirp[rp0,rnd,grey]  headdia 27
f_deltap    27 24+8 27 25+8
mirp[min,rnd,grey]  headstem 52
f_deltap    52 26+8   52 27-4 52 28-4 52 29-4  
#
f_deltap    7 12+4  7 13+4
IUP[x]
shpix    -9  11
shpix    9   9
shpix    18  8
shpix    18  6
shpix    9   5
#
shpix   -9  20
shpix   -18 22
shpix   -9  23
shpix   9   25
shpix   18  26
#
SVTCA[y-axis]
mdap[rnd]  0
mirp[min,rnd,grey]  vstem_curve 13
mirp[rnd,grey]  vheight_lo 24
mirp[rnd,grey]  vheight 17
mirp[rp0,rnd,grey]  vheight_shoot 10
mirp[min,rnd,grey]  headstem 37
f_deltap    37 27+4 37 28+4 37 29+4
mirp[rp0,rnd,grey]  headdia 4
f_deltap    4 19+8   4 24+8 4 25+8 4 26+8   4 40+8 4 41+8   4 44-8 4 45-8
mirp[min,rnd,grey]  headstem 31
f_deltap    31 27-4 31 28-4 31 29-4
shpix    -18 31
#
srp0    24
mirp[min,rnd,grey]  headstem 43
f_deltap    43 27-4 43 28-4 43 29-4
mirp[rp0,rnd,grey]  headdia 18
f_deltap    18 24-8 18 25-8 18 26-8
alignrp     15
mirp[min,rnd,grey]  headstem 49
f_deltap    49 27+4 49 28+4 49 29+4
srp0    15
mdrp[grey]  29
shpix   -16 15
shpix   16  29
shpix   16  49
IUP[y]
""",

    #bo_baimai
    "uni0E1A": """
f_deltap    30 15-8  30 19-8  30 21-8  
srp0    29
mirp[rp0,rnd,white] gap_340 1
mirp[rp0,min,rnd,grey]  hstem 12
mirp[rp0,rnd,grey]  headdia_plus 7
mirp[min,rnd,grey]  headstem 26
f_deltap    26 27-4 26 28-4 26 29-4
mirp[rnd,grey]  headstem_plus_hole 20
f_deltap    20 27-4 20 28-4 20 29-4
#
srp0    30
mirp[rp0,rnd,grey]  gap_164 16
mirp[min,rnd,grey]  hstem 14
f_deltap    7 12+4  7 13+4
IUP[x]
shpix    -9  11
shpix    9   9
shpix    18  8
shpix    18  6
shpix    9   5
#
SVTCA[y-axis]
mdap[rnd]  0
mirp[min,rnd,grey]  vstem 14
mirp[rnd,grey]  vheight 16
mirp[rp0,rnd,grey]  vheight_shoot 10
mirp[min,rnd,grey]  headstem 23
f_deltap    23 27+4 23 28+4 23 29+4
mirp[rp0,rnd,grey]  headdia 4
f_deltap    4 19+8   4 24+8 4 25+8 4 26+8   4 40+8 4 41+8   4 44-8 4 45-8
mirp[min,rnd,grey]  headstem 17
f_deltap    17 27-4 17 28-4 17 29-4
shpix    -18 17
IUP[y]
""",

    #po_pla
    "uni0E1B": """
f_deltap    30 15-8  30 19-8  30 21-8
srp0    29
mirp[rp0,rnd,white] gap_340 1
mirp[rp0,min,rnd,grey]  hstem 12
mirp[rp0,rnd,grey]  headdia_plus 7
mirp[min,rnd,grey]  headstem 26
f_deltap    26 27-4 26 28-4 26 29-4
mirp[rnd,grey]  headstem_plus_hole 20
f_deltap    20 27-4 20 28-4 20 29-4
#
srp0    30
mirp[rp0,rnd,grey]  gap_164 16
mirp[min,rnd,grey]  hstem 14
f_deltap    7 12+4  7 13+4
IUP[x]
shpix    -9  11
shpix    9   9
shpix    18  8
shpix    18  6
shpix    9   5
#
SVTCA[y-axis]
mdap[rnd]  0
mirp[min,rnd,grey]  vstem 14
mirp[rnd,grey]  vheight_po 16
mirp[rp0,rnd,grey]  vheight_shoot 10
mirp[min,rnd,grey]  headstem 23
f_deltap    23 27+4 23 28+4 23 29+4
mirp[rp0,rnd,grey]  headdia 4
f_deltap    4 19+8   4 24+8 4 25+8 4 26+8   4 40+8 4 41+8   4 44-8 4 45-8
mirp[min,rnd,grey]  headstem 17
f_deltap    17 27-4 17 28-4 17 29-4
shpix    -18 17
IUP[y]
""",

    #po_phung
    "uni0E1C": """
f_deltap    35 13-8   35 15-8   35 16-8   
srp0    34
mirp[rp0,rnd,grey]  gap_186 4
mirp[min,rnd,grey]  hstem 15
shp[rp2]    3
mirp[rp0,rnd,grey]  headdia_plus 10
mirp[min,rnd,grey]  headstem 25
f_deltap    25 27+4 25 28+4 25 29+4
mirp[rnd,grey]  headstem_plus_hole 31
f_deltap    31 27+4 31 28+4 31 29+4
#
srp0    35
mirp[rp0,rnd,grey]  gap_164 21
mirp[min,rnd,grey]  hstem   19
shp[rp2]    1
srp1    15
sloop 3
ip  17 2 18
f_deltap    10 12-4  10 13-4
IUP[x]
shpix    9  6
shpix    -9   8
shpix    -18  9
shpix    -18  11
shpix    -9   12
#
SVTCA[y-axis]
mdap[rnd]   1
alignrp     3
mirp[rnd,grey]  vheight 21
mirp[rp0,rnd,grey]  vheight_shoot 7
mirp[min,rnd,grey]  headstem 28
f_deltap    28 27+4 28 28+4 28 29+4
mirp[rp0,rnd,grey]  headdia 13
f_deltap    13 19+8   13 24+8 13 25+8 13 26+8   13 40+8 13 41+8   13 44-8 13 45-8
mirp[min,rnd,grey]  headstem 22
f_deltap    22 27-4 22 28-4 22 29-4
shpix    -18 22
mdrp[rp0,rnd,white] 17
mirp[min,rnd,grey]  vstem 2
srp2    0
ip  19
ip  16
shpix   16  2
shpix   -16 16
shpix   -16 19
IUP[y]
""",

    #fo_fa
    "uni0E1D": """
f_deltap    35 13-8   35 15-8   35 16-8
srp0    34
mirp[rp0,rnd,grey]  gap_186 4
mirp[min,rnd,grey]  hstem 15
shp[rp2]    3
mirp[rp0,rnd,grey]  headdia_plus 10
mirp[min,rnd,grey]  headstem 25
f_deltap    25 27+4 25 28+4 25 29+4
mirp[rnd,grey]  headstem_plus_hole 31
f_deltap    31 27+4 31 28+4 31 29+4
#
srp0    35
mirp[rp0,rnd,grey]  gap_164 21
mirp[min,rnd,grey]  hstem   19
shp[rp2]    1
srp1    15
sloop 3
ip  17 2 18
f_deltap    10 12-4  10 13-4
IUP[x]
shpix    9  6
shpix    -9   8
shpix    -18  9
shpix    -18  11
shpix    -9   12
#
SVTCA[y-axis]
mdap[rnd]   1
alignrp     3
mirp[rnd,grey]  vheight_po 21
mirp[rp0,rnd,grey]  vheight_shoot 7
mirp[min,rnd,grey]  headstem 28
f_deltap    28 27+4 28 28+4 28 29+4
mirp[rp0,rnd,grey]  headdia 13
f_deltap    13 19+8   13 24+8 13 25+8 13 26+8   13 40+8 13 41+8   13 44-8 13 45-8
mirp[min,rnd,grey]  headstem 22
f_deltap    22 27-4 22 28-4 22 29-4
shpix    -18 22
mdrp[rp0,rnd,white] 17
mirp[min,rnd,grey]  vstem 2
srp2    0
ip  19
ip  16
shpix   16  2
shpix   -16 16
shpix   -16 19
IUP[y]
""",

    #po_pan
    "uni0E1E": """
f_deltap    35 11-8   35 15-8  35 22+8   
srp0    34
mirp[rp0,rnd,white] gap_340 4
mirp[rp0,min,rnd,grey]  hstem 15
mirp[rp0,rnd,grey]  headdia_plus 10
mirp[min,rnd,grey]  headstem 31
f_deltap    31 27-4 31 28-4 31 29-4
mirp[rnd,grey]  headstem_plus_hole 25
f_deltap    25 27-4 25 28-4 25 29-4
#
srp0    35
mirp[rp0,rnd,grey]  gap_164 21
mirp[min,rnd,grey]  hstem   19
srp1    15
sloop   5
ip      3 1 17 2 18 
f_deltap    10 12+4  10 13+4
IUP[x]
shpix    -9  14
shpix    9   12
shpix    18  11
shpix    18  9
shpix    9   8
#
SVTCA[y-axis]
mdap[rnd]   1
alignrp     3
mdrp[grey]  19
shp[rp2]    16
mirp[rnd,grey]  vheight 21
mirp[rp0,rnd,grey]  vheight_shoot 13
ip  17
ip  2
mirp[min,rnd,grey]  headstem 28
f_deltap    28 27+4 28 28+4 28 29+4
mirp[rp0,rnd,grey]  headdia 7
f_deltap    7 19+8   7 24+8 7 25+8 7 26+8   7 40+8 7 41+8   7 44-8 7 45-8
mirp[min,rnd,grey]  headstem 22
f_deltap    22 27-4 22 28-4 22 29-4
shpix    -18 22
shpix   16  2
shpix   -16 16
shpix   -16 19
IUP[y]
""",

    #fo_fun
    "uni0E1F": """
f_deltap    35 11-8   35 15-8  35 22+8
srp0    34
mirp[rp0,rnd,white] gap_340 4
mirp[rp0,min,rnd,grey]  hstem 15
mirp[rp0,rnd,grey]  headdia_plus 10
mirp[min,rnd,grey]  headstem 31
f_deltap    31 27-4 31 28-4 31 29-4
mirp[rnd,grey]  headstem_plus_hole 25
f_deltap    25 27-4 25 28-4 25 29-4
#
srp0    35
mirp[rp0,rnd,grey]  gap_164 21
mirp[min,rnd,grey]  hstem   19
srp1    15
sloop   5
ip      3 1 17 2 18
f_deltap    10 12+4  10 13+4
IUP[x]
shpix    -9  14
shpix    9   12
shpix    18  11
shpix    18  9
shpix    9   8
#
SVTCA[y-axis]
mdap[rnd]   1
alignrp     3
mdrp[grey]  19
shp[rp2]    16
mirp[rnd,grey]  vheight_po 21
mirp[rp0,rnd,grey]  vheight_shoot 13
ip  17
ip  2
mirp[min,rnd,grey]  headstem 28
f_deltap    28 27+4 28 28+4 28 29+4
mirp[rp0,rnd,grey]  headdia 7
f_deltap    7 19+8   7 24+8 7 25+8 7 26+8   7 40+8 7 41+8   7 44-8 7 45-8
mirp[min,rnd,grey]  headstem 22
f_deltap    22 27-4 22 28-4 22 29-4
shpix    -18 22
shpix   16  2
shpix   -16 16
shpix   -16 19
IUP[y]
""",

    #po_sampao
    "uni0E20": """
f_deltap    48 10-8  48 15-8  48 16-8  48 19-8  48 21-8  
srp0    47
mirp[rp0,rnd,white]  gap_340 23
mdrp[grey]  27
mdrp[grey]  8
mirp[rp0,min,rnd,grey]  hstem 13
mdrp[grey]  10
mdrp[grey]  26
mirp[rp0,rnd,grey]  headdia_plus 18
mirp[min,rnd,grey]  headstem    44
f_deltap    44 27-4 44 28-4 44 29-4
mirp[rnd,grey]  headstem_plus_hole 38
f_deltap    38 27-4 38 28-4 38 29-4
#
srp0    48
mirp[rp0,rnd,white]  gap_164 34
mirp[min,rnd,grey]  hstem   1
f_deltap    18 12+4  18 13+4
IUP[x]
shpix    -9  14
shpix    9   16
shpix    18  17
shpix    18  19
shpix    9   20
#
shpix    -16    8
shpix   16  26
#
SVTCA[y-axis]
mdap[rnd]  1
mirp[rnd,grey]  vheight_lo 15
mirp[rp0,rnd,grey]  vheight_shoot 31
mdrp[grey]  28
mirp[min,rnd,grey]  vstem_curve   5
shpix   16 5
f_deltap    5 17-4   5 18+4 5 19+3 5 20+2 5 21+2 5 22+2 5 23+2 5 24+2 5 25+2   5 26+1   5 29+6 5 30+6 5 31+6 5 32+6 5 33+6 5 34+6 5 35+6
mdrp[grey]  27
ip  8
srp0    15
mirp[min,rnd,grey]  headstem 35
f_deltap    35 27-4 35 28-4 35 29-4
mirp[rp0,rnd,grey]  headdia 21
f_deltap    21 19-8   21 24-8 21 25-8 21 26-8   21 40-8 21 41-8   21 44+8 21 45+8
#
mirp[min,rnd,grey]  headstem 41
shpix    18  41
f_deltap    41 27+4 41 28+4 41 29+4
IUP[y]
""",

    #mo_ma
    "uni0E21": """
f_deltap    56 11-8  56 15-8  56 20-8  56 32+8  
srp0    55
mirp[rp0,rnd,white]  gap_340 14
mirp[rp0,min,rnd,grey]  hstem 25
alignrp 3
mirp[rp0,rnd,grey]  headdia_plus 20
mirp[min,rnd,grey]  headstem 40
f_deltap    40 27-4 40 28-4 40 29-4
shp[rp2]    52
mirp[rnd,grey]  headstem_plus_hole 34
f_deltap    34 27-4 34 28-4 34 29-4
shp[rp2]    46
srp0    20
f_deltap    20 12+4  20 13+4
alignrp 9
#
srp0    56
mirp[rp0,rnd,white]  gap_164 30
mirp[min,rnd,grey]  hstem 28
shp[rp2]    1
IUP[x]
shpix    -9  24
shpix    9   22
shpix    18  21
shpix    18  19
shpix    9   18
#
shpix   9   11
shpix   18  10
shpix   18  8
shpix   9   7
shpix   -9  5
#
SVTCA[y-axis]
mdap[rnd]   1
mirp[min,rnd,grey]  vstem 28
mirp[rnd,grey]  vheight_lo 6
mirp[rnd,grey]  vheight 30
mirp[rp0,rnd,grey]  vheight_shoot 23
mirp[min,rnd,grey]  headstem 37
f_deltap    37 27+4 37 28+4 37 29+4
mirp[rp0,rnd,grey]  headdia 17
f_deltap    17 19+8   17 24+8 17 25+8 17 26+8   17 40+8 17 41+8   17 44-8 17 45-8
mirp[min,rnd,grey]  headstem 31
f_deltap    31 27-4 31 28-4 31 29-4
#
srp0    6
mdrp[min,rnd,grey]  43
mdrp[rp0,rnd,grey]  12
f_deltap    12 13-8
mdrp[min,rnd,grey]  49
mdrp[rp0,rnd,grey]  26
mdrp[min,rnd,grey]  3
shpix    -18 31
shpix   16  3
shpix   -16 26
shpix   -16 12
IUP[y]
""",

    #yo_yak
    "uni0E22": """
f_deltap    47 9+8   47 16-8   47 17+8   47 21-8   
srp0    46
mirp[rp0,rnd,grey]  gap_186 1
mdrp[grey]  4
mdrp[rnd,grey]  7
mirp[rp0,min,rnd,grey]  hstem 29
mdrp[grey]  26
mdrp[rp0,rnd,grey]  19
f_deltap    19 13+8 19 14+8 19 15+8 19 16+8
mdrp[grey]  21
mdrp[rp0,rnd,grey]  13
f_deltap    13 26-8
mirp[min,rnd,grey]  headstem 37
f_deltap    37 27+4 37 28+4 37 29+4
mirp[min,rnd,grey]  headstem_plus_hole 43
f_deltap    43 27+4 43 28+4 43 29+4
#
srp0    47
mirp[rp0,rnd,grey]  gap_164 33
mirp[min,rnd,grey]  hstem 31
shpix   -8 7
shpix   -16 21
shpix   16   4
shpix   -18 43
f_deltap    7 18-2  7 19-2  7 20-2  7 21+6  7 22+6 7 23+6 7 24+6 7 25+6 7 26+6 7 27+6   
IUP[x]
shpix   9   9
shpix   -9   11
shpix   -18  12
shpix   -18 14
shpix   -9  15
shpix   9   17
shpix   18  18
#
SVTCA[y-axis]
mdap[rnd] 0
mirp[min,rnd,grey]  vstem 31
mirp[rnd,grey]      vheight 33
mirp[rp0,rnd,grey]  vheight_shoot 10
mdrp[grey]  19
mirp[min,rnd,grey]  headstem 40
f_deltap    40 27+4 40 28+4 40 29+4
mirp[rp0,rnd,grey]  headdia 16
f_deltap    16 19+8   16 24+8 16 25+8 16 26+8
mirp[min,rnd,grey]  headstem 34
f_deltap    34 27-4 34 28-4 34 29-4
srp2    30
ip      25
mdap[rnd]   25
f_deltap    25 9+4 25 10+4  25 20+8  25 21+8  25 30+8 25 31+8  25 35+8 
mdrp[min,rnd,grey]  26
ip  4
shpix   16  19
f_deltap    19 14+4 19 15+4 19 16+4   19 20+2   19 26+4 
f_deltap    22 14-3 22 15-5 22 16-1
IUP[y]
shpix   -18 22
""",

    #ro_ruar
    "uni0E23": """
srp0    52
mirp[rp0,white]  gap_113 12
mdrp[grey]  34
#
srp0    53
mirp[rp0,rnd,white]  gap_240 37
mirp[min,rnd,grey]  hstem 8
mdrp[grey]  24
mirp[rp0,rnd,grey]  headdia_plus 3
mirp[min,rnd,grey]  headstem 49
f_deltap    49 27-4 49 28-4 49 29-4
mirp[rnd,grey]  headstem_plus_hole 43
f_deltap    43 27-4 43 28-4 43 29-4
f_deltap    3 12+4  3 13+4
IUP[x]
shpix    -9  39
shpix    9   1
shpix    18  2
shpix    18  4
shpix    9   5
#
shpix   -16 34
#
SVTCA[y-axis]
mdap[rnd]   52
mirp[rnd,grey]  vheight_lo  0
mirp[rp0,rnd,grey]  vheight_shoot 16
mdrp[grey]  21
ip  23
mdrp[grey]  13
mirp[rp0,min,rnd,grey]  vstem_curve 31
shpix   16 31
f_deltap    31 17-4   31 18+4 31 19+3 31 20+2 31 21+2 31 22+2 31 23+2 31 24+2 31 25+2   31 26+1   31 29+6 31 30+6 31 31+6 31 32+6 31 33+6 31 34+6 31 35+6
mdrp[grey]  26
ip  24
mdrp[rp0,grey]  12
ip  34
mdrp[grey]      11
srp0    34
mdrp[grey]  35
srp0    0
mirp[min,rnd,grey]  headstem 40
f_deltap    40 27-4 40 28-4 40 29-4
mirp[rp0,rnd,grey]  headdia 6
f_deltap    6 19-8   6 24-8 6 25-8 6 26-8   6 40-8 6 41-8   6 44+8 6 45+8
mirp[min,rnd,grey]  headstem 46
f_deltap    46 27+4 46 28+4 46 29+4
shpix    18  46
IUP[y]
""",

    #lo_lu
    "uni0E24": """
f_deltap    48 14-8   48 20-8   48 25-8   48 26+8
srp0                47
mirp[rp0,rnd,grey]  gap_197 23
mdrp[grey]  27
mdrp[grey]  8
mirp[rp0,min,rnd,grey]  hstem  12
mdrp[grey]  10
mdrp[grey]  26
srp0    23
mirp[rp0,rnd,grey]  headdia_plus 18
mirp[min,rnd,grey]  headstem 38
f_deltap    38 27+4 38 28+4 38 29+4
mirp[rnd,grey]  headstem_plus_hole 44
f_deltap    44 27+4 44 28+4 44 29+4
#
srp0    48
mirp[rp0,rnd,grey]  gap_164 34
mirp[min,rnd,grey]  hstem  1
f_deltap    18 12-4  18 13-4
IUP[x]
shpix    9   22
shpix    -9  20
shpix    -18 19
shpix    -18 17
shpix    -9  16
#
shpix   -16 8
shpix   16  26
SVTCA[y-axis]
mdap[rnd]           47
mirp[rnd,grey]      vheight_lu  1
mirp[rnd,grey]      vheight_lo  21
mirp[rp0,rnd,grey]  vheight_shoot    31
mdrp[grey]  28
mirp[rp0,min,rnd,grey]  vstem_curve  5
shpix   16 5
f_deltap    5 17-4   5 18+4 5 19+3 5 20+2 5 21+2 5 22+2 5 23+2 5 24+2 5 25+2   5 26+1   5 29+6 5 30+6 5 31+6 5 32+6 5 33+6 5 34+6 5 35+6
mdrp[grey]  27
ip  8
srp0    21
mirp[min,rnd,grey]  headstem 35
mirp[rp0,rnd,grey]  headdia 15
f_deltap    15 19-8   15 24-8 15 25-8 15 26-8   15 40-8 15 41-8   15 44+8 15 45+8
mirp[min,rnd,grey]  headstem 41
f_deltap    41 27+4 41 28+4 41 29+4
shpix    18  41
IUP[y]
""",

    #lo_ling
    "uni0E25": """
f_deltap    52 9+8  52 16-8  52 18-8 
srp0    51
mirp[rp0,rnd,white] gap_143 17
mdrp[grey]  31
mirp[min,rnd,grey]  hstem 6
mirp[rp0,rnd,grey]  headdia_plus 12
mirp[min,rnd,grey]  headstem 42
f_deltap    42 27+4 42 28+4 42 29+4
mirp[rnd,grey]  headstem_plus_hole 48
f_deltap    48 27+4 48 28+4 48 29+4
#
srp0    52
mirp[rp0,rnd,grey]  gap_164 38
mirp[min,rnd,grey]  hstem 24
shp[rp2]    1
f_deltap    12 12-4  12 13-4
IUP[x]
shpix    9   16
shpix    -9  14
shpix    -18 13
shpix    -18 11
shpix    -9  10
#
SVTCA[y-axis]
mdap[rnd]  1
mirp[rnd,grey]  vheight_lo 15
mdrp[grey]  24
mirp[rp0,rnd,grey]  vheight_shoot 35
mdrp[grey]  32
mirp[rp0,min,rnd,grey]  vstem_curve 28
shpix   16 28
f_deltap    28 17-4   28 18+4 28 19+3 28 20+2 28 21+2 28 22+2 28 23+2 28 24+2 28 25+2   28 26+1   28 29+6 28 30+6 28 31+6 28 32+6 28 33+6 28 34+6 28 35+6
mdrp[grey]  31
mdrp[rp0,rnd,grey]  21
mdap[rnd]   21
f_deltap    21 16-8  21 17-8  21 23-8  21 24-8  21 25-8  
mirp[min,rnd,grey]  vstem  4
shpix   16 4
f_deltap    4 17-4   4 20+2 4 21+2 4 22+2 4 23+2 4 24+2 4 25+2   4 26+1   4 34+6 4 35+6
#
srp0    15
mirp[min,rnd,grey]  headstem 39
f_deltap    39 27-4 39 28-4 39 29-4
mirp[rp0,rnd,grey]  headdia 9
f_deltap    9 19-8   9 24-8 9 25-8 9 26-8   9 40-8 9 41-8   9 44+8 9 45+8
#
mirp[min,rnd,grey]  headstem 45
f_deltap    45 27+4 45 28+4 45 29+4
shpix    18  45
IUP[y]
""",

    #ro_ru
    "uni0E26": """
f_deltap    48 10-8  48 15-8  48 16-8  48 19-8  48 21-8
srp0    47
mirp[rp0,rnd,white]  gap_340 23
mdrp[grey]  27
mdrp[grey]  8
mirp[rp0,min,rnd,grey]  hstem 13
mdrp[grey]  10
mdrp[grey]  26
mirp[rp0,rnd,grey]  headdia_plus 18
mirp[min,rnd,grey]  headstem    44
f_deltap    44 27-4 44 28-4 44 29-4
mirp[rnd,grey]  headstem_plus_hole 38
f_deltap    38 27-4 38 28-4 38 29-4
#
srp0    48
mirp[rp0,rnd,white]  gap_164 34
mirp[min,rnd,grey]  hstem   1
f_deltap    18 12+4  18 13+4
IUP[x]
shpix    -9  14
shpix    9   16
shpix    18  17
shpix    18  19
shpix    9   20
#
shpix    -16    8
shpix   16  26
#
SVTCA[y-axis]
mdap[rnd]  47
mirp[rnd,grey]  vheight_lu  1
mirp[rnd,grey]  vheight_lo 15
mirp[rp0,rnd,grey]  vheight_shoot 31
mdrp[grey]  28
mirp[min,rnd,grey]  vstem_curve   5
shpix   16 5
f_deltap    5 17-4   5 18+4 5 19+3 5 20+2 5 21+2 5 22+2 5 23+2 5 24+2 5 25+2   5 26+1   5 29+6 5 30+6 5 31+6 5 32+6 5 33+6 5 34+6 5 35+6
mdrp[grey]  27
ip  8
srp0    15
mirp[min,rnd,grey]  headstem 35
f_deltap    35 27-4 35 28-4 35 29-4
mirp[rp0,rnd,grey]  headdia 21
f_deltap    21 19-8   21 24-8 21 25-8 21 26-8   21 40-8 21 41-8   21 44+8 21 45+8
#
mirp[min,rnd,grey]  headstem 41
shpix    18  41
f_deltap    41 27+4 41 28+4 41 29+4
IUP[y]
""",

    #wo_wan
    "uni0E27": """
srp0    37
mirp[rp0,white] gap_51  15
#
srp0    38
mirp[rp0,rnd,white]  gap_164 22
mirp[min,rnd,grey]  hstem 8
mirp[rp0,rnd,grey]  headdia_plus 3
mirp[min,rnd,grey]  headstem 34
f_deltap    34 27-4 34 28-4 34 29-4
mirp[rnd,grey]  headstem_plus_hole 28
f_deltap    28 27-4 28 28-4 28 29-4
f_deltap    28 12+4  28 13+4
IUP[x]
shpix    -9  24
shpix    9   26
shpix    18  27
shpix    18  29
shpix    9   30
#
SVTCA[y-axis]
mdap[rnd]    37
mirp[rnd,grey]  vheight_lo 0
mirp[rp0,rnd,grey]  vheight_shoot 19
mdrp[grey]  16
mirp[rp0,min,rnd,grey]  vstem_curve   12
shpix   16 12
f_deltap    12 17-4   12 18+4 12 19+3 12 20+2 12 21+2 12 22+2 12 23+2 12 24+2 12 25+2   12 26+1   12 29+6 12 30+6 12 31+6 12 32+6 12 33+6 12 34+6 12 35+6
mdrp[grey]  15
srp0    0
mirp[min,rnd,grey]  headstem 25
f_deltap    25 27-4 25 28-4 25 29-4
mirp[rp0,rnd,grey]  headdia 6
f_deltap    6 19-8   6 24-8 6 25-8 6 26-8   6 40-8 6 41-8   6 44+8 6 45+8
mirp[min,rnd,grey]  headstem 31
f_deltap    31 27+4 31 28+4 31 29+4
shpix    18  31
IUP[y]
""",

    #so_sala
    "uni0E28": """
f_deltap    64 9+8  64 10+8   64 15-8   64 17+8  64 21-8  
srp0                63
mirp[rp0,rnd,grey]  gap_164 35
mdrp[rp0,rnd,grey]  38
shpix   -8  38
f_deltap    38 17+4 38 18+4 38 19+4 38 20+4 38 21+4 
mirp[min,rnd,grey]  hstem 14
shpix   -16  14
srp0    35
mirp[rp0,min,rnd,grey]  hstem 34
srp1    14
ip  17
mdrp[rp0,rnd,grey]  26
f_deltap    26 11-8  26 12+8 26 13+8  26 14+8  26 15+8   26 26-8  26 27-8 26 29-8  26 33-8 26 38-8 
mirp[min,rnd,grey]  headstem 54
f_deltap    54 27+4 54 28+4 54 29+4
mirp[rp0,rnd,grey]  headstem_plus_hole 60
f_deltap    60 27+4 60 28+4 60 29+4
mdrp[grey]  31
mdrp[grey]  20
#
srp0    64
mirp[rp0,rnd,grey]  gap_186 50
mirp[min,rnd,grey]  hstem 1
f_deltap    26 12-8 26 13-8
IUP[x]
shpix   9   22
shpix   -9  24
shpix   -18 25
shpix   -18 27
shpix   -9  28
shpix   9   30
shpix   -9  60
#
shpix   16  9
shpix   -16 48
#
SVTCA[y-axis]
MDAP[rnd]           0
ALIGNRP             34 
MIRP[rp0,rnd,grey]  vheight_shoot  41     
mdrp[min,rnd,grey]  45
mdrp[grey]  43
mdrp[grey]  48
MIRP[rp0,min,rnd,grey]  vstem_curve  11
shpix   16 11
f_deltap    11 17-4   11 18+4 11 19+3 11 20+2 11 21+2 11 22+2 11 23+2 11 24+2 11 25+2   11 26+1   11 29+6 11 30+6 11 31+6 11 32+6 11 33+6 11 34+6 11 35+6
mdrp[grey]  9
mdrp[grey]  4
MDRP[rp0,rnd,grey]  23
mdap[rnd]   23
f_deltap    23 16-8  23 17-8  23 23-8  23 24-8 23 25-8  23 40-8
srp1    11
ip  6
ip  7
MIRP[min,rnd,grey]  headstem  57    
f_deltap    57 27+4 57 28+4 57 29+4
MIRP[rp0,rnd,grey]  headdia  29    
f_deltap    29 19+8  29 24+8 29 25+8 29 26+8   29 40+8 29 41+8   29 44-8 29 45-8
mdrp[grey]  17
mdrp[grey]  31
f_deltap    17 14-5 31 14+3   17 15-5 31 15+3   17 16-5 31 16+3 33 16+8
MIRP[min,rnd,grey]  headstem  51    
f_deltap    51 27-4 51 28-4 51 29-4
shpix   -18 51
IUP[y]
shpix   9   4
shpix   -9  43
""",

    #so_lusi
    "uni0E29": """
f_deltap    65 11-8  65 14-8  65 17+8  65 18+8  65 26+8  65 28+8  65 36+8  65 37+8  
srp0    64
mirp[rp0,rnd,white] gap_340 1
mirp[rp0,min,rnd,grey]  hstem 12
mirp[rp0,rnd,grey]  headdia_plus 7
mirp[min,rnd,grey]  headstem 49
f_deltap    49 27-4 49 28-4 49 29-4
mirp[rnd,grey]  headstem_plus_hole 43
f_deltap    43 27-4 43 28-4 43 29-4
#
srp0    65
mirp[rp0,rnd,grey]  gap_205 33
alignrp 39
mdrp[grey]  37
ip  36
mirp[min,rnd,grey]  hstem 31
shp[rp2]    14
srp1    12
ip  20
mdap[rnd]   20
mdrp[rnd,grey]  26
f_deltap    26 17-8 26 18-8 26 19-8  
ip  61
ip  55
#
f_deltap    7 12+4  7 13+4
IUP[x]
shpix    -9  11
shpix    9   9
shpix    18  8
shpix    18  6
shpix    9   5
#
SVTCA[y-axis]
mdap[rnd]  0
mirp[min,rnd,grey]  vstem 14
mirp[rnd,grey]  vheight 33
mirp[rp0,rnd,grey]  vheight_shoot 10
ip  23
mirp[min,rnd,grey]  headstem 46
f_deltap    46 27+4 46 28+4 46 29+4
mirp[rp0,rnd,grey]  headdia 4
f_deltap    4 19+8   4 24+8 4 25+8 4 26+8   4 40+8 4 41+8   4 44-8 4 45-8
mirp[min,rnd,grey]  headstem 40
f_deltap    40 27-4 40 28-4 40 29-4
shpix    -18 40
#
mdap[rnd]   23
mdrp[rnd,grey]  28
sloop   6
ip  58 52 34 36 37 39
mdrp[grey]  17
ip  31
ip  15
#
IUP[y]
shpix   -12  34
shpix   8   18
""",

    #so_sua
    "uni0E2A": """
f_deltap    64 9+8  64 16-8  64 17+8 
srp0    63
mirp[rp0,rnd,white] gap_143 17
mdrp[grey]  37
mirp[min,rnd,grey]  hstem 6
mirp[rp0,rnd,grey]  headdia_plus 12
mirp[min,rnd,grey]  headstem 54
f_deltap    54 27+4 54 28+4 54 29+4
mirp[rnd,grey]  headstem_plus_hole 60
f_deltap    60 27+4 60 28+4 60 29+4
#
srp0    64
mirp[rp0,rnd,grey]  gap_186 50
mdrp[grey]  46
ip  45
mirp[rp0,min,rnd,grey]  hstem 24
shp[rp2]    1
sloop   4
ip  43 48 32 27
mdrp[grey]  30
mdrp[grey]  29
#
f_deltap    12 12-4  12 13-4
IUP[x]
shpix    9   16
shpix    -9  14
shpix    -18 13
shpix    -18 11
shpix    -9  10
#
shpix   18  32
shpix   -18 48
#
SVTCA[y-axis]
mdap[rnd]  1
mirp[rnd,grey]  vheight_lo 15
mdrp[grey]  24
mirp[rp0,rnd,grey]  vheight_shoot 41
mdrp[min,rnd,grey]  45
mdrp[grey]  38
mdrp[grey]  43
mdrp[grey]  48
mirp[rp0,min,rnd,grey]  vstem_curve 34
shpix   16 34
f_deltap    34 17-4   34 18+4 34 19+3 34 20+2 34 21+2 34 22+2 34 23+2 34 24+2 34 25+2   34 26+1   34 29+6 34 30+6 34 31+6 34 32+6 34 33+6 34 34+6 34 35+6
mdrp[grey]  37
mdrp[grey]  32
mdrp[grey]  27
mdrp[rp0,rnd,grey]  21
mdap[rnd]   21
f_deltap    21 16-8  21 17-8  21 23-8  21 24-8  21 25-8
srp1    34
ip  30
ip  29
mirp[min,rnd,grey]  vstem  4
shpix   16 4
f_deltap    4 17-4   4 20+2 4 21+2 4 22+2 4 23+2 4 24+2 4 25+2   4 26+1   4 34+6 4 35+6
#
srp0    15
mirp[min,rnd,grey]  headstem 51
f_deltap    51 27-4 51 28-4 51 29-4
mirp[rp0,rnd,grey]  headdia 9
f_deltap    9 19-8   9 24-8 9 25-8 9 26-8   9 40-8 9 41-8   9 44+8 9 45+8
#
mirp[min,rnd,grey]  headstem 57
f_deltap    57 27+4 57 28+4 57 29+4
shpix    18  57
IUP[y]
shpix   -9  43
shpix   9   27
""",

    #ho_hib
    "uni0E2B": """
f_deltap    65 11-8  65 14-8  65 15-8  65 20-8
srp0    64
mirp[rp0,rnd,white]  gap_340 9
mirp[rp0,min,rnd,grey]  hstem 20
alignrp 8
mirp[rp0,rnd,grey]  headdia_plus 15
mirp[min,rnd,grey]  headstem 49
f_deltap    49 27-4 49 28-4 49 29-4
mirp[rnd,grey]  headstem_plus_hole 43
f_deltap    43 27-4 43 28-4 43 29-4
#
srp0    65
mirp[rp0,rnd,grey]  gap_164 39
mirp[min,rnd,grey]  hstem 1
srp1   20
ip  23
srp0    23
mdrp[grey]  6
srp0    39
mdrp[rp0,rnd,grey]  34
mirp[min,rnd,grey]  headstem 55
f_deltap    55 27+4 55 28+4 55 29+4
mirp[rp0,rnd,grey]  headdia 28
f_deltap    28 19+8  28 24+8  28 25+8  28 26+8  28 40+8  28 41+8
ip  25
ip  37
mirp[min,rnd,grey]  headstem 61
f_deltap    61 27-4 61 28-4 61 29-4
#
f_deltap    15 12+4  15 13+4
IUP[x]
shpix    -9  19
shpix    9   17
shpix    18  16
shpix    18  14
shpix    9   13
#
shpix   9   27
shpix   18  29
shpix   9   30
shpix   -9  32
shpix   -18 33
shpix   -9  35
#
shpix   16  25
shpix   -16 37
#
SVTCA[y-axis]
mdap[rnd]  1
alignrp 8
mirp[rp0,rnd,grey]  vheight_shoot 18
alignrp 31
mirp[min,rnd,grey]  headstem 46
f_deltap    46 27+4 46 28+4 46 29+4
shp[rp2]    58
mirp[rp0,rnd,grey]  headdia 12
f_deltap    12 19+8   12 24+8 12 25+8 12 26+8   12 40+8 12 41+8   12 44-8 12 45-8
mirp[min,rnd,grey]  headstem 40
f_deltap    40 27-4 40 28-4 40 29-4
shp[rp2]    52
srp0    52
mdrp[min,rnd,grey]  4
ip  25
ip  37
shpix    -18 40
shpix    -18 52
shpix    -18 21
shpix    18  4 
IUP[y]
""",

    #lo_jula
    "uni0E2C": """
f_deltap    62 17+8   
srp0    61
mirp[rp0,rnd,white] gap_340 4
mirp[rp0,min,rnd,grey]  hstem 15
mirp[rp0,rnd,grey]  headdia_plus 10
mirp[min,rnd,grey]  headstem 46
f_deltap    46 27-4 46 28-4 46 29-4
mirp[rnd,grey]  headstem_plus_hole 40
f_deltap    40 27-4 40 28-4 40 29-4
#
srp0    62
mirp[rp0,rnd,grey]  gap_205 36
alignrp 30
mdrp[grey]  34
ip  33
mirp[min,rnd,grey]  hstem   19
srp1    15
sloop   5
ip      3 1 17 2 18
#
srp0    30
mirp[min,rnd,grey]  headstem 52
f_deltap    52 27+4 52 28+4 52 29+4
mirp[rp0,rnd,grey]  headdia 24
f_deltap    24 19+8  24 24+8  24 25+8  24 26+8  24 40+8  24 41+8
mirp[min,rnd,grey]  headstem 58
f_deltap    58 27-4 58 28-4 58 29-4
#
f_deltap    10 12+4  10 13+4
IUP[x]
shpix    -9  14
shpix    9   12
shpix    18  11
shpix    18  9
shpix    9   8
#
shpix   9   22
shpix   18  23
shpix   18  25
shpix   9   26
shpix   -18 28
shpix   -9  29
#
SVTCA[y-axis]
mdap[rnd]   1
alignrp     3
mdrp[grey]  19
shp[rp2]    16
mirp[rp0,rnd,grey]  vheight_shoot 13
mirp[min,rnd,grey]  headstem 43
f_deltap    43 27+4 43 28+4 43 29+4
mirp[rp0,rnd,grey]  headdia 7
f_deltap    7 19+8   7 24+8 7 25+8 7 26+8   7 40+8 7 41+8   7 44-8 7 45-8
mirp[min,rnd,grey]  headstem 37
f_deltap    37 27-4 37 28-4 37 29-4
#
srp0    13
mdrp[rp0,rnd,grey]  27
mirp[min,rnd,grey]  headstem 55
f_deltap    55 27+4 55 28+4 55 29+4
mirp[rp0,rnd,grey]  headdia 21
f_deltap    21 19+8  21 24+8  21 25+8  21 26+8  21 40+8 21 41+8
mirp[min,rnd,grey]  headstem 49
f_deltap    49 27-4 49 28-4 49 29-4
#
mdrp[rp0,grey]  17
mdrp[grey]  2
#
shpix    -18 37
shpix   16  2
shpix   -16 16
shpix   -16 19
shpix   -18 49
IUP[y]
shpix   -9  31
""",

    #aw_ang
    "uni0E2D": """
f_deltap    42 9+8  42 17-8  42 19-8  42 21-8  42 22+8 
srp0    41
mirp[rp0,rnd,white] gap_143 1
mdrp[grey]  21
mirp[min,rnd,grey]  hstem 12
mirp[rp0,rnd,grey]  headdia_plus 7
mirp[min,rnd,grey]  headstem   32
f_deltap    32 27+4 32 28+4 32 29+4
mirp[rnd,grey]  headstem_plus_hole 38
f_deltap    38 27+4 38 28+4 38 29+4
#
srp0    42
mirp[rp0,rnd,white]  gap_164 28
mirp[min,rnd,grey]  hstem 14
f_deltap    7 12-4  7 13-4
IUP[x]
shpix    9   3
shpix    -9  5
shpix    -18 6
shpix    -18 8
shpix    -9  9
#
SVTCA[y-axis]
MDAP[rnd]   0
mirp[min,rnd,grey]  vstem   14
mirp[rp0,rnd,grey]  vheight_shoot  25
mdrp[grey]  22
mirp[rp0,min,rnd,grey]  vstem_curve   18
shpix   16 18
f_deltap    18 17-4   18 18+4 18 19+3 18 20+2 18 21+2 18 22+2 18 23+2 18 24+2 18 25+2   18 26+1   18 29+6 18 30+6 18 31+6 18 32+6 18 33+6 18 34+6 18 35+6
mdrp[grey]  21
mdrp[rp0,rnd,white]  4
mdap[rnd]   4
f_deltap    4 16-8 4 17-8  4 23-8  4 24-8 4 25-8  
mirp[min,rnd,grey]  headstem    35
f_deltap    35 27+4 35 28+4 35 29+4
mirp[rp0,rnd,grey]  headdia 10
f_deltap    10 19+8   10 24+8 10 25+8 10 26+8   10 40+8 10 41+8   10 44-8 10 45-8
mirp[min,rnd,grey]  headstem    29
f_deltap    29 27-4 29 28-4 29 29-4
shpix    -18 29
IUP[y]
""",

    #ho_nokhuk
    "uni0E2E": """
f_deltap    56 9+8  56 15-8  56 18+8  
srp0    55
mirp[rp0,rnd,white]  gap_143 1
mdrp[grey]  22
mirp[rp0,min,rnd,grey]  hstem   12
mdrp[grey]  52
srp0    1
mirp[rp0,rnd,grey]  headdia_plus 7
mirp[min,rnd,grey]  headstem   36
f_deltap    36 27+4 36 28+4 36 29+4
mirp[rnd,grey]  headstem_plus_hole 42
f_deltap    42 27+4 42 28+4 42 29+4
#
srp0    56
mirp[rp0,rnd,white]  gap_186 32
mdrp[grey]  29
ip  28
mirp[min,rnd,grey]  hstem 14
sloop   4
ip  47 27 30 17
#
f_deltap    7 12-4  7 13-4
IUP[x]
shpix    9   3
shpix    -9  5
shpix    -18 6
shpix    -18 8
shpix    -9  9
#
shpix   16  47
shpix   -16 30
shpix   -16 52
#
SVTCA[y-axis]
MDAP[rnd]   0
mirp[min,rnd,grey]  vstem   14
mirp[rp0,rnd,grey]  vheight_shoot 25
alignrp 28
mdrp[grey]  27
mdrp[grey]  30  
mirp[rp0,rnd,grey]  vstem  49
shpix   16 49
f_deltap    49 17-4   49 20+2 49 21+2 49 22+2 49 23+2 49 24+2 49 25+2   49 26+1   49 34+6 49 35+6
mdrp[grey]  47
mdrp[grey]  17
mdrp[rp0,rnd,white]  4
mdap[rnd]  4
f_deltap    4 16-8
srp1    49
ip  19
mirp[min,rnd,grey]  headstem    39
f_deltap    39 27+4 39 28+4 39 29+4
mirp[rp0,rnd,grey]  headdia 10
f_deltap    10 19+8   10 24+8 10 25+8 10 26+8   10 40+8 10 41+8   10 44-8 10 45-8
mirp[min,rnd,grey]  headstem    33
f_deltap    33 27-4 33 28-4 33 29-4
shpix    -18 33
srp0    19
mdrp[grey]  45
IUP[y]
shpix   -9  27
shpix   9   17
""",

    #paiyal
    "uni0E2F": """
f_deltap    36 9+8   36 11+8   
srp0    35
mirp[rp0,rnd,white]  gap_113 8
mirp[min,rnd,grey]  headstem 32
f_deltap    32 27-4 32 28-4 32 29-4
mirp[rp0,rnd,grey]  headdia 14
f_deltap    14 19-8  14 24-8 14 25-8 14 26-8   14 40-8 14 41-8
mirp[min,rnd,grey]  headstem 26
f_deltap    26 27+4 26 28+4 26 29+4
#
srp0    36
mirp[rp0,rnd,white]  gap_186 22
mirp[min,rnd,grey]  hstem 1
shp[rp2]    21
IUP[x]
shpix   -9 15
shpix   -18 13
shpix   -9  12
shpix   9   10
shpix   18  9
shpix   9   7
#
shpix   -16 17
#
SVTCA[y-axis]
mdap[rnd]   0
mirp[rp0,rnd,grey]  vheight_shoot 21
alignrp 11
mdrp[grey]  2
mdrp[grey]  22
srp0    11
mirp[min,rnd,grey]  headstem 29
f_deltap    29 27+4 29 28+4 29 29+4
mirp[rnd,grey]  headstem_plus_hole 23
f_deltap    23 27+4 23 28+4 23 29+4
mirp[rp0,rnd,grey]  headdia 17
f_deltap    17 19+8   17 24+8 17 25+8 17 26+8
mdrp[rnd,grey]  18
mirp[grey]  vstem 5
shpix   -16 18
shpix   16  2
shpix   16  5
IUP[y]
""",

    #sara_a
    "uni0E30": """
srp0    60
mirp[rp0,rnd,white]  gap_102 3
alignrp 21
mirp[min,rnd,grey]  headstem 45
f_deltap    45 27-4 45 28-4 45 29-4
shp[rp2]    57
mirp[rp0,rnd,grey]  headdia 9
f_deltap    9 19-8   9 24-8 9 25-8 9 26-8   9 40-8 9 41-8
alignrp 27
mirp[min,rnd,grey]  headstem 39
f_deltap    39 27+4 39 28+4 39 29+4
shp[rp2]    51
mdrp[rp0,grey]  11
alignrp 29
#
srp0    61
mdrp[rp0,white]  15
alignrp     33
mdrp[grey]  14
shp[rp2]    32
IUP[x]
shpix   -16 29
shpix   -36 28
shpix   -36 26
shpix   36  22
shpix   18  20
shpix   9   26
#
shpix   -16 11
shpix   -36 10
shpix   -36 8 
shpix   36  4 
shpix   18  2 
#
SVTCA[y-axis]
mdap[rnd]   0
mdrp[rp0,rnd,grey]  11
mdrp[rp0,rnd,grey]  6
mdrp[grey]  14
mdrp[grey]  15
mirp[min,rnd,grey]  headstem 42
f_deltap    42 27+4 42 28+4 42 29+4
mirp[rnd,grey]  headstem_plus_hole 36
f_deltap    36 27+4 36 28+4 36 29+4
#
srp0    0
mirp[rp0,rnd,grey]  vheight 24
mdrp[grey]  32
mdrp[grey]  33
mirp[min,rnd,grey]  headstem 54
f_deltap    54 27+4 54 28+4 54 29+4
mirp[rnd,grey]  headstem_plus_hole 48
f_deltap    48 27+4 48 28+4 48 29+4
mdrp[rp0,rnd,grey]  29
mdrp[min,rnd,grey]  18
shpix   -18 48
shpix   -18 36
shpix   8  18
shpix   8  0
shpix   -16 29
shpix   -16  11
f_deltap    36 20+2 48 20+2   36 21+2 48 21+2
IUP[y]
""",

    #sara_maihanakat
    "uni0E31": """
mdap[rnd]   9
mdrp[grey]  15
mdrp[grey]  11
mirp[min,rnd,grey]  headstem 21
f_deltap    21 27+4 21 28+4 21 29+4
mirp[rp0,rnd,grey]  headdia 3
f_deltap    3 19+8   3 24+8 3 25+8 3 26+8   3 40+8 3 41+8
mirp[min,rnd,grey]  headstem 27
f_deltap    27 27-4 27 28-4 27 29-4
IUP[x]
shpix   -16 11
shpix   -9  10
shpix   -18 8
shpix   -9  7
shpix   9   5
shpix   18  4
shpix   9   2
#
SVTCA[y-axis]
mdap[rnd]   0
#f_deltap    0 9+8  0 12+8  0 14+8 
f_deltap    0 9+8  0 12+8   0 14+8  0 21-8  0 26-8  0 28-8  0 30-8  0 31-8   0 33-8   
mirp[min,rnd,grey]  vstem_small 11
mdrp[rp0,rnd,grey]  6
mirp[min,rnd,grey]  headstem 24
f_deltap    24 27+4 24 28+4 24 29+4
mirp[rnd,grey]  headstem_plus_hole 18
f_deltap    18 27+4 18 28+4 18 29+4
mdrp[grey]  14
mdrp[grey]  15
shpix   8  0
shpix   -16 18
shpix   -8  11
IUP[y]
""",

    #sara_aa
    "uni0E32": """
srp0    16
mirp[white]  gap_51 8
#
srp0    17
mirp[rp0,rnd,white]  gap_164 15
mirp[min,rnd,grey]  hstem 1
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   1
mirp[rp0,rnd,grey]  vheight_shoot 12
mdrp[grey]  9
mirp[rp0,min,rnd,grey]  vstem_curve   5
shpix   16 5
f_deltap    5 17-4   5 18+4 5 19+3 5 20+2 5 21+2 5 22+2 5 23+2 5 24+2 5 25+2   5 26+1   5 29+6 5 30+6 5 31+6 5 32+6 5 33+6 5 34+6 5 35+6
mdrp[grey]  8
IUP[y]
""",

    #sara_am
    #uni0E33: use sara_aa with nikahit
    
    #sara_i
    "uni0E34": """
mdap[rnd]   0
mirp[grey]  w_102 14
mdrp[rp0,rnd,white]  4
mirp[grey]  w_102 20
IUP[x]
shpix   -16 20
shpix   16  14
#
SVTCA[y-axis]
mdap[rnd]   12
f_deltap    12 9+8  12 12+8   12 17-8  12 18-8 12 21-8  12 24-8   12 26-8 12 27-8  12 28-8  12 30-8  12 31-8   12 33-8 12 34-8   12 37-8  12 41-8
#f_deltap    12 9+8  12 12+8   12 21-8  12 26-8  12 28-8  12 30-8  12 31-8   12 33-8   
mdrp[grey]  2
mdrp[rp0,min,rnd,white]   17
mdrp[grey]  8
shpix   -8  12
shpix   8   17
IUP[y]
""",

    #sara_ii
    "uni0E35": """
mdap[rnd]   0
mirp[grey]  w_102 16
mirp[min,rnd,grey]   sarastem 12
mdrp[rp0,rnd,white]  4
mirp[grey]  w_102 22
IUP[x]
shpix   -16 22
shpix   16  16
#
SVTCA[y-axis]
mdap[rnd]   14
f_deltap    14 9+8  14 12+8   14 17-8  14 18-8 14 21-8  14 24-8   14 26-8 14 27-8  14 28-8  14 30-8  14 31-8   14 33-8 14 34-8   14 37-8  14 41-8
mdrp[grey]  2
mdrp[rp0,min,rnd,white]   19
mdrp[rp0,grey]  8
mdrp[min,rnd,grey]  12
shpix   -8  14
shpix   8   19
IUP[y]
""",

    #sara_ue
    "uni0E36": """
mdap[rnd]   0
mirp[grey]  w_102 24
mdrp[rp0,rnd,white]  4
mirp[grey]  w_102 30
srp0    0
mdrp[rp0,rnd,grey]  16
mdrp[rnd,grey]  10
f_deltap    10 14-8 10 15-8 10 16-8
ip  41
ip  35
ip  19
IUP[x]
shpix   -16 30
shpix   16  24
shpix   8   10
shpix   -8  19
#
SVTCA[y-axis]
mdap[rnd]   22
f_deltap    22 9+8  22 12+8   22 17-8  22 18-8 22 21-8  22 24-8   22 26-8 22 27-8  22 28-8  22 30-8  22 31-8   22 33-8 22 34-8   22 37-8  22 41-8
mdrp[grey]  2
mdrp[rp0,min,rnd,white]   27
mdrp[rp0,grey]  8
mdrp[rp0,rnd,grey]  13
mdap[rnd]   13
mdrp[rnd,grey]  19
ip  10
ip  38
ip  32
f_deltap    32 14-3 32 15-3 32 16-3
shpix   -8  22
shpix   8   27
shpix   -9  32
IUP[y]
""",

    #sara_uee
    "uni0E37": """
mdap[rnd]   0
mirp[grey]  w_102 20
mirp[rp0,min,rnd,grey]   sarastem 16
mdrp[rp0,min,rnd,white] 13
mirp[rp0,min,rnd,grey]   sarastem 11
srp0    0
mdrp[rp0,rnd,white]  4
mirp[grey]  w_102 26
IUP[x]
shpix   -16 26
shpix   16  20
shpix   -4  0
shpix   -4  13
#
SVTCA[y-axis]
mdap[rnd]   18
f_deltap    18 9+8  18 12+8   18 17-8  18 18-8 18 21-8  18 24-8   18 26-8 18 27-8  18 28-8  18 30-8  18 31-8   18 33-8 18 34-8   18 37-8  18 41-8
mdrp[grey]  2
mdrp[rp0,min,rnd,white]   23
mdrp[rp0,grey]  8
ip  13
ip  15
mdrp[min,rnd,grey]  11
shp[rp2]    16
shpix   -8  18
shpix   8   23
shpix   -16  15
shpix   -8  10
IUP[y]
""",

    #sara_u
    "uni0E38": """
mdap[rnd]   12
mirp[rp0,min,rnd,grey]  vstem_curve   1
mdrp[rp0,rnd,grey]  7
mirp[min,rnd,grey]  headstem_tiny 22
mdrp[min,rnd,grey]  16
f_deltap    12 9-1 12 10-1 12 11-1 12 12-1 12 13-1 12 14-1   12 15-1   12 16-1 7 16+4   
IUP[x]
SVTCA[y-axis]
mdap[rnd]   25
mirp[rp0,min,rnd,white]  vstem_tiny 10
mirp[min,rnd,grey]  headstem_tiny 19
mdrp[rp0,rnd,grey]  4
mirp[min,rnd,grey]  headstem_tiny 13
mdrp[min,rnd,grey]  0
IUP[y]
""",

    #sara_uu
    "uni0E39": """
mdap[rnd]   16
mirp[rp0,min,rnd,grey]  vstem_curve 14
mdrp[rp0,rnd,white]  12
mirp[rp0,rnd,grey]  vstem_curve 1
mdrp[rp0,rnd,grey]  7
mirp[min,rnd,grey]  headstem_tiny 26
mdrp[rnd,grey]  20
f_deltap    14 9+1   14 10+1 1 10+1   14 11+1 1 11+1   14 12+1 1 12+1   14 13+1 1 13+1   14 14+1 1 14+1   14 15+1 1 15+1   14 16+1 1 16+1 7 16+4  
IUP[x]
SVTCA[y-axis]
mdap[rnd]   29
mirp[rp0,min,rnd,grey]  vstem_tiny 10
alignrp 16
mirp[min,rnd,grey]  headstem_tiny 23
mdrp[rp0,rnd,grey]  4
f_deltap    4 10+8   4 11+8
mirp[min,rnd,grey]  headstem_tiny 17
mdrp[rp0,min,rnd,grey]  1
mirp[min,rnd,grey]  headstem 13
f_deltap    1 9+1   1 10+1   1 11+1   1 12+1   1 13+1   1 14+1   1 15+1   1 16+1   
IUP[y]
""",

    #pinthu
    "uni0E3A": """
mdap[rnd]   9
mdrp[rp0,min,rnd,grey]  3
IUP[x]
SVTCA[y-axis]
mdap[rnd]   12
mirp[rp0,min,rnd,grey]  vstem_tiny 6
mdrp[rp0,min,rnd,grey]  0
IUP[y]
""",

    #thai_baht
    "uni0E3F": """
f_deltap    50 9+8   50 10+8   
srp0    49
mirp[rp0,rnd,white]  gap_197 3
mdrp[min,rnd,grey]  25
shp[rp2]    38
#
srp0    50
mirp[rp0,rnd,white]  gap_164 18
mdrp[min,rnd,grey]  31
mdrp[rp0,rnd,grey]  12
mdrp[min,rnd,grey]  44
srp1    25
ip  23
mdap[rnd]   23
alignrp 1
alignrp 36
alignrp 5
mdrp[rp0,min,rnd,grey]  35
alignrp 48
alignrp 7
alignrp 22
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   22
alignrp 3
mdrp[min,rnd,grey]  1
mdrp[min,rnd,grey]  27
shp[rp2]    26
mdrp[rp0,rnd,grey]  8
alignrp     4
mdrp[min,rnd,grey]  6
mdrp[min,rnd,grey]  48
shp[rp2]    38
srp2    27
ip      40
mdap[rnd]   40
alignrp 39
mdrp[min,rnd,grey]  35
shp[rp2]    25
ip  15
IUP[y]
""",

    #sara_e
    "uni0E40": """
srp0    26
mirp[rp0,rnd,white] gap_377 4
mirp[rp0,min,rnd,grey]  hstem 2
mirp[rp0,rnd,grey]  headdia_plus 10
mirp[min,rnd,grey]  headstem 16
f_deltap    16 27+4 16 28+4 16 29+4
mirp[rnd,grey]  headstem_plus_hole 22
f_deltap    22 27+4 22 28+4 22 29+4
f_deltap    10 12-4  10 13-4
IUP[x]
shpix    9   1
shpix    -9  8
shpix    -18 9
shpix    -18 11
shpix    -9  12
#
SVTCA[y-axis]
MDAP[rnd]   25
mirp[min,rnd,grey]  vheight 4
mirp[rp0,rnd,grey]  vheight_lo 0
mirp[min,rnd,grey]  headstem 13
f_deltap    13 27-4 13 28-4 13 29-4
mirp[rp0,rnd,grey]  headdia 7
f_deltap    7 19-8   7 24-8 7 25-8 7 26-8   7 40-8 7 41-8   7 44+8 7 45+8
mirp[min,rnd,grey]  headstem 19
f_deltap    19 27+4 19 28+4 19 29+4
shpix    18  19
IUP[y]
""",

    #sara_ae
    #use sara_a reference: uni0E40

    #sara_o
    "uni0E42": """
srp0    52
mirp[rp0,white]  gap_51 6
mdrp[grey]  28
#
srp0    53
mirp[rp0,rnd,white] gap_377 31
mdrp[grey]  18
mirp[rp0,min,rnd,grey]  hstem   2
mirp[rp0,rnd,grey]  headdia_plus 37
mirp[min,rnd,grey]  headstem 43
f_deltap    43 27+4 43 28+4 43 29+4
mirp[rnd,grey]  headstem_plus_hole 49
f_deltap    49 27+4 49 28+4 49 29+4
f_deltap    37 12-4  37 13-4
IUP[x]
shpix    9   1
shpix    -9  39
shpix    -18 38
shpix    -18 36
shpix    -9  35
#
shpix   -16 28
#
SVTCA[y-axis]
mdap[rnd]   52
mirp[rnd,grey]  vheight_lo 0
mirp[rp0,rnd,grey]  vheight_o 10
mdrp[grey]  15
ip  17
mdrp[grey]  7
mirp[rp0,min,rnd,grey]  vstem_curve 25
shpix   16 25
f_deltap    25 17-4   25 18+4 25 19+3 25 20+2 25 21+2 25 22+2 25 23+2 25 24+2 25 25+2   25 26+1   25 29+6 25 30+6 25 31+6 25 32+6 25 33+6 25 34+6 25 35+6
mdrp[grey]  20
ip  18
mdrp[grey]  6
ip  28
srp0    0
mirp[min,rnd,grey]  headstem   40
f_deltap    40 27-4 40 28-4 40 29-4
mirp[rp0,rnd,grey]  headdia 34
f_deltap    34 19-8   34 24-8 34 25-8 34 26-8   34 40-8 34 41-8   34 44+8 34 45+8
mirp[min,rnd,grey]  headstem   46
f_deltap    46 27+4 46 28+4 46 29+4
shpix    18  46
IUP[y]
""",

    #sara_i_moun
    "uni0E43": """
srp0    64
mdrp[rp0,rnd,grey]  61
mdrp[grey]  20
mdrp[grey]  11
mdrp[rp0,rnd,grey]  55
f_deltap    55 16-8
mirp[min,rnd,grey]  headstem 14
#
srp0    65
mirp[rp0,rnd,white] gap_377 31
srp1    14
ip  8
mirp[rp0,min,rnd,grey]  hstem 2
mirp[rp0,rnd,grey]  headdia_plus 37
mirp[min,rnd,grey]  headstem 43
f_deltap    43 27+4 43 28+4 43 29+4
mirp[rnd,grey]  headstem_plus_hole 49
f_deltap    49 27+4 49 28+4 49 29+4
#
mdap[rnd]   8
f_deltap    8 17+8
mirp[grey]  vstem_curve 26
f_deltap    37 12-4  37 13-4
f_deltap    26 14-1 10 14+3   26 15-2  10 15+2   26 16-2 10 16+2
IUP[x]
shpix    9   1
shpix    -9  39
shpix    -18 38
shpix    -18 36
shpix    -9  35
#
shpix   9   21
shpix   18   19
shpix   9   18
shpix   -9  16
shpix   -18 15
shpix   -18 13
shpix   -9  12
#
shpix   -9   11
shpix   9   8
#
SVTCA[y-axis]
MDAP[rnd]   64
mdrp[rnd,grey]  11
mirp[rp0,rnd,grey]  vheight_lo 0
mirp[min,rnd,grey]  headstem 40
f_deltap    40 27-4 40 28-4 40 29-4
mirp[rp0,rnd,grey]  headdia 34
f_deltap    34 19-8   34 24-8 34 25-8 34 26-8   34 40-8 34 41-8   34 44+8 34 45+8
mirp[min,rnd,grey]  headstem 46
f_deltap    46 27+4 46 28+4 46 29+4
#
mdap[rnd]   58
mdrp[rnd,grey]  23
ip  11
mdrp[rp0,rnd,grey]  17
mirp[min,rnd,grey]  headstem 52
IUP[y]
shpix    18  46
shpix   9   10
shpix   9   58
IUP[y]
""",

    #sara_i_mlai
    "uni0E44": """
srp0    37
mdrp[rp0,white] 9
mdrp[grey]  10
#
srp0    38
mirp[rp0,rnd,white] gap_377 16
mirp[rp0,min,rnd,grey]  hstem 2
alignrp 15
mirp[rp0,rnd,grey]  headdia_plus 22
mirp[min,rnd,grey]  headstem 28
f_deltap    28 27+4 28 28+4 28 29+4
mirp[rnd,grey]  headstem_plus_hole 34
f_deltap    34 27+4 34 28+4 34 29+4
srp2    9
sloop 3
ip 6 13 5
f_deltap    22 12-4  22 13-4
IUP[x]
shpix    9   2
shpix    -9  24
shpix    -18 23
shpix    -18 21
shpix    -9  20
#
SVTCA[y-axis]
MDAP[rnd]   37
mirp[rp0,rnd,grey]  vheight_o 16
sloop   4
ip  10 9 13 5
mirp[min,rnd,grey]  vstem_curve 3
srp0    37
mirp[rp0,rnd,grey]  vheight_lo 0
mirp[min,rnd,grey]  headstem 25
f_deltap    25 27-4 25 28-4 25 29-4
mirp[rp0,rnd,grey]  headdia 19
f_deltap    19 19-8   19 24-8 19 25-8 19 26-8   19 40-8 19 41-8   19 44+8 19 45+8
mirp[min,rnd,grey]  headstem 31
f_deltap    31 27+4 31 28+4 31 29+4
shpix    18  31
IUP[y]
shpix   -9  13
shpix   9   3
""",

    #lakkhangyao
    "uni0E45": """
srp0    16
mirp[grey]  gap_113 8
#
srp0    17
mirp[rp0,rnd,white]  gap_205 15
mirp[min,rnd,grey]  hstem 1
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   16
mirp[rnd,grey]  vheight_lu 1
mirp[rp0,rnd,grey]  vheight_shoot 12
mdrp[grey]  9
mirp[rp0,min,rnd,grey]  vstem_curve   5
shpix   16 5
f_deltap    5 17-4   5 18+4 5 19+3 5 20+2 5 21+2 5 22+2 5 23+2 5 24+2 5 25+2   5 26+1   5 29+6 5 30+6 5 31+6 5 32+6 5 33+6 5 34+6 5 35+6
mdrp[grey]  8
IUP[y]
""",

    #maiyamok
    "uni0E46": """
f_deltap    39 9+8  39 10+8  39 11+8 
srp0    38
mdrp[rp0,rnd,grey]  13
mdrp[grey]  8
mirp[min,rnd,grey]  headstem    29
f_deltap    29 27+4 29 28+4 29 29+4
mirp[rp0,rnd,grey]  headstem_plus_hole 35
f_deltap    35 27+4 35 28+4 35 29+4
mdrp[grey]  19
#
srp0    39
mirp[rp0,rnd,white]  gap_186 25
mirp[min,rnd,grey]  hstem 1
srp1    8
sloop   6
ip  21 6 22 5 23 4
IUP[x]
shpix   -9  11
shpix   -18 12
shpix   -18 14
shpix   -9  15
shpix   9   17
shpix   18  16
shpix   9   20
#
shpix   -16 8
shpix   -9  35
#
SVTCA[y-axis]
MDAP[rnd]   38
mirp[rnd,grey]  vheight_lu 1
mirp[rp0,rnd,grey]  vheight_shoot 21
alignrp 23
mirp[min,rnd,grey]  vstem_curve   6
shpix   16 6
f_deltap    6 17-4   6 18+4 6 19+3 6 20+2 6 21+2 6 22+2 6 23+2 6 24+2 6 25+2   6 26+1   6 29+6 6 30+6 6 31+6 6 32+6 6 33+6 6 34+6 6 35+6
shp[rp2]    4
mdrp[rp0,min,rnd,grey]  22
mirp[min,rnd,grey]  vstem   5
mdrp[rp0,rnd,white]  10
mdap[rnd]   10
f_deltap    10 9+8  10 10+8  10 11+8
mirp[min,rnd,grey]  headstem    32
f_deltap    32 27+4 32 28+4 32 29+4
mirp[rp0,rnd,grey]  headdia 16
f_deltap    16 19+8   16 24+8 16 25+8 16 26+8   16 40+8 16 41+8
mirp[min,rnd,grey]  headstem    26
f_deltap    26 27-4 26 28-4 26 29-4
shpix   -8 22
shpix   8   6
shpix   8   4
shpix   9   32
IUP[y]
""",

    #maitaikhu
    "uni0E47": """
mdap[rnd]  44
mdrp[grey]  19
mirp[min,rnd,grey]  headstem_wan 50
mdrp[rp0,rnd,grey]  38
mirp[min,rnd,grey]  headstem_wan 56
#
mdap[rnd]   11
mirp[min,rnd,grey]  sarastem 26
srp1    38
ip  28
ip  8
shpix   9   36
shpix   -16 26
IUP[x]
shpix   18 39
shpix   9   40
shpix   -9  42
shpix   -18 43
shpix   -18 45
shpix   -9  46
#
#
SVTCA[y-axis]
MDAP[rnd]   0
f_deltap    0 9+8   0 12+8   0 14+8   
alignrp     8
mdrp[min,rnd,grey]  36
mdrp[min,rnd,grey]  47
f_deltap    47 9-8 47 10-8 47 11-8
mdrp[rp0,rnd,grey]  41
mirp[min,rnd,grey]  headstem_wan 53
srp0    8
mdrp[min,rnd,grey]  28
mdrp[rp0,rnd,grey]  5
mirp[min,rnd,grey]  vstem_tiny 31
srp0    41
f_deltap    41 20-8  41 21-8 
mdrp[rp0,min,rnd,white]  23
mirp[rp0,min,rnd,grey]  vstem_tiny 14
mdrp[min,rnd,grey]  18
shpix   -16  14
shpix   16  5
shpix   -8  28
IUP[y]
""",

    #maiek
    "uni0E48": """
MDAP[rnd]   0
f_deltap    0 15+8 0 16+8 0 25+8 0 26+8 0 27+8 0 35+8 0 36+8 0 37+8 0 38+8 
mdrp[min,rnd,grey]  2
IUP[x]
SVTCA[y-axis]
MDAP[rnd]   0
f_deltap    0 9+8   0 12+8   0 14+8 0 15+8 0 16+8 0 17-8   0 21-8 0 22-8 0 23-8   0 26-8 0 27-8  0 28+8 0 29+8   0 37-8 0 38-8 0 39-8   0 41-8  
mdrp[grey]  2
IUP[y]
""",

    #maiek
    "uni0E48.low": """
MDAP[rnd]   0
mirp[min,rnd,grey]  vstem_curve 2
IUP[x]
SVTCA[y-axis]
MDAP[rnd]   0
f_deltap    0 9+8   0 12+8   0 14+8   0 15+8
mirp[min,rnd,grey]  w_340 2
IUP[y]
""",

    #maitho
    "uni0E49": """
MDAP[rnd]   14
f_deltap    14 15+8 14 16+8 14 25+8 14 26+8 14 27+8 14 35+8 14 36+8 14 37+8 14 38+8 
mdrp[grey]  22
mdrp[rnd,grey]  8
shp[rp2]    1
ip  28
ip  34
IUP[x]
SVTCA[y-axis]
MDAP[rnd]   0
f_deltap    0 9+8   0 12+8   0 14+8 0 15+8 0 16+8 0 17-8   0 21-8 0 22-8 0 23-8   0 26-8 0 27-8  0 28+8 0 29+8   0 37-8 0 38-8 0 39-8   0 41-8  
mdrp[min,rnd,grey]  17
shpix   -16 17
shp[rp2]    2
mdrp[rp0,rnd,grey]  11
ip  31
ip  25
ip  5
mdrp[grey]  21
IUP[y]
""",

    #maitho
    "uni0E49.low": """
MDAP[rnd]   14
mdrp[grey]  22
mdrp[rnd,grey]  8
shp[rp2]    1
ip  28
ip  34
ip  5
ip  17
IUP[x]
shpix   16  5
shpix   -16 17
#
SVTCA[y-axis]
MDAP[rnd]   0
f_deltap    0 9+8   0 12+8   0 14+8
mirp[rp0,min,rnd,grey]  vstem_tiny 17
alignrp     2
mdrp[rp0,rnd,grey]  11
ip  31
ip  25
ip  5
mdrp[grey]  21
srp0    0
shpix   -16 17
shpix   -16 2
IUP[y]
""",

    #maitri
    "uni0E4A": """
mdap[rnd]   31
f_deltap    31 15+8 31 16+8 31 25+8 31 26+8 31 27+8 31 35+8 31 36+8 31 37+8 31 38+8 
mdrp[grey]  36
mdrp[grey]  33
mdrp[grey]  2
mdrp[grey]  1
mdrp[rp0,rnd,grey]  23
sloop   8
ip  26 27 28 5 7 8 9 11
mdrp[rp0,rnd,grey]  17
f_deltap    17 13-8 17 14-8 17 15-8 17 16-8 17 22-8 17 23-8
ip  47
ip  41
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   0
f_deltap    0 9+8   0 12+8   0 14+8 0 15+8 0 16+8 0 17-8   0 21-8 0 22-8 0 23-8   0 26-8 0 27-8  0 28+8 0 29+8   0 37-8 0 38-8 0 39-8   0 41-8  
alignrp 20
mdrp[rp0,rnd,grey]  26
sloop   7
ip  27 28 7 8 9 2 33
srp0    20
mdrp[grey]  14
ip  44
ip  38
ip  11
IUP[y]
""",

    #maitri
    "uni0E4A.low": """
mdap[rnd]   31
mdrp[grey]  36
mdrp[min,rnd,grey]  5
mdrp[rp0,rnd,grey]  23
sloop   9
ip  26 27 28 7 8 9 2 1 33
mdrp[rp0,min,rnd,grey]  11
mdrp[rnd,grey]  17
f_deltap    17 9-8 17 10-8 17 11-8 17 12-8 17 15-8 17 16-8 17 17-8 17 18-8 17 19-8
ip  47
ip  41
shpix   -8  10
shpix   8   5
shpix   -8   31
shpix   -9  47
shpix   -9  13
shpix   8   14
shpix   8   37
IUP[x]
shpix   -9  32
shpix   9   34
#
SVTCA[y-axis]
MDAP[rnd]   0
f_deltap    0 9+8   0 12+8   0 14+8
alignrp     20
mdrp[grey]  2
ip  33
mdrp[rp0,rnd,grey]  26
alignrp 28
mdrp[grey]  35
mdrp[min,rnd,grey]  9
shp[rp2]    7
ip  27
srp0    20
mdrp[rnd,grey]  14
ip  44
ip  38
ip  11
shpix   8 1
shpix   8 20
shpix   8   9
shpix   8   7
shpix   -16 27
shpix   -16 11
IUP[y]
""",

    #maichattawa
    "uni0E4B": """
mdap[rnd]   0
f_deltap    0 15+8 0 16+8 0 35+8 0 36+8 0 37+8 0 38+8 
alignrp     8
mdrp[grey]  10
mdrp[rp0,min,rnd,grey]  1
alignrp     5
mdrp[grey]  3
IUP[x]
shpix   -8  8
shpix   -8  11
shpix   8   5
shpix   8   2
#
SVTCA[y-axis]
MDAP[rnd]   11
f_deltap    11 9+8   11 12+8   11 14+8 11 15+8 11 16+8 11 17-8   11 21-8 11 22-8 11 23-8 11 24-8   11 26-8 11 27-8  11 28+8 11 29+8   11 37-8 11 38-8 11 39-8   11 41-8  
alignrp     3
mdrp[grey]  0
mdrp[rp0,min,rnd,grey]  8
alignrp     4
mdrp[grey]  7
IUP[y]
shpix   -8  8
shpix   8   11
shpix   -8  5
shpix   8   2
""",

    #maichattawa
    "uni0E4B.low": """
mdap[rnd]   0
alignrp 8
mdrp[grey]  10
mirp[rp0,rnd,grey]  vstem 2
alignrp 6
mdrp[grey]  4
IUP[x]
shpix   -8  8
shpix   -8  11
shpix   8   5
shpix   8   2
#
SVTCA[y-axis]
mdap[rnd]   11
f_deltap    0 9+8   0 12+8   0 14+8
alignrp 3
mdrp[grey]  0
mirp[rp0,rnd,grey]  vstem 8
alignrp 4
mdrp[grey]  7
IUP[y]
shpix   -8  8
shpix   8   11
shpix   -8  5
shpix   8   2
""",

    #thanthakhat
    "uni0E4C": """
mdap[rnd]   17
mdrp[grey]  11
mdrp[min,rnd,grey]  3
ip  23
ip  29
IUP[x]
SVTCA[y-axis]
MDAP[rnd]   0
f_deltap    0 9+8   0 12+8    0 21-8 0 22-8 0 23-8   0 26-8 0 27-8  0 28+8 0 29+8   0 37-8 0 38-8 0 39-8   0 41-8  
mdrp[rp0,rnd,grey]  6
ip  26
ip  20
ip  15
mdrp[grey]  10
IUP[y]
""",

    #thanthakhat
    "uni0E4C.low": """
mdap[rnd]   17
mdrp[grey]  11
mdrp[rp0,rnd,grey]  3
ip  23
ip  29
IUP[x]
SVTCA[y-axis]
MDAP[rnd]   0
f_deltap    0 9+8   0 12+8   0 14+8
mdrp[rp0,rnd,grey]  6
ip  26
ip  20
ip  15
mdrp[grey]  10
IUP[y]
""",

    #nikhahit
    "uni0E4D": """
MDAP[rnd]   9
mirp[min,rnd,grey]  headstem 15
mirp[rp0,rnd,grey]  headdia 3
mirp[min,rnd,grey]  headstem 21
IUP[x]
shpix   9   15
shpix   -9   21
#
SVTCA[y-axis]
MDAP[rnd]   0
f_deltap    0 9+8   0 12+8   0 14+8
mirp[min,rnd,grey]  headstem 12
mirp[rp0,rnd,grey]  headdia 6
mirp[min,rnd,grey]  headstem 18
shpix   9   18
shpix   -9   12
IUP[y]
""",

    #nikhahit
    "uni0E4D.high": """
MDAP[rnd]   9
mdrp[min,rnd,grey]  15
mdrp[rp0,rnd,grey]  3
mdrp[min,rnd,grey]  21
shpix   9   15
shpix   -9  21
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   0
f_deltap    0 9+8   0 12+8    0 21-8 0 22-8 0 23-8   0 26-8 0 27-8  0 28+8 0 29+8   0 37-8 0 38-8 0 39-8   0 41-8  
mdrp[min,rnd,grey]  12
mdrp[rp0,rnd,grey]  6
mdrp[min,rnd,grey]  18
shpix   9   18
shpix   -9   12
IUP[y]
""",

    #yamakkan
    "uni0E4E": """
SRP0    0
mdrp[rp0,rnd,grey]  4
mirp[min,rnd,grey]  sarastem 27
mdrp[rp0,rnd,grey]  10
mirp[min,rnd,grey]  sarastem 20
srp0    0
mdrp[rnd,grey]  16
mdrp[grey]  24
shpix   -8  20
shpix   -8  27
IUP[x]
shpix   16  7
#
SVTCA[y-axis]
MDAP[rnd]   0
f_deltap    0 9+8   0 12+8   0 14+8
mirp[min,rnd,grey]  headstem    29
mdrp[rp0,rnd,grey]  23
mirp[min,rnd,grey]  headstem    25
ip  7
mdrp[rp0,rnd,grey]  13
mirp[min,rnd,grey]  headstem    18
IUP[y]
""",

    #fongman
    "uni0E4F": """
SRP0    56
mirp[rp0,min,rnd,grey]  gap_102 5
mdrp[min,rnd,grey]  29
mdrp[rp0,rnd,grey]  35
mdrp[min,rnd,grey]  53
mdrp[rp0,rnd,grey]  41
mdrp[min,rnd,grey]  47
mdrp[rp0,rnd,grey]  15
mdrp[min,rnd,grey]  23
mdrp[rnd,white]  57
IUP[x]
SVTCA[y-axis]
MDAP[rnd]   56
mirp[rp0,rnd,grey]  vheight_lo 0
mdrp[min,rnd,grey]  20
mdrp[rp0,rnd,grey]  32
mdrp[min,rnd,grey]  44
mdrp[rp0,rnd,grey]  38
mdrp[min,rnd,grey]  50
mdrp[rp0,rnd,grey]  10
mdrp[min,rnd,grey]  26
IUP[y]
""",

    #thaidigit_zero
    "uni0E50": """
SRP0    24
mirp[rp0,min,rnd,grey]  headhole    3
mirp[min,rnd,grey]  hstem   21
mirp[rp0,rnd,grey]  w_956    9
mirp[min,rnd,grey]  hstem   15
mdrp[rnd,white]  25
IUP[x]
SVTCA[y-axis]
MDAP[rnd]   24
mirp[rnd,grey]  vheight_lo  0
mirp[rp0,rnd,grey]  vheight_num 6
mirp[min,rnd,grey]  vstem_curve 18
srp0    0
mirp[min,rnd,grey]  vstem_curve 12
IUP[y]
""",

    #thaidigit_one
    "uni0E51": """
f_deltap    49 10+8  49 11+8  49 21+8  49 34+8
SRP0    48
mirp[rp0,min,rnd,grey]  gap_152 3
mirp[min,rnd,grey]  hstem   22
mdrp[rp0,min,rnd,grey]  33
f_deltap    33 23-8  33 24-8  33 25-8  33 26-8  
mirp[min,rnd,grey]  headstem 39
f_deltap    39 27+4 39 28+4 39 29+4
mirp[rp0,rnd,grey]  headdia 27
f_deltap    27 19+8  27 24+8 27 25+8 27 26+8 
ip  25
mirp[min,rnd,grey]  headstem 45
f_deltap    45 27-4 45 28-4 45 29-4
#
srp0    49
mirp[rp0,rnd,white] gap_152  9
mdrp[grey]  12
mdrp[rp0,min,rnd,grey]  16
mdrp[grey]  13
#
shpix   -16 22
shpix   16  16
IUP[x]
#
shpix   36  28
shpix   36  26
shpix   -36 32
shpix   -18 34
#
shpix   16  25
#
SVTCA[y-axis]
MDAP[rnd]   48
mirp[rp0,rnd,grey]  vheight_num 6
mirp[min,rnd,grey]  vstem_curve 19
srp0    48
mdrp[rp0,rnd,grey]  30
mirp[min,rnd,grey]  headstem 42
f_deltap    42 27+4 42 28+4 42 29+4
mirp[rp0,rnd,grey]  headstem_plus_hole 36
f_deltap    36 27+4 36 28+4 36 29+4
srp1    48
ip  0
ip  25
srp0    0
mdrp[grey]  13
mdrp[grey]  12
shpix   -16 36
shpix   16  19
IUP[y]
""",

    #thaidigit_two
    "uni0E52": """
f_deltap    51 9+8 51 11+8 
SRP0    50
mirp[rp0,min,rnd,grey]  gap_152 3
mdrp[grey]  5
mdrp[grey]  1
mirp[rp0,min,rnd,grey]  hstem   8
mdrp[grey]  6
mdrp[grey]  10
mdrp[rp0,min,rnd,white]  30
f_deltap    30 36-8  30 37-8 30 38-8 30 39-8 30 40-8 30 41-8
mdrp[min,rnd,grey]  19
mdrp[min,rnd,grey]  47
f_deltap    47 27+4 47 28+4 47 29+4   47 30-8
mdrp[rp0,min,rnd,grey]  24
f_deltap    24 17-8  24 20+8   24 26-8 
mirp[min,rnd,grey]  headstem 41
f_deltap    41 27+4 41 28+4 41 29+4
#
srp0    51
mirp[rp0,rnd,white]  gap_152 36
mirp[min,rnd,grey]  hstem 13
srp2    30
sloop   6
ip  32 33 34 15 16 17
shpix   -18 47
IUP[x]
shpix   -36 23
shpix   -36 25
shpix   18  29
#
SVTCA[y-axis]
MDAP[rnd]   0
mirp[min,rnd,grey]  vstem 11
mirp[rp0,rnd,grey]  vheight_num 32
alignrp 34
mdrp[grey]  6
mirp[min,rnd,grey]  vstem_curve 17
shp[rp2]    15
mdrp[rp0,min,rnd,grey]  33
mirp[rp0,min,rnd,grey]  vstem 16
mdrp[rp0,rnd,white]  21
f_deltap    21 9+8  21 10+8  21 12+8  21 14+8  21 17-8  21 18-8  21 19-8  21 20+8 21 21+8  21 24-8  21 25-8 21 26-8   21 29-8 21 30-8 21 31-8 21 32-8 21 33-8   21 35+8 
mirp[min,rnd,grey]  headstem 44
f_deltap    44 27+4 44 28+4 44 29+4
mirp[rp0,rnd,grey]  headdia 27
f_deltap    27 19+8  27 24+8 27 25+8  27 26+8 
mirp[min,rnd,grey]  headstem 38
f_deltap    38 27-4 38 28-4 38 29-4
shpix   16   17
shpix   16   15
shpix   -16  33
IUP[y]
""",

    #thaidigit_three
    "uni0E53": """
f_deltap    53 16-8  53 20-8 53 21+8 
SRP0    52
mirp[rp0,rnd,white]  gap_152 28
mirp[min,rnd,grey]  hstem   16
mdrp[rp0,min,rnd,grey]  22
f_deltap    22 26-8  22 34-8
mirp[min,rnd,grey]  headstem 43
f_deltap    43 27+4 43 28+4 43 29+4
mirp[rnd,grey]  headstem_plus_hole 49
f_deltap    49 27+4 49 28+4 49 29+4
#
srp0    53
mirp[rp0,rnd,white] gap_152 38
mdrp[grey]  0
mirp[rp0,min,rnd,grey]  hstem 3
mdrp[grey]  1
#
srp2    16
ip  10
mdap[rnd]   10
f_deltap    10 17-8  10 26-8
mirp[min,rnd,grey]  hstem 8
ip  33
IUP[x]
#
shpix   -36 21
shpix   -36 23
shpix   18  27
#
SVTCA[y-axis]
MDAP[rnd]   1
mirp[rnd,grey]  vheight_lo 25
mirp[rp0,rnd,grey]  vheight_num 31
alignrp 35
mdrp[grey]  10
mirp[min,rnd,grey]  vstem_curve 13
shp[rp2]    6
mdrp[min,rnd,grey]  33
srp0    25
mirp[min,rnd,grey]  headstem 40
f_deltap    40 27-4 40 28-4 40 29-4
mirp[rp0,rnd,grey]  headdia 19
f_deltap    19 19-8  19 24-8 19 25-8 19 26-8  19 40-8 19 41-8
mirp[min,rnd,grey]  headstem 46
f_deltap    46 27+4 46 28+4 46 29+4
shpix   -16 17
shpix   -16 33
shpix   8   13
shpix   8   6
IUP[y]
""",

    #thaidigit_four
    "uni0E54": """
f_deltap    52 9+8  52 27+8  
SRP0    51
mirp[rp0,min,rnd,grey]  gap_152 7
mirp[min,rnd,grey]  hstem   20
#
srp0    52
alignrp 14
mdrp[rp0,rnd,grey]  33
f_deltap    33 10+8 
ip  38
mirp[min,rnd,grey]  headstem 42
mirp[rp0,rnd,grey]  headstem_plus_hole 48
ip  36
ip  25
ip  2
mdrp[grey]  27
IUP[x]
shpix   -36 32
shpix   -36 34
shpix   18  28
shpix   18  26
shpix   16  25
shpix   -16 36
#
SVTCA[y-axis]
MDAP[rnd]   51
mirp[rp0,rnd,grey]  special_2 4
alignrp 0
mirp[min,rnd,grey]  vstem_curve 23
shp[rp2]    38
mdrp[rp0,rnd,grey]  36
f_deltap    36 12-8  36 14-8  36 19-8  36 20-8 36 21-8  36 27-8  36 30-8  36 34-8  36 41-8 36 42-8 
ip  25
mdrp[rp0,rnd,grey]  30
f_deltap    30 25-8  30 26-8
mirp[min,rnd,grey]  headstem 45
mirp[rnd,grey]  headstem_plus_hole 39
srp0    51
mirp[rp0,rnd,grey]  vheight_num 10
mirp[min,rnd,grey]  vstem_curve 16
mdrp[grey]  13
shpix   8   2
shpix   -18 39
IUP[y]
""",

    #thaidigit_five
    "uni0E55": """
f_deltap    74 9+8  74 27+8  
SRP0    73
mirp[rp0,min,rnd,grey]  gap_152 7
mirp[min,rnd,grey]  hstem   30
#
srp0    74
alignrp 24
mdrp[rp0,rnd,grey]  43
f_deltap    43 10+8 
ip  48
mirp[min,rnd,grey]  headstem 52
mirp[rp0,rnd,grey]  headstem_plus_hole 58
ip  46
ip  35
ip  2
mdrp[grey]  37
#
mdap[rnd]   18
mirp[min,rnd,grey]  headstem 64
mirp[rp0,rnd,grey]  headdia 12
f_deltap    12 19+8  12 24+8 12 25+8 12 26+8 12 27-8 12 28-8 12 29-8 12 44-8 12 45-8
ip  20
ip  10
mirp[min,rnd,grey]  headstem 70
IUP[x]
shpix   -18 20
shpix   18  10
shpix   -36 17
shpix   36  13
shpix   -36 42
shpix   -36 44
shpix   18  38
shpix   18  36
shpix   16  35
shpix   -16 46
#
SVTCA[y-axis]
MDAP[rnd]   73
mirp[rp0,rnd,grey]  special_2 4
alignrp 0
mirp[min,rnd,grey]  vstem_curve 33
shp[rp2]    48
mdrp[rp0,rnd,grey]  46
f_deltap    46 12-8  46 14-8  46 19-8  46 20-8 46 21-8  46 27-8  46 30-8  46 34-8  46 41-8 46 42-8 
ip  35
mdrp[rp0,rnd,grey]  40
f_deltap    40 25-8  40 26-8
mirp[min,rnd,grey]  headstem 55
mirp[rnd,grey]  headstem_plus_hole 49
srp0    73
mirp[rp0,rnd,grey]  vheight_num 20
alignrp 61
mirp[min,rnd,grey]  vstem_curve 26
mdrp[grey]  23
mirp[rp0,rnd,grey]  headstem_plus_hole 15
mirp[min,rnd,grey]  headstem 67
shpix   8   2
shpix   -18 49
IUP[y]
""",

    #thaidigit_six
    "uni0E56": """
SRP0    44
mdrp[rp0,white]  21
mdrp[grey]  22
mdrp[rp0,rnd,grey]  19
mdap[rnd]   19
mdrp[grey]  24
mdrp[rp0,rnd,grey]  3
mirp[min,rnd,grey]  headstem 41
f_deltap    41 27-4 41 28-4 41 29-4 
mirp[rp0,rnd,grey]  headdia 9
f_deltap    9 19-8 9 24-8 9 25-8 9 26-8   9 40-8 9 41-8 
mirp[min,rnd,grey]  headstem 35
f_deltap    35 27+4 35 28+4 35 29+4 
mdrp[rnd,grey]  11
#
srp0    45
mirp[rp0,rnd,white] gap_152 29
mirp[min,rnd,grey]  hstem   14
IUP[x]
shpix   -16 11
shpix   -36 8
shpix   36  4
shpix   18  2
#
SVTCA[y-axis]
MDAP[rnd]   44
mirp[rnd,grey]  vheight_lo 0
mirp[rp0,rnd,grey]  vheight_num 26
mdrp[grey]  24
mdrp[grey]  22
mirp[rp0,min,rnd,grey]  vstem_curve 17
mdrp[grey]  19
mdrp[grey]  21
srp0    0
mirp[min,rnd,grey]  vstem_curve 11
mdrp[rp0,rnd,grey]  6
f_deltap    6 12-8  6 26-8 6 27-8  6 28-8
mirp[min,rnd,grey]  headstem 38
f_deltap    38 27+4 38 28+4 38 29+4 
mirp[rnd,grey]  headstem_plus_hole 32
f_deltap    32 27+4 32 28+4 32 29+4 
shpix   -16 24
IUP[y]
""",

    #thaidigit_seven
    "uni0E57": """
f_deltap    62 10+8  62 11+8  62 12+8  62 18+8 
SRP0    61
mirp[rp0,rnd,white]  gap_152 28
mirp[min,rnd,grey]  hstem   16
mdrp[rp0,min,rnd,grey]  22
f_deltap    22 26-8  22 34-8
mirp[min,rnd,grey]  headstem 52
f_deltap    52 27+4 52 28+4 52 29+4
mirp[rnd,grey]  headstem_plus_hole 58
f_deltap    58 27+4 58 28+4 58 29+4
#
srp0    62
mirp[rp0,rnd,white] gap_102 45
mirp[rp0,min,rnd,grey]  vstem_curve 42
mdrp[rp0,min,rnd,white] 38
mirp[min,rnd,grey]  hstem   3
ip  40
mdrp[grey]  1
#
srp2    16
ip  10
mdap[rnd]   10
f_deltap    10 14+8  10 17-8  10 26-8 10 27-8 10 28-8 
mirp[min,rnd,grey]  hstem 8
ip  33
IUP[x]
#
shpix   -36 21
shpix   -36 23
shpix   18  27
f_deltap    46 17+4 
#
SVTCA[y-axis]
MDAP[rnd]   1
mirp[rnd,grey]  vheight_lo 25
mirp[rp0,rnd,grey]  vheight_num 31
alignrp 35
mdrp[grey]  10
f_deltap    10 10+5
mdrp[grey]  44
mirp[min,rnd,grey]  vstem_curve 13
shp[rp2]    6
mdrp[min,rnd,grey]  33
srp0    25
mirp[min,rnd,grey]  vstem_curve 40
mirp[min,rnd,grey]  headstem 49
f_deltap    49 27-4 49 28-4 49 29-4
mirp[rp0,rnd,grey]  headdia 19
f_deltap    19 19-8  19 24-8 19 25-8 19 26-8  19 40-8 19 41-8
mirp[min,rnd,grey]  headstem 55
f_deltap    55 27+4 55 28+4 55 29+4
shpix   -16 17
shpix   -16 33
shpix   -16 40
shpix   8   13
shpix   8   6
IUP[y]
""",

    #thaidigit_eight
    "uni0E58": """
f_deltap    53 21+8 
SRP0    52
mirp[rp0,rnd,white] gap_152 6
mirp[min,rnd,grey]  hstem   19
f_deltap    19 17-2
mdrp[rp0,rnd,grey]  23
f_deltap    23 16+8 23 17+8  23 27+8 
ip  3
ip  22
mdrp[min,rnd,grey]  24
ip  2
#
srp0    53
alignrp 13
mirp[rp0,rnd,white] gap_152 37
mirp[min,rnd,grey]  headstem 43
f_deltap    43 27+4 43 28+4 43 29+4 
mirp[rp0,rnd,grey]  headdia 31
f_deltap    31 19+8  31 24+8 31 25+8 31 26+8  31 40+8  31 41+8 
ip  28
mirp[min,rnd,grey]  headstem 49
f_deltap    49 27-4 49 28-4 49 29-4 
f_deltap    25 13-4 25 14-4 25 15-4 25 16-4
IUP[x]
shpix   36  32
shpix   18  30
shpix   -36 36
shpix   -36 38
shpix   16  28
#
SVTCA[y-axis]
MDAP[rnd]   52
mirp[rp0,rnd,grey]  special_2 3
alignrp 0
mirp[min,rnd,grey]  vstem_curve 24
mdrp[min,rnd,grey]  23
f_deltap    23 23-8 23 24-8
ip  24
ip  2
ip  22
mdrp[rp0,rnd,grey]  34
f_deltap    34 10-8 34 14-8 34 18-8 34 19-8  34 26-8  34 30-8  34 34-8 
mirp[min,rnd,grey]  headstem 46
f_deltap    46 27+4 46 28+4 46 29+4
mirp[rnd,grey]  headstem_plus_hole 40
f_deltap    40 27+4 40 28+4 40 29+4
srp0    0
mirp[rp0,rnd,grey]  vheight_num 9
mirp[min,rnd,grey]  vstem_curve 15
mdrp[grey]  12
mdrp[grey]  13
f_deltap    22 13-3 22 14-4 22 15-4 22 16-4
f_deltap    2 11+4 2 12+4 2 13+4 2 14+4 2 15+4 2 16+4
shpix   -16 40
shpix   16  2
shpix   -16 22
shpix   -16 28
IUP[y]
""",

    #thaidigit_nine
    "uni0E59": """
f_deltap    60 11+8  60 14+8  60 41+8 
SRP0    59
mirp[rp0,rnd,white]  gap_152 26
mirp[rp0,min,rnd,grey]  hstem   9
mdrp[rp0,rnd,grey]  20
f_deltap    20 11-8  20 12-8  20 19-8  20 24-8 20 25-8 20 26-8 20 28-8   20 36-8 20 37-8 20 38-8 20 40-8 
mirp[min,rnd,grey]  headstem 50
f_deltap    50 27+4 50 28+4 50 29+4
mirp[rp0,rnd,grey]  headdia 14
f_deltap    14 19+8  14 24+8 14 25+8 14 26+8   14 40+8 14 41+8
ip  12
mirp[min,rnd,grey]  headstem 56
f_deltap    56 27-4 56 28-4 56 29-4
#
srp0    60
alignrp 38
mdrp[rp0,rnd,white] 0
sloop   3
ip  33 40 41
mdrp[grey]  31
mdrp[grey]  45
mdrp[rp0,min,rnd,grey]  1
mdrp[grey]  3
IUP[x]
shpix   16  12
shpix   36  15
shpix   -36 19
shpi    -18 21
#
SVTCA[y-axis]
MDAP[rnd]   1
mirp[rnd,grey]  vheight_lo 23
mirp[rp0,rnd,grey]  vheight_num 33
alignrp 29
mdrp[grey]  37
mdrp[grey]  31
mdrp[grey]  35
mirp[rp0,min,rnd,grey]  vstem_curve 43
alignrp     6
mdrp[grey]  45
mdrp[grey]  41
srp0    23
mdrp[rp0,rnd,grey]  17
f_deltap    17 18-8  17 19-8  17 22-8  17 23-8  17 27-8 17 28-8 17 29-8  17 32-8 
mirp[min,rnd,grey]  headstem 53
f_deltap    53 27+4 53 28+4 53 29+4
mirp[rnd,grey]  headstem_plus_hole 47
f_deltap    47 27+4 47 28+4 47 29+4
mdrp[grey]  12
shpix   -16  31
shpix   -16  35
IUP[y]
""",

    #angkhankhu
    "uni0E5A": """
f_deltap    40 9+8   40 10+8   40 17+8
srp0    39
mirp[rp0,rnd,white]  gap_113 8
mirp[min,rnd,grey]  headstem 32
f_deltap    32 27-4 32 28-4 32 29-4
mirp[rp0,rnd,grey]  headdia 14
f_deltap    14 19-8  14 24-8 14 25-8 14 26-8   14 40-8 14 41-8
mirp[min,rnd,grey]  headstem 26
f_deltap    26 27+4 26 28+4 26 29+4
#
srp0    40
mirp[rp0,rnd,white]  gap_205 38
mirp[rp0,min,rnd,grey]  hstem 36
mdrp[rp0,min,rnd,white] 22
mirp[min,rnd,grey]  hstem 1
shp[rp2]    21
IUP[x]
shpix   -9 15
shpix   -18 13
shpix   -9  12
shpix   9   10
shpix   18  9
shpix   9   7
#
shpix   -16 17
#
SVTCA[y-axis]
mdap[rnd]   0
alignrp 35
mirp[rp0,rnd,grey]  vheight_shoot 21
alignrp 11
mdrp[grey]  2
mdrp[grey]  22
mdrp[grey]  37
mdrp[grey]  38
srp0    11
mirp[min,rnd,grey]  headstem 29
f_deltap    29 27+4 29 28+4 29 29+4
mirp[rnd,grey]  headstem_plus_hole 23
f_deltap    23 27+4 23 28+4 23 29+4
mirp[rp0,rnd,grey]  headdia 17
f_deltap    17 19+8   17 24+8 17 25+8 17 26+8
mdrp[rnd,grey]  18
mirp[grey]  vstem 5
shpix   -16 18
shpix   16  2
shpix   16  5
IUP[y]
""",

    #khomut
    "uni0E5B": """
SRP0    70
mirp[rp0,min,rnd,grey]  gap_152 3
mirp[rp0,min,rnd,grey]  hstem 26
mdrp[rp0,min,rnd,grey]  15
mirp[min,rnd,grey]  headstem   67
f_deltap    67 27-4 67 28-4 67 29-4
mirp[rp0,rnd,grey]  headstem_plus_hole 61
f_deltap    61 27-4 61 28-4 61 29-4
mdrp[grey]  20
mdrp[rp0,rnd,grey]  9
f_deltap    9 9-8  9 12-8  9 26-8  9 27-8 9 28-8
mdrp[min,rnd,white] 32
f_deltap    9 14-4  32 18+8 
#
srp0    71
mirp[rp0,rnd,white] gap_84 45
#
srp1    32
sloop   12
ip  33 34 37 38 39 42 43 49 51 52 54 55
#
IUP[x]
f_deltap    22 15+8  22 16+8  22 18+8 22 19+8 22 20+8 22 21+8 
shpix   36  16
shpix   36  14
shpix   -36  10
shpix   18  61
#
SVTCA[y-axis]
MDAP[rnd]   70
mirp[rp0,rnd,grey]  vheight_lo  0
mirp[min,rnd,grey]  vstem_curve 29
srp0    70
mirp[rp0,rnd,grey]  vheight_num 6
mirp[min,rnd,grey]  vstem_curve 23
mdrp[rp0,rnd,grey]  12
f_deltap    12 10+8 12 11+8  12 12+8  12 18+8  12 19+8  12 21+8   12 30+8 12 39+8 
mirp[min,rnd,grey]  headstem 58
f_deltap    58 27-4 58 28-4 58 29-4
mirp[rp0,rnd,grey]  headdia 18
f_deltap    18 19-8  18 24-8 18 25-8 18 26-8 
mirp[min,rnd,grey]  headstem 64
f_deltap    64 27+4 64 28+4 64 29+4
mdrp[grey]  20
#
mdap[rnd]   55
alignrp     52
alignrp     49
alignrp     45
mdrp[rp0,rnd,grey]  32
alignrp 37
alignrp 42
#
mdap[rnd]   34
alignrp 39
mdrp[rp0,rnd,grey]  54
alignrp 51
#
srp0    0
mdrp[rp0,rnd,grey]  46
mirp[min,rnd,grey]  vstem 45
#
shpix   16 55
shpix   16 52
shpix   16 49
shpix   -16 20
IUP[y]
""",

#    #LAO KHO TAM
    "uni0E84": """
SRP0    55
mirp[rp0,rnd,white] w_115 16
alignrp 20
mdrp[grey]  18
mirp[rp0,min,rnd,grey]  w_184 45
alignrp 35
mdrp[grey]  0
ip  43
mdrp[rp0,rnd,grey]  39
mirp[min,rnd,grey]  w_184 4
srp0    45
mdrp[rp0,rnd,grey]  47
mdrp[min,rnd,grey]  14
mdrp[rp0,rnd,grey]  51
mdrp[min,rnd,grey]  10
srp0    45
mdrp[rp0,rnd,grey]  28
mirp[rp0,min,rnd,grey]  w_184 27
mdrp[white] 56
IUP[x]
shpix   18  18
shpix   36  48
#
SVTCA[y-axis]
MDAP[rnd]   28
mirp[rp0,rnd,grey]  w_29 53
mdrp[min,rnd,grey]  8
mdrp[rp0,rnd,grey]  49
ip  47
mdrp[min,rnd,grey]  12
#
mdrp[rp0,rnd,grey]  37
mdrp[min,rnd,grey]  6
ip  35
srp1    48
sloop   4
ip  18 2 43 41
#
srp0    55
mirp[rp0,rnd,grey]  w_1147 23
mirp[min,rnd,grey]  w_156 32
shpix   18  6
shpix   -18 2
IUP[y]
f_deltap    43 15+4 43 16+4
""",

    #LAO PHO SUNG
    "uni0E9C": """
SRP0    70
mirp[rp0,rnd,white] w_115 31
mirp[min,rnd,grey]  w_184 38
mdrp[min,rnd,grey]  15
mdrp[rp0,rnd,grey]  36
mdrp[min,rnd,grey]  21
srp0    31
mdrp[rp0,rnd,grey]  50
ip  44
mirp[rp0,min,rnd,grey]  w_184 66
alignrp 57
mdrp[min,rnd,grey]  9
mdrp[rp0,rnd,grey]  53
mdrp[min,rnd,grey]  3
srp0    66
mdrp[rp0,min,rnd,grey]  59
mirp[rp0,min,rnd,grey]  w_184 64
mdrp[white] 71
srp0    44
mirp[min,rnd,grey]  w_184 45
ip  26
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   70
mirp[rp0,rnd,grey]  w_29  28
alignrp     24
mirp[min,rnd,grey]  w_184 41
shp[rp2]    48
ip  26
srp0    70
mirp[rp0,rnd,grey]  w_1147 55
alignrp 34
mdrp[grey]  62
mdrp[min,rnd,grey]  0
shp[rp2]    12
mdrp[rp0,rnd,grey]  51
alignrp 38
mdrp[grey]  66
mdrp[rnd,grey]  44
mdrp[rp0,min,rnd,grey]  6
alignrp     18
mdrp[grey]  57
IUP[y]
""",

    #LAO SO SUNG
    "uni0EAA": """
SRP0    61
mirp[rp0,rnd,white] w_115 45
mirp[rp0,min,rnd,grey]  w_195 39
alignrp 59
mirp[min,rnd,grey]  w_184 17
srp0    45
mdrp[min,rnd,grey]  3
mdrp[rp0,rnd,grey]  41
mdrp[min,rnd,grey]  9
mdrp[rp0,rnd,white] 35
mirp[min,rnd,grey]  w_184 49
srp0    45
mdrp[rp0,rnd,grey]  12
alignrp 55
mirp[rp0,min,rnd,grey]  w_184 30
mdrp[rp0,rnd,white] 23
mdrp[grey]  25
mirp[rp0,min,rnd,grey]  w_184 28
mdrp[grey]  26
mdrp[white] 62
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   61
mirp[rp0,rnd,grey]  w_29 43
alignrp     33
mirp[min,rnd,grey]  w_156 51
mdrp[min,rnd,grey]  6
mdrp[rp0,rnd,grey]  39
mdrp[min,rnd,grey]  0
mdrp[rp0,rnd,grey]  47
mirp[min,rnd,grey]  w_156 37
srp0    61
mirp[rp0,rnd,grey]  w_1147 19
mdrp[grey]  26
mdrp[grey]  21
mirp[min,rnd,grey]  w_156 57
srp1    47
ip  15
srp0    15
mirp[min,rnd,grey]  w_156 53
IUP[y]
""",

    #LAO HO SUNG
    "uni0EAB": """
SRP0    58
mirp[rp0,rnd,white] w_115 18
alignrp 22
mirp[min,rnd,grey]  w_195 30
mdrp[min,rnd,grey]  2
mdrp[rp0,rnd,grey]  26
mdrp[min,rnd,grey]  6
srp0    18
mdrp[rp0,rnd,grey]  34
mirp[rp0,min,rnd,grey]  w_184 55
alignrp 43
mdrp[min,rnd,grey]  14
mdrp[rp0,rnd,grey]  39
mdrp[min,rnd,grey]  10
srp0    34
mdrp[rp0,rnd,grey]  49
mirp[rp0,min,rnd,grey]  w_184 47
mdrp[white] 59
shpix   -8 26
shpix   8  39
IUP[x]
shpix   -36 25
shpix   -36 27
shpix   36 40
shpix   36 38
#
SVTCA[y-axis]
MDAP[rnd]   49
mirp[rp0,rnd,grey]  w_29 16
mirp[min,rnd,grey]  w_156 32
srp0    49
mirp[rp0,rnd,grey]  w_1147 24
alignrp 41
alignrp 45
mdrp[min,rnd,grey]  0
shp[rp2]    8
mdrp[rp0,rnd,grey]  20
alignrp 37
mdrp[grey]  43
mdrp[rp0,min,rnd,grey]  4
shp[rp2]    12
mdrp[grey]  55
IUP[y]
shpix   -36 43
""",

#LAO'S
#    "w_115":            69,     #115    =gap1
#    "w_186":            70,     #186    =gap2
#    "w_184":            8,      #184    =hstem
#    "w_195":            18,     #195    =hstem_curve
#    "w_156":            135,    #156    =vstem
#    "w_1147":           184,    #1147   =vheight_shoot
#    "w_1556":           151,    #1556   =vheight_po
#    "w_29":             140,    #29     =vheight_lo
#    "w_1120":           188,    #1120   =vheight
#    "w_426":            189,    #426    =vheight_lu


#    #CHAR_NAME
#    "uni0EXX": """
#SRP0    0
#
#IUP[x]
#SVTCA[y-axis]
#MDAP[rnd]   0
#
#IUP[y]
#""",


}

if __name__=="__main__":
    if sys.argv[1] == "--all":
        #$0 --all = ENCODE ALL CHARS
        sfd_file = os.path.basename(sys.argv[0]).split('.',1)[0] + '.sfd'
        print "Encoding all character in %s" % (sfd_file)
        dfont.inst_encode_all( sfd_file, pseudo_code_dict, cvt_dict )
    else:
        #$0 uni0E01 > x.txt = PRINT INSTRUCTION CODE OF uni0E01 TO x.txt
        print '\n'.join(dfont.inst_encode( pseudo_code_dict[sys.argv[1]], cvt_dict ))
